Documentation
¶
Index ¶
- type AggregationType
- type CategoryType
- type ClientFactory
- func (c *ClientFactory) NewDiagnosticSettingsCategoryClient() *DiagnosticSettingsCategoryClient
- func (c *ClientFactory) NewDiagnosticSettingsClient() *DiagnosticSettingsClient
- func (c *ClientFactory) NewEventCategoriesClient() *EventCategoriesClient
- func (c *ClientFactory) NewMetricDefinitionsClient() *MetricDefinitionsClient
- func (c *ClientFactory) NewMetricsClient() *MetricsClient
- func (c *ClientFactory) NewOperationsClient() *OperationsClient
- type DiagnosticSettings
- type DiagnosticSettingsCategory
- type DiagnosticSettingsCategoryClient
- func (client *DiagnosticSettingsCategoryClient) Get(ctx context.Context, resourceURI string, name string, ...) (DiagnosticSettingsCategoryClientGetResponse, error)
- func (client *DiagnosticSettingsCategoryClient) List(ctx context.Context, resourceURI string, ...) (DiagnosticSettingsCategoryClientListResponse, error)
- type DiagnosticSettingsCategoryClientGetOptions
- type DiagnosticSettingsCategoryClientGetResponse
- type DiagnosticSettingsCategoryClientListOptions
- type DiagnosticSettingsCategoryClientListResponse
- type DiagnosticSettingsCategoryResource
- type DiagnosticSettingsCategoryResourceCollection
- type DiagnosticSettingsClient
- func (client *DiagnosticSettingsClient) CreateOrUpdate(ctx context.Context, resourceURI string, name string, ...) (DiagnosticSettingsClientCreateOrUpdateResponse, error)
- func (client *DiagnosticSettingsClient) Delete(ctx context.Context, resourceURI string, name string, ...) (DiagnosticSettingsClientDeleteResponse, error)
- func (client *DiagnosticSettingsClient) Get(ctx context.Context, resourceURI string, name string, ...) (DiagnosticSettingsClientGetResponse, error)
- func (client *DiagnosticSettingsClient) List(ctx context.Context, resourceURI string, ...) (DiagnosticSettingsClientListResponse, error)
- type DiagnosticSettingsClientCreateOrUpdateOptions
- type DiagnosticSettingsClientCreateOrUpdateResponse
- type DiagnosticSettingsClientDeleteOptions
- type DiagnosticSettingsClientDeleteResponse
- type DiagnosticSettingsClientGetOptions
- type DiagnosticSettingsClientGetResponse
- type DiagnosticSettingsClientListOptions
- type DiagnosticSettingsClientListResponse
- type DiagnosticSettingsResource
- type DiagnosticSettingsResourceCollection
- type ErrorResponse
- type EventCategoriesClient
- type EventCategoriesClientListOptions
- type EventCategoriesClientListResponse
- type EventCategoryCollection
- type LocalizableString
- type LogSettings
- type MetadataValue
- type Metric
- type MetricAvailability
- type MetricClass
- type MetricDefinition
- type MetricDefinitionCollection
- type MetricDefinitionsClient
- type MetricDefinitionsClientListOptions
- type MetricDefinitionsClientListResponse
- type MetricSettings
- type MetricUnit
- type MetricValue
- type MetricsClient
- type MetricsClientListOptions
- type MetricsClientListResponse
- type Operation
- type OperationDisplay
- type OperationListResult
- type OperationsClient
- type OperationsClientListOptions
- type OperationsClientListResponse
- type ProxyOnlyResource
- type Response
- type ResultType
- type RetentionPolicy
- type TimeSeriesElement
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AggregationType ¶
type AggregationType string
AggregationType - the aggregation type of the metric.
const ( AggregationTypeNone AggregationType = "None" AggregationTypeAverage AggregationType = "Average" AggregationTypeCount AggregationType = "Count" AggregationTypeMinimum AggregationType = "Minimum" AggregationTypeMaximum AggregationType = "Maximum" AggregationTypeTotal AggregationType = "Total" )
func PossibleAggregationTypeValues ¶
func PossibleAggregationTypeValues() []AggregationType
PossibleAggregationTypeValues returns the possible values for the AggregationType const type.
type CategoryType ¶
type CategoryType string
CategoryType - The type of the diagnostic settings category.
const ( CategoryTypeMetrics CategoryType = "Metrics" CategoryTypeLogs CategoryType = "Logs" )
func PossibleCategoryTypeValues ¶
func PossibleCategoryTypeValues() []CategoryType
PossibleCategoryTypeValues returns the possible values for the CategoryType const type.
type ClientFactory ¶
type ClientFactory struct {
// contains filtered or unexported fields
}
ClientFactory is a client factory used to create any client in this module. Don't use this type directly, use NewClientFactory instead.
func NewClientFactory ¶
func NewClientFactory(credential azcore.TokenCredential, options *arm.ClientOptions) (*ClientFactory, error)
NewClientFactory creates a new instance of ClientFactory with the specified values. The parameter values will be propagated to any client created from this factory.
- credential - used to authorize requests. Usually a credential from azidentity.
- options - pass nil to accept the default values.
func (*ClientFactory) NewDiagnosticSettingsCategoryClient ¶
func (c *ClientFactory) NewDiagnosticSettingsCategoryClient() *DiagnosticSettingsCategoryClient
func (*ClientFactory) NewDiagnosticSettingsClient ¶
func (c *ClientFactory) NewDiagnosticSettingsClient() *DiagnosticSettingsClient
func (*ClientFactory) NewEventCategoriesClient ¶
func (c *ClientFactory) NewEventCategoriesClient() *EventCategoriesClient
func (*ClientFactory) NewMetricDefinitionsClient ¶
func (c *ClientFactory) NewMetricDefinitionsClient() *MetricDefinitionsClient
func (*ClientFactory) NewMetricsClient ¶
func (c *ClientFactory) NewMetricsClient() *MetricsClient
func (*ClientFactory) NewOperationsClient ¶
func (c *ClientFactory) NewOperationsClient() *OperationsClient
type DiagnosticSettings ¶
type DiagnosticSettings struct {
// The resource Id for the event hub authorization rule.
EventHubAuthorizationRuleID *string `json:"eventHubAuthorizationRuleId,omitempty"`
// The name of the event hub. If none is specified, the default event hub will be selected.
EventHubName *string `json:"eventHubName,omitempty"`
// A string indicating whether the export to Log Analytics should use the default destination type, i.e. AzureDiagnostics,
// or use a destination type constructed as follows: _. Possible values are:
// Dedicated and null (null is default.)
LogAnalyticsDestinationType *string `json:"logAnalyticsDestinationType,omitempty"`
// The list of logs settings.
Logs []*LogSettings `json:"logs,omitempty"`
// The list of metric settings.
Metrics []*MetricSettings `json:"metrics,omitempty"`
// The service bus rule Id of the diagnostic setting. This is here to maintain backwards compatibility.
ServiceBusRuleID *string `json:"serviceBusRuleId,omitempty"`
// The resource ID of the storage account to which you would like to send Diagnostic Logs.
StorageAccountID *string `json:"storageAccountId,omitempty"`
// The full ARM resource ID of the Log Analytics workspace to which you would like to send Diagnostic Logs. Example:
// /subscriptions/4b9e8510-67ab-4e9a-95a9-e2f1e570ea9c/resourceGroups/insights-integration/providers/Microsoft.OperationalInsights/workspaces/viruela2
WorkspaceID *string `json:"workspaceId,omitempty"`
}
DiagnosticSettings - The diagnostic settings.
func (DiagnosticSettings) MarshalJSON ¶
func (d DiagnosticSettings) MarshalJSON() ([]byte, error)
MarshalJSON implements the json.Marshaller interface for type DiagnosticSettings.
func (*DiagnosticSettings) UnmarshalJSON ¶
func (d *DiagnosticSettings) UnmarshalJSON(data []byte) error
UnmarshalJSON implements the json.Unmarshaller interface for type DiagnosticSettings.
type DiagnosticSettingsCategory ¶
type DiagnosticSettingsCategory struct {
// The type of the diagnostic settings category.
CategoryType *CategoryType `json:"categoryType,omitempty"`
}
DiagnosticSettingsCategory - The diagnostic settings Category.
func (DiagnosticSettingsCategory) MarshalJSON ¶
func (d DiagnosticSettingsCategory) MarshalJSON() ([]byte, error)
MarshalJSON implements the json.Marshaller interface for type DiagnosticSettingsCategory.
func (*DiagnosticSettingsCategory) UnmarshalJSON ¶
func (d *DiagnosticSettingsCategory) UnmarshalJSON(data []byte) error
UnmarshalJSON implements the json.Unmarshaller interface for type DiagnosticSettingsCategory.
type DiagnosticSettingsCategoryClient ¶
type DiagnosticSettingsCategoryClient struct {
// contains filtered or unexported fields
}
DiagnosticSettingsCategoryClient contains the methods for the DiagnosticSettingsCategory group. Don't use this type directly, use NewDiagnosticSettingsCategoryClient() instead.
func NewDiagnosticSettingsCategoryClient ¶
func NewDiagnosticSettingsCategoryClient(credential azcore.TokenCredential, options *arm.ClientOptions) (*DiagnosticSettingsCategoryClient, error)
NewDiagnosticSettingsCategoryClient creates a new instance of DiagnosticSettingsCategoryClient with the specified values.
- credential - used to authorize requests. Usually a credential from azidentity.
- options - pass nil to accept the default values.
func (*DiagnosticSettingsCategoryClient) Get ¶
func (client *DiagnosticSettingsCategoryClient) Get(ctx context.Context, resourceURI string, name string, options *DiagnosticSettingsCategoryClientGetOptions) (DiagnosticSettingsCategoryClientGetResponse, error)
Get - Gets the diagnostic settings category for the specified resource. If the operation fails it returns an *azcore.ResponseError type.
Generated from API version 2017-05-01-preview
- resourceURI - The identifier of the resource.
- name - The name of the diagnostic setting.
- options - DiagnosticSettingsCategoryClientGetOptions contains the optional parameters for the DiagnosticSettingsCategoryClient.Get method.
func (*DiagnosticSettingsCategoryClient) List ¶
func (client *DiagnosticSettingsCategoryClient) List(ctx context.Context, resourceURI string, options *DiagnosticSettingsCategoryClientListOptions) (DiagnosticSettingsCategoryClientListResponse, error)
List - Lists the diagnostic settings categories for the specified resource. If the operation fails it returns an *azcore.ResponseError type.
Generated from API version 2017-05-01-preview
- resourceURI - The identifier of the resource.
- options - DiagnosticSettingsCategoryClientListOptions contains the optional parameters for the DiagnosticSettingsCategoryClient.List method.
type DiagnosticSettingsCategoryClientGetOptions ¶
type DiagnosticSettingsCategoryClientGetOptions struct {
}
DiagnosticSettingsCategoryClientGetOptions contains the optional parameters for the DiagnosticSettingsCategoryClient.Get method.
type DiagnosticSettingsCategoryClientGetResponse ¶
type DiagnosticSettingsCategoryClientGetResponse struct {
DiagnosticSettingsCategoryResource
}
DiagnosticSettingsCategoryClientGetResponse contains the response from method DiagnosticSettingsCategoryClient.Get.
type DiagnosticSettingsCategoryClientListOptions ¶
type DiagnosticSettingsCategoryClientListOptions struct {
}
DiagnosticSettingsCategoryClientListOptions contains the optional parameters for the DiagnosticSettingsCategoryClient.List method.
type DiagnosticSettingsCategoryClientListResponse ¶
type DiagnosticSettingsCategoryClientListResponse struct {
DiagnosticSettingsCategoryResourceCollection
}
DiagnosticSettingsCategoryClientListResponse contains the response from method DiagnosticSettingsCategoryClient.List.
type DiagnosticSettingsCategoryResource ¶
type DiagnosticSettingsCategoryResource struct {
// The properties of a Diagnostic Settings Category.
Properties *DiagnosticSettingsCategory `json:"properties,omitempty"`
// READ-ONLY; Azure resource Id
ID *string `json:"id,omitempty" azure:"ro"`
// READ-ONLY; Azure resource name
Name *string `json:"name,omitempty" azure:"ro"`
// READ-ONLY; Azure resource type
Type *string `json:"type,omitempty" azure:"ro"`
}
DiagnosticSettingsCategoryResource - The diagnostic settings category resource.
func (DiagnosticSettingsCategoryResource) MarshalJSON ¶
func (d DiagnosticSettingsCategoryResource) MarshalJSON() ([]byte, error)
MarshalJSON implements the json.Marshaller interface for type DiagnosticSettingsCategoryResource.
func (*DiagnosticSettingsCategoryResource) UnmarshalJSON ¶
func (d *DiagnosticSettingsCategoryResource) UnmarshalJSON(data []byte) error
UnmarshalJSON implements the json.Unmarshaller interface for type DiagnosticSettingsCategoryResource.
type DiagnosticSettingsCategoryResourceCollection ¶
type DiagnosticSettingsCategoryResourceCollection struct {
// The collection of diagnostic settings category resources.
Value []*DiagnosticSettingsCategoryResource `json:"value,omitempty"`
}
DiagnosticSettingsCategoryResourceCollection - Represents a collection of diagnostic setting category resources.
func (DiagnosticSettingsCategoryResourceCollection) MarshalJSON ¶
func (d DiagnosticSettingsCategoryResourceCollection) MarshalJSON() ([]byte, error)
MarshalJSON implements the json.Marshaller interface for type DiagnosticSettingsCategoryResourceCollection.
func (*DiagnosticSettingsCategoryResourceCollection) UnmarshalJSON ¶
func (d *DiagnosticSettingsCategoryResourceCollection) UnmarshalJSON(data []byte) error
UnmarshalJSON implements the json.Unmarshaller interface for type DiagnosticSettingsCategoryResourceCollection.
type DiagnosticSettingsClient ¶
type DiagnosticSettingsClient struct {
// contains filtered or unexported fields
}
DiagnosticSettingsClient contains the methods for the DiagnosticSettings group. Don't use this type directly, use NewDiagnosticSettingsClient() instead.
func NewDiagnosticSettingsClient ¶
func NewDiagnosticSettingsClient(credential azcore.TokenCredential, options *arm.ClientOptions) (*DiagnosticSettingsClient, error)
NewDiagnosticSettingsClient creates a new instance of DiagnosticSettingsClient with the specified values.
- credential - used to authorize requests. Usually a credential from azidentity.
- options - pass nil to accept the default values.
func (*DiagnosticSettingsClient) CreateOrUpdate ¶
func (client *DiagnosticSettingsClient) CreateOrUpdate(ctx context.Context, resourceURI string, name string, parameters DiagnosticSettingsResource, options *DiagnosticSettingsClientCreateOrUpdateOptions) (DiagnosticSettingsClientCreateOrUpdateResponse, error)
CreateOrUpdate - Creates or updates diagnostic settings for the specified resource. If the operation fails it returns an *azcore.ResponseError type.
Generated from API version 2017-05-01-preview
- resourceURI - The identifier of the resource.
- name - The name of the diagnostic setting.
- parameters - Parameters supplied to the operation.
- options - DiagnosticSettingsClientCreateOrUpdateOptions contains the optional parameters for the DiagnosticSettingsClient.CreateOrUpdate method.
func (*DiagnosticSettingsClient) Delete ¶
func (client *DiagnosticSettingsClient) Delete(ctx context.Context, resourceURI string, name string, options *DiagnosticSettingsClientDeleteOptions) (DiagnosticSettingsClientDeleteResponse, error)
Delete - Deletes existing diagnostic settings for the specified resource. If the operation fails it returns an *azcore.ResponseError type.
Generated from API version 2017-05-01-preview
- resourceURI - The identifier of the resource.
- name - The name of the diagnostic setting.
- options - DiagnosticSettingsClientDeleteOptions contains the optional parameters for the DiagnosticSettingsClient.Delete method.
func (*DiagnosticSettingsClient) Get ¶
func (client *DiagnosticSettingsClient) Get(ctx context.Context, resourceURI string, name string, options *DiagnosticSettingsClientGetOptions) (DiagnosticSettingsClientGetResponse, error)
Get - Gets the active diagnostic settings for the specified resource. If the operation fails it returns an *azcore.ResponseError type.
Generated from API version 2017-05-01-preview
- resourceURI - The identifier of the resource.
- name - The name of the diagnostic setting.
- options - DiagnosticSettingsClientGetOptions contains the optional parameters for the DiagnosticSettingsClient.Get method.
func (*DiagnosticSettingsClient) List ¶
func (client *DiagnosticSettingsClient) List(ctx context.Context, resourceURI string, options *DiagnosticSettingsClientListOptions) (DiagnosticSettingsClientListResponse, error)
List - Gets the active diagnostic settings list for the specified resource. If the operation fails it returns an *azcore.ResponseError type.
Generated from API version 2017-05-01-preview
- resourceURI - The identifier of the resource.
- options - DiagnosticSettingsClientListOptions contains the optional parameters for the DiagnosticSettingsClient.List method.
type DiagnosticSettingsClientCreateOrUpdateOptions ¶
type DiagnosticSettingsClientCreateOrUpdateOptions struct {
}
DiagnosticSettingsClientCreateOrUpdateOptions contains the optional parameters for the DiagnosticSettingsClient.CreateOrUpdate method.
type DiagnosticSettingsClientCreateOrUpdateResponse ¶
type DiagnosticSettingsClientCreateOrUpdateResponse struct {
DiagnosticSettingsResource
}
DiagnosticSettingsClientCreateOrUpdateResponse contains the response from method DiagnosticSettingsClient.CreateOrUpdate.
type DiagnosticSettingsClientDeleteOptions ¶
type DiagnosticSettingsClientDeleteOptions struct {
}
DiagnosticSettingsClientDeleteOptions contains the optional parameters for the DiagnosticSettingsClient.Delete method.
type DiagnosticSettingsClientDeleteResponse ¶
type DiagnosticSettingsClientDeleteResponse struct {
}
DiagnosticSettingsClientDeleteResponse contains the response from method DiagnosticSettingsClient.Delete.
type DiagnosticSettingsClientGetOptions ¶
type DiagnosticSettingsClientGetOptions struct {
}
DiagnosticSettingsClientGetOptions contains the optional parameters for the DiagnosticSettingsClient.Get method.
type DiagnosticSettingsClientGetResponse ¶
type DiagnosticSettingsClientGetResponse struct {
DiagnosticSettingsResource
}
DiagnosticSettingsClientGetResponse contains the response from method DiagnosticSettingsClient.Get.
type DiagnosticSettingsClientListOptions ¶
type DiagnosticSettingsClientListOptions struct {
}
DiagnosticSettingsClientListOptions contains the optional parameters for the DiagnosticSettingsClient.List method.
type DiagnosticSettingsClientListResponse ¶
type DiagnosticSettingsClientListResponse struct {
DiagnosticSettingsResourceCollection
}
DiagnosticSettingsClientListResponse contains the response from method DiagnosticSettingsClient.List.
type DiagnosticSettingsResource ¶
type DiagnosticSettingsResource struct {
// Properties of a Diagnostic Settings Resource.
Properties *DiagnosticSettings `json:"properties,omitempty"`
// READ-ONLY; Azure resource Id
ID *string `json:"id,omitempty" azure:"ro"`
// READ-ONLY; Azure resource name
Name *string `json:"name,omitempty" azure:"ro"`
// READ-ONLY; Azure resource type
Type *string `json:"type,omitempty" azure:"ro"`
}
DiagnosticSettingsResource - The diagnostic setting resource.
func (DiagnosticSettingsResource) MarshalJSON ¶
func (d DiagnosticSettingsResource) MarshalJSON() ([]byte, error)
MarshalJSON implements the json.Marshaller interface for type DiagnosticSettingsResource.
func (*DiagnosticSettingsResource) UnmarshalJSON ¶
func (d *DiagnosticSettingsResource) UnmarshalJSON(data []byte) error
UnmarshalJSON implements the json.Unmarshaller interface for type DiagnosticSettingsResource.
type DiagnosticSettingsResourceCollection ¶
type DiagnosticSettingsResourceCollection struct {
// The collection of diagnostic settings resources;.
Value []*DiagnosticSettingsResource `json:"value,omitempty"`
}
DiagnosticSettingsResourceCollection - Represents a collection of alert rule resources.
func (DiagnosticSettingsResourceCollection) MarshalJSON ¶
func (d DiagnosticSettingsResourceCollection) MarshalJSON() ([]byte, error)
MarshalJSON implements the json.Marshaller interface for type DiagnosticSettingsResourceCollection.
func (*DiagnosticSettingsResourceCollection) UnmarshalJSON ¶
func (d *DiagnosticSettingsResourceCollection) UnmarshalJSON(data []byte) error
UnmarshalJSON implements the json.Unmarshaller interface for type DiagnosticSettingsResourceCollection.
type ErrorResponse ¶
type ErrorResponse struct {
// Error code
Code *string `json:"code,omitempty"`
// Error message indicating why the operation failed.
Message *string `json:"message,omitempty"`
}
ErrorResponse - Describes the format of Error response.
func (ErrorResponse) MarshalJSON ¶
func (e ErrorResponse) MarshalJSON() ([]byte, error)
MarshalJSON implements the json.Marshaller interface for type ErrorResponse.
func (*ErrorResponse) UnmarshalJSON ¶
func (e *ErrorResponse) UnmarshalJSON(data []byte) error
UnmarshalJSON implements the json.Unmarshaller interface for type ErrorResponse.
type EventCategoriesClient ¶
type EventCategoriesClient struct {
// contains filtered or unexported fields
}
EventCategoriesClient contains the methods for the EventCategories group. Don't use this type directly, use NewEventCategoriesClient() instead.
func NewEventCategoriesClient ¶
func NewEventCategoriesClient(credential azcore.TokenCredential, options *arm.ClientOptions) (*EventCategoriesClient, error)
NewEventCategoriesClient creates a new instance of EventCategoriesClient with the specified values.
- credential - used to authorize requests. Usually a credential from azidentity.
- options - pass nil to accept the default values.
func (*EventCategoriesClient) NewListPager ¶
func (client *EventCategoriesClient) NewListPager(options *EventCategoriesClientListOptions) *runtime.Pager[EventCategoriesClientListResponse]
NewListPager - Get the list of available event categories supported in the Activity Logs Service. The current list includes the following: Administrative, Security, ServiceHealth, Alert, Recommendation, Policy.
Generated from API version 2015-04-01
- options - EventCategoriesClientListOptions contains the optional parameters for the EventCategoriesClient.NewListPager method.
type EventCategoriesClientListOptions ¶
type EventCategoriesClientListOptions struct {
}
EventCategoriesClientListOptions contains the optional parameters for the EventCategoriesClient.NewListPager method.
type EventCategoriesClientListResponse ¶
type EventCategoriesClientListResponse struct {
EventCategoryCollection
}
EventCategoriesClientListResponse contains the response from method EventCategoriesClient.NewListPager.
type EventCategoryCollection ¶
type EventCategoryCollection struct {
// REQUIRED; the list that includes the Azure event categories.
Value []*LocalizableString `json:"value,omitempty"`
}
EventCategoryCollection - A collection of event categories. Currently possible values are: Administrative, Security, ServiceHealth, Alert, Recommendation, Policy.
func (EventCategoryCollection) MarshalJSON ¶
func (e EventCategoryCollection) MarshalJSON() ([]byte, error)
MarshalJSON implements the json.Marshaller interface for type EventCategoryCollection.
func (*EventCategoryCollection) UnmarshalJSON ¶
func (e *EventCategoryCollection) UnmarshalJSON(data []byte) error
UnmarshalJSON implements the json.Unmarshaller interface for type EventCategoryCollection.
type LocalizableString ¶
type LocalizableString struct {
// REQUIRED; the invariant value.
Value *string `json:"value,omitempty"`
// the locale specific value.
LocalizedValue *string `json:"localizedValue,omitempty"`
}
LocalizableString - The localizable string class.
func (LocalizableString) MarshalJSON ¶
func (l LocalizableString) MarshalJSON() ([]byte, error)
MarshalJSON implements the json.Marshaller interface for type LocalizableString.
func (*LocalizableString) UnmarshalJSON ¶
func (l *LocalizableString) UnmarshalJSON(data []byte) error
UnmarshalJSON implements the json.Unmarshaller interface for type LocalizableString.
type LogSettings ¶
type LogSettings struct {
// REQUIRED; a value indicating whether this log is enabled.
Enabled *bool `json:"enabled,omitempty"`
// Name of a Diagnostic Log category for a resource type this setting is applied to. To obtain the list of Diagnostic Log
// categories for a resource, first perform a GET diagnostic settings operation.
Category *string `json:"category,omitempty"`
// the retention policy for this log.
RetentionPolicy *RetentionPolicy `json:"retentionPolicy,omitempty"`
}
LogSettings - Part of MultiTenantDiagnosticSettings. Specifies the settings for a particular log.
func (LogSettings) MarshalJSON ¶
func (l LogSettings) MarshalJSON() ([]byte, error)
MarshalJSON implements the json.Marshaller interface for type LogSettings.
func (*LogSettings) UnmarshalJSON ¶
func (l *LogSettings) UnmarshalJSON(data []byte) error
UnmarshalJSON implements the json.Unmarshaller interface for type LogSettings.
type MetadataValue ¶
type MetadataValue struct {
// the name of the metadata.
Name *LocalizableString `json:"name,omitempty"`
// the value of the metadata.
Value *string `json:"value,omitempty"`
}
MetadataValue - Represents a metric metadata value.
func (MetadataValue) MarshalJSON ¶
func (m MetadataValue) MarshalJSON() ([]byte, error)
MarshalJSON implements the json.Marshaller interface for type MetadataValue.
func (*MetadataValue) UnmarshalJSON ¶
func (m *MetadataValue) UnmarshalJSON(data []byte) error
UnmarshalJSON implements the json.Unmarshaller interface for type MetadataValue.
type Metric ¶
type Metric struct {
// REQUIRED; the metric Id.
ID *string `json:"id,omitempty"`
// REQUIRED; the name and the display name of the metric, i.e. it is localizable string.
Name *LocalizableString `json:"name,omitempty"`
// REQUIRED; the time series returned when a data query is performed.
Timeseries []*TimeSeriesElement `json:"timeseries,omitempty"`
// REQUIRED; the resource type of the metric resource.
Type *string `json:"type,omitempty"`
// REQUIRED; The unit of the metric.
Unit *MetricUnit `json:"unit,omitempty"`
// Detailed description of this metric.
DisplayDescription *string `json:"displayDescription,omitempty"`
// 'Success' or the error details on query failures for this metric.
ErrorCode *string `json:"errorCode,omitempty"`
// Error message encountered querying this specific metric.
ErrorMessage *string `json:"errorMessage,omitempty"`
}
Metric - The result data of a query.
func (Metric) MarshalJSON ¶
MarshalJSON implements the json.Marshaller interface for type Metric.
func (*Metric) UnmarshalJSON ¶
UnmarshalJSON implements the json.Unmarshaller interface for type Metric.
type MetricAvailability ¶
type MetricAvailability struct {
// the retention period for the metric at the specified timegrain. Expressed as a duration 'PT1M', 'P1D', etc.
Retention *string `json:"retention,omitempty"`
// the time grain specifies the aggregation interval for the metric. Expressed as a duration 'PT1M', 'P1D', etc.
TimeGrain *string `json:"timeGrain,omitempty"`
}
MetricAvailability - Metric availability specifies the time grain (aggregation interval or frequency) and the retention period for that time grain.
func (MetricAvailability) MarshalJSON ¶
func (m MetricAvailability) MarshalJSON() ([]byte, error)
MarshalJSON implements the json.Marshaller interface for type MetricAvailability.
func (*MetricAvailability) UnmarshalJSON ¶
func (m *MetricAvailability) UnmarshalJSON(data []byte) error
UnmarshalJSON implements the json.Unmarshaller interface for type MetricAvailability.
type MetricClass ¶
type MetricClass string
MetricClass - The class of the metric.
const ( MetricClassAvailability MetricClass = "Availability" MetricClassErrors MetricClass = "Errors" MetricClassLatency MetricClass = "Latency" MetricClassSaturation MetricClass = "Saturation" MetricClassTransactions MetricClass = "Transactions" )
func PossibleMetricClassValues ¶
func PossibleMetricClassValues() []MetricClass
PossibleMetricClassValues returns the possible values for the MetricClass const type.
type MetricDefinition ¶
type MetricDefinition struct {
// Custom category name for this metric.
Category *string `json:"category,omitempty"`
// the name and the display name of the dimension, i.e. it is a localizable string.
Dimensions []*LocalizableString `json:"dimensions,omitempty"`
// Detailed description of this metric.
DisplayDescription *string `json:"displayDescription,omitempty"`
// the resource identifier of the metric definition.
ID *string `json:"id,omitempty"`
// Flag to indicate whether the dimension is required.
IsDimensionRequired *bool `json:"isDimensionRequired,omitempty"`
// the collection of what aggregation intervals are available to be queried.
MetricAvailabilities []*MetricAvailability `json:"metricAvailabilities,omitempty"`
// The class of the metric.
MetricClass *MetricClass `json:"metricClass,omitempty"`
// the name and the display name of the metric, i.e. it is a localizable string.
Name *LocalizableString `json:"name,omitempty"`
// the namespace the metric belongs to.
Namespace *string `json:"namespace,omitempty"`
// the primary aggregation type value defining how to use the values for display.
PrimaryAggregationType *AggregationType `json:"primaryAggregationType,omitempty"`
// the resource identifier of the resource that emitted the metric.
ResourceID *string `json:"resourceId,omitempty"`
// the collection of what aggregation types are supported.
SupportedAggregationTypes []*AggregationType `json:"supportedAggregationTypes,omitempty"`
// The unit of the metric.
Unit *MetricUnit `json:"unit,omitempty"`
}
MetricDefinition - Metric definition class specifies the metadata for a metric.
func (MetricDefinition) MarshalJSON ¶
func (m MetricDefinition) MarshalJSON() ([]byte, error)
MarshalJSON implements the json.Marshaller interface for type MetricDefinition.
func (*MetricDefinition) UnmarshalJSON ¶
func (m *MetricDefinition) UnmarshalJSON(data []byte) error
UnmarshalJSON implements the json.Unmarshaller interface for type MetricDefinition.
type MetricDefinitionCollection ¶
type MetricDefinitionCollection struct {
// REQUIRED; the values for the metric definitions.
Value []*MetricDefinition `json:"value,omitempty"`
}
MetricDefinitionCollection - Represents collection of metric definitions.
func (MetricDefinitionCollection) MarshalJSON ¶
func (m MetricDefinitionCollection) MarshalJSON() ([]byte, error)
MarshalJSON implements the json.Marshaller interface for type MetricDefinitionCollection.
func (*MetricDefinitionCollection) UnmarshalJSON ¶
func (m *MetricDefinitionCollection) UnmarshalJSON(data []byte) error
UnmarshalJSON implements the json.Unmarshaller interface for type MetricDefinitionCollection.
type MetricDefinitionsClient ¶
type MetricDefinitionsClient struct {
// contains filtered or unexported fields
}
MetricDefinitionsClient contains the methods for the MetricDefinitions group. Don't use this type directly, use NewMetricDefinitionsClient() instead.
func NewMetricDefinitionsClient ¶
func NewMetricDefinitionsClient(credential azcore.TokenCredential, options *arm.ClientOptions) (*MetricDefinitionsClient, error)
NewMetricDefinitionsClient creates a new instance of MetricDefinitionsClient with the specified values.
- credential - used to authorize requests. Usually a credential from azidentity.
- options - pass nil to accept the default values.
func (*MetricDefinitionsClient) NewListPager ¶
func (client *MetricDefinitionsClient) NewListPager(resourceURI string, options *MetricDefinitionsClientListOptions) *runtime.Pager[MetricDefinitionsClientListResponse]
NewListPager - Lists the metric definitions for the resource.
Generated from API version 2018-01-01
- resourceURI - The identifier of the resource.
- options - MetricDefinitionsClientListOptions contains the optional parameters for the MetricDefinitionsClient.NewListPager method.
type MetricDefinitionsClientListOptions ¶
type MetricDefinitionsClientListOptions struct {
// Metric namespace to query metric definitions for.
Metricnamespace *string
}
MetricDefinitionsClientListOptions contains the optional parameters for the MetricDefinitionsClient.NewListPager method.
type MetricDefinitionsClientListResponse ¶
type MetricDefinitionsClientListResponse struct {
MetricDefinitionCollection
}
MetricDefinitionsClientListResponse contains the response from method MetricDefinitionsClient.NewListPager.
type MetricSettings ¶
type MetricSettings struct {
// REQUIRED; a value indicating whether this category is enabled.
Enabled *bool `json:"enabled,omitempty"`
// Name of a Diagnostic Metric category for a resource type this setting is applied to. To obtain the list of Diagnostic metric
// categories for a resource, first perform a GET diagnostic settings
// operation.
Category *string `json:"category,omitempty"`
// the retention policy for this category.
RetentionPolicy *RetentionPolicy `json:"retentionPolicy,omitempty"`
// the timegrain of the metric in ISO8601 format.
TimeGrain *string `json:"timeGrain,omitempty"`
}
MetricSettings - Part of MultiTenantDiagnosticSettings. Specifies the settings for a particular metric.
func (MetricSettings) MarshalJSON ¶
func (m MetricSettings) MarshalJSON() ([]byte, error)
MarshalJSON implements the json.Marshaller interface for type MetricSettings.
func (*MetricSettings) UnmarshalJSON ¶
func (m *MetricSettings) UnmarshalJSON(data []byte) error
UnmarshalJSON implements the json.Unmarshaller interface for type MetricSettings.
type MetricUnit ¶
type MetricUnit string
MetricUnit - The unit of the metric.
const ( MetricUnitBitsPerSecond MetricUnit = "BitsPerSecond" MetricUnitByteSeconds MetricUnit = "ByteSeconds" MetricUnitBytes MetricUnit = "Bytes" MetricUnitBytesPerSecond MetricUnit = "BytesPerSecond" MetricUnitCores MetricUnit = "Cores" MetricUnitCount MetricUnit = "Count" MetricUnitCountPerSecond MetricUnit = "CountPerSecond" MetricUnitMilliCores MetricUnit = "MilliCores" MetricUnitMilliSeconds MetricUnit = "MilliSeconds" MetricUnitNanoCores MetricUnit = "NanoCores" MetricUnitPercent MetricUnit = "Percent" MetricUnitSeconds MetricUnit = "Seconds" MetricUnitUnspecified MetricUnit = "Unspecified" )
func PossibleMetricUnitValues ¶
func PossibleMetricUnitValues() []MetricUnit
PossibleMetricUnitValues returns the possible values for the MetricUnit const type.
type MetricValue ¶
type MetricValue struct {
// REQUIRED; the timestamp for the metric value in ISO 8601 format.
TimeStamp *time.Time `json:"timeStamp,omitempty"`
// the average value in the time range.
Average *float64 `json:"average,omitempty"`
// the number of samples in the time range. Can be used to determine the number of values that contributed to the average
// value.
Count *float64 `json:"count,omitempty"`
// the greatest value in the time range.
Maximum *float64 `json:"maximum,omitempty"`
// the least value in the time range.
Minimum *float64 `json:"minimum,omitempty"`
// the sum of all of the values in the time range.
Total *float64 `json:"total,omitempty"`
}
MetricValue - Represents a metric value.
func (MetricValue) MarshalJSON ¶
func (m MetricValue) MarshalJSON() ([]byte, error)
MarshalJSON implements the json.Marshaller interface for type MetricValue.
func (*MetricValue) UnmarshalJSON ¶
func (m *MetricValue) UnmarshalJSON(data []byte) error
UnmarshalJSON implements the json.Unmarshaller interface for type MetricValue.
type MetricsClient ¶
type MetricsClient struct {
// contains filtered or unexported fields
}
MetricsClient contains the methods for the Metrics group. Don't use this type directly, use NewMetricsClient() instead.
func NewMetricsClient ¶
func NewMetricsClient(credential azcore.TokenCredential, options *arm.ClientOptions) (*MetricsClient, error)
NewMetricsClient creates a new instance of MetricsClient with the specified values.
- credential - used to authorize requests. Usually a credential from azidentity.
- options - pass nil to accept the default values.
func (*MetricsClient) List ¶
func (client *MetricsClient) List(ctx context.Context, resourceURI string, options *MetricsClientListOptions) (MetricsClientListResponse, error)
List - Lists the metric values for a resource. If the operation fails it returns an *azcore.ResponseError type.
Generated from API version 2018-01-01
- resourceURI - The identifier of the resource.
- options - MetricsClientListOptions contains the optional parameters for the MetricsClient.List method.
type MetricsClientListOptions ¶
type MetricsClientListOptions struct {
// The list of aggregation types (comma separated) to retrieve.
Aggregation *string
// The $filter is used to reduce the set of metric data returned. Example: Metric contains metadata A, B and C. - Return all
// time series of C where A = a1 and B = b1 or b2 $filter=A eq 'a1' and B eq 'b1'
// or B eq 'b2' and C eq ” - Invalid variant: $filter=A eq 'a1' and B eq 'b1' and C eq ” or B = 'b2' This is invalid because
// the logical or operator cannot separate two different metadata names. -
// Return all time series where A = a1, B = b1 and C = c1: $filter=A eq 'a1' and B eq 'b1' and C eq 'c1' - Return all time
// series where A = a1 $filter=A eq 'a1' and B eq ” and C eq ”. Special case:
// When dimension name or dimension value uses round brackets. Eg: When dimension name is dim (test) 1 Instead of using $filter=
// "dim (test) 1 eq ” " use $filter= "dim %2528test%2529 1 eq ” " When
// dimension name is dim (test) 3 and dimension value is dim3 (test) val Instead of using $filter= "dim (test) 3 eq 'dim3
// (test) val' " use $filter= "dim %2528test%2529 3 eq 'dim3 %2528test%2529 val' "
Filter *string
// The interval (i.e. timegrain) of the query.
Interval *string
// The names of the metrics (comma separated) to retrieve. Special case: If a metricname itself has a comma in it then use
// %2 to indicate it. Eg: 'Metric,Name1' should be 'Metric%2Name1'
Metricnames *string
// Metric namespace to query metric definitions for.
Metricnamespace *string
// The aggregation to use for sorting results and the direction of the sort. Only one order can be specified. Examples: sum
// asc.
Orderby *string
// Reduces the set of data collected. The syntax allowed depends on the operation. See the operation's description for details.
ResultType *ResultType
// The timespan of the query. It is a string with the following format 'startDateTimeISO/endDateTimeISO'.
Timespan *string
// The maximum number of records to retrieve. Valid only if $filter is specified. Defaults to 10.
Top *int32
}
MetricsClientListOptions contains the optional parameters for the MetricsClient.List method.
type MetricsClientListResponse ¶
type MetricsClientListResponse struct {
Response
}
MetricsClientListResponse contains the response from method MetricsClient.List.
type Operation ¶
type Operation struct {
// Display metadata associated with the operation.
Display *OperationDisplay `json:"display,omitempty"`
// Operation name: {provider}/{resource}/{operation}
Name *string `json:"name,omitempty"`
}
Operation - Microsoft Insights API operation definition.
func (Operation) MarshalJSON ¶
MarshalJSON implements the json.Marshaller interface for type Operation.
func (*Operation) UnmarshalJSON ¶
UnmarshalJSON implements the json.Unmarshaller interface for type Operation.
type OperationDisplay ¶
type OperationDisplay struct {
// Operation type: Read, write, delete, etc.
Operation *string `json:"operation,omitempty"`
// Service provider: Microsoft.Insights
Provider *string `json:"provider,omitempty"`
// Resource on which the operation is performed: AlertRules, Autoscale, etc.
Resource *string `json:"resource,omitempty"`
}
OperationDisplay - Display metadata associated with the operation.
func (OperationDisplay) MarshalJSON ¶
func (o OperationDisplay) MarshalJSON() ([]byte, error)
MarshalJSON implements the json.Marshaller interface for type OperationDisplay.
func (*OperationDisplay) UnmarshalJSON ¶
func (o *OperationDisplay) UnmarshalJSON(data []byte) error
UnmarshalJSON implements the json.Unmarshaller interface for type OperationDisplay.
type OperationListResult ¶
type OperationListResult struct {
// URL to get the next set of operation list results if there are any.
NextLink *string `json:"nextLink,omitempty"`
// List of operations supported by the Microsoft.Insights provider.
Value []*Operation `json:"value,omitempty"`
}
OperationListResult - Result of the request to list Microsoft.Insights operations. It contains a list of operations and a URL link to get the next set of results.
func (OperationListResult) MarshalJSON ¶
func (o OperationListResult) MarshalJSON() ([]byte, error)
MarshalJSON implements the json.Marshaller interface for type OperationListResult.
func (*OperationListResult) UnmarshalJSON ¶
func (o *OperationListResult) UnmarshalJSON(data []byte) error
UnmarshalJSON implements the json.Unmarshaller interface for type OperationListResult.
type OperationsClient ¶
type OperationsClient struct {
// contains filtered or unexported fields
}
OperationsClient contains the methods for the Operations group. Don't use this type directly, use NewOperationsClient() instead.
func NewOperationsClient ¶
func NewOperationsClient(credential azcore.TokenCredential, options *arm.ClientOptions) (*OperationsClient, error)
NewOperationsClient creates a new instance of OperationsClient with the specified values.
- credential - used to authorize requests. Usually a credential from azidentity.
- options - pass nil to accept the default values.
func (*OperationsClient) List ¶
func (client *OperationsClient) List(ctx context.Context, options *OperationsClientListOptions) (OperationsClientListResponse, error)
List - Lists all of the available operations from Microsoft.Insights provider. If the operation fails it returns an *azcore.ResponseError type.
Generated from API version 2015-04-01
- options - OperationsClientListOptions contains the optional parameters for the OperationsClient.List method.
type OperationsClientListOptions ¶
type OperationsClientListOptions struct {
}
OperationsClientListOptions contains the optional parameters for the OperationsClient.List method.
type OperationsClientListResponse ¶
type OperationsClientListResponse struct {
OperationListResult
}
OperationsClientListResponse contains the response from method OperationsClient.List.
type ProxyOnlyResource ¶
type ProxyOnlyResource struct {
// READ-ONLY; Azure resource Id
ID *string `json:"id,omitempty" azure:"ro"`
// READ-ONLY; Azure resource name
Name *string `json:"name,omitempty" azure:"ro"`
// READ-ONLY; Azure resource type
Type *string `json:"type,omitempty" azure:"ro"`
}
ProxyOnlyResource - A proxy only azure resource object
func (ProxyOnlyResource) MarshalJSON ¶
func (p ProxyOnlyResource) MarshalJSON() ([]byte, error)
MarshalJSON implements the json.Marshaller interface for type ProxyOnlyResource.
func (*ProxyOnlyResource) UnmarshalJSON ¶
func (p *ProxyOnlyResource) UnmarshalJSON(data []byte) error
UnmarshalJSON implements the json.Unmarshaller interface for type ProxyOnlyResource.
type Response ¶
type Response struct {
// REQUIRED; The timespan for which the data was retrieved. Its value consists of two datetimes concatenated, separated by
// '/'. This may be adjusted in the future and returned back from what was originally
// requested.
Timespan *string `json:"timespan,omitempty"`
// REQUIRED; the value of the collection.
Value []*Metric `json:"value,omitempty"`
// The integer value representing the relative cost of the query.
Cost *int32 `json:"cost,omitempty"`
// The interval (window size) for which the metric data was returned in. This may be adjusted in the future and returned back
// from what was originally requested. This is not present if a metadata request
// was made.
Interval *string `json:"interval,omitempty"`
// The namespace of the metrics being queried
Namespace *string `json:"namespace,omitempty"`
// The region of the resource being queried for metrics.
Resourceregion *string `json:"resourceregion,omitempty"`
}
Response - The response to a metrics query.
func (Response) MarshalJSON ¶
MarshalJSON implements the json.Marshaller interface for type Response.
func (*Response) UnmarshalJSON ¶
UnmarshalJSON implements the json.Unmarshaller interface for type Response.
type ResultType ¶
type ResultType string
const ( ResultTypeData ResultType = "Data" ResultTypeMetadata ResultType = "Metadata" )
func PossibleResultTypeValues ¶
func PossibleResultTypeValues() []ResultType
PossibleResultTypeValues returns the possible values for the ResultType const type.
type RetentionPolicy ¶
type RetentionPolicy struct {
// REQUIRED; the number of days for the retention in days. A value of 0 will retain the events indefinitely.
Days *int32 `json:"days,omitempty"`
// REQUIRED; a value indicating whether the retention policy is enabled.
Enabled *bool `json:"enabled,omitempty"`
}
RetentionPolicy - Specifies the retention policy for the log.
func (RetentionPolicy) MarshalJSON ¶
func (r RetentionPolicy) MarshalJSON() ([]byte, error)
MarshalJSON implements the json.Marshaller interface for type RetentionPolicy.
func (*RetentionPolicy) UnmarshalJSON ¶
func (r *RetentionPolicy) UnmarshalJSON(data []byte) error
UnmarshalJSON implements the json.Unmarshaller interface for type RetentionPolicy.
type TimeSeriesElement ¶
type TimeSeriesElement struct {
// An array of data points representing the metric values. This is only returned if a result type of data is specified.
Data []*MetricValue `json:"data,omitempty"`
// the metadata values returned if $filter was specified in the call.
Metadatavalues []*MetadataValue `json:"metadatavalues,omitempty"`
}
TimeSeriesElement - A time series result type. The discriminator value is always TimeSeries in this case.
func (TimeSeriesElement) MarshalJSON ¶
func (t TimeSeriesElement) MarshalJSON() ([]byte, error)
MarshalJSON implements the json.Marshaller interface for type TimeSeriesElement.
func (*TimeSeriesElement) UnmarshalJSON ¶
func (t *TimeSeriesElement) UnmarshalJSON(data []byte) error
UnmarshalJSON implements the json.Unmarshaller interface for type TimeSeriesElement.