Documentation
¶
Index ¶
- type AccountsServer
- type AccountsServerTransport
- type FirewallRulesServer
- type FirewallRulesServerTransport
- type LocationsServer
- type LocationsServerTransport
- type OperationsServer
- type OperationsServerTransport
- type ServerFactory
- type ServerFactoryTransport
- type TrustedIDProvidersServer
- type TrustedIDProvidersServerTransport
- type VirtualNetworkRulesServer
- type VirtualNetworkRulesServerTransport
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AccountsServer ¶
type AccountsServer struct {
// CheckNameAvailability is the fake for method AccountsClient.CheckNameAvailability
// HTTP status codes to indicate success: http.StatusOK
CheckNameAvailability func(ctx context.Context, location string, parameters armdatalakestore.CheckNameAvailabilityParameters, options *armdatalakestore.AccountsClientCheckNameAvailabilityOptions) (resp azfake.Responder[armdatalakestore.AccountsClientCheckNameAvailabilityResponse], errResp azfake.ErrorResponder)
// BeginCreate is the fake for method AccountsClient.BeginCreate
// HTTP status codes to indicate success: http.StatusOK, http.StatusCreated
BeginCreate func(ctx context.Context, resourceGroupName string, accountName string, parameters armdatalakestore.CreateDataLakeStoreAccountParameters, options *armdatalakestore.AccountsClientBeginCreateOptions) (resp azfake.PollerResponder[armdatalakestore.AccountsClientCreateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method AccountsClient.BeginDelete
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, resourceGroupName string, accountName string, options *armdatalakestore.AccountsClientBeginDeleteOptions) (resp azfake.PollerResponder[armdatalakestore.AccountsClientDeleteResponse], errResp azfake.ErrorResponder)
// EnableKeyVault is the fake for method AccountsClient.EnableKeyVault
// HTTP status codes to indicate success: http.StatusOK
EnableKeyVault func(ctx context.Context, resourceGroupName string, accountName string, options *armdatalakestore.AccountsClientEnableKeyVaultOptions) (resp azfake.Responder[armdatalakestore.AccountsClientEnableKeyVaultResponse], errResp azfake.ErrorResponder)
// Get is the fake for method AccountsClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, accountName string, options *armdatalakestore.AccountsClientGetOptions) (resp azfake.Responder[armdatalakestore.AccountsClientGetResponse], errResp azfake.ErrorResponder)
// NewListPager is the fake for method AccountsClient.NewListPager
// HTTP status codes to indicate success: http.StatusOK
NewListPager func(options *armdatalakestore.AccountsClientListOptions) (resp azfake.PagerResponder[armdatalakestore.AccountsClientListResponse])
// NewListByResourceGroupPager is the fake for method AccountsClient.NewListByResourceGroupPager
// HTTP status codes to indicate success: http.StatusOK
NewListByResourceGroupPager func(resourceGroupName string, options *armdatalakestore.AccountsClientListByResourceGroupOptions) (resp azfake.PagerResponder[armdatalakestore.AccountsClientListByResourceGroupResponse])
// BeginUpdate is the fake for method AccountsClient.BeginUpdate
// HTTP status codes to indicate success: http.StatusOK, http.StatusCreated, http.StatusAccepted
BeginUpdate func(ctx context.Context, resourceGroupName string, accountName string, parameters armdatalakestore.UpdateDataLakeStoreAccountParameters, options *armdatalakestore.AccountsClientBeginUpdateOptions) (resp azfake.PollerResponder[armdatalakestore.AccountsClientUpdateResponse], errResp azfake.ErrorResponder)
}
AccountsServer is a fake server for instances of the armdatalakestore.AccountsClient type.
type AccountsServerTransport ¶
type AccountsServerTransport struct {
// contains filtered or unexported fields
}
AccountsServerTransport connects instances of armdatalakestore.AccountsClient to instances of AccountsServer. Don't use this type directly, use NewAccountsServerTransport instead.
func NewAccountsServerTransport ¶
func NewAccountsServerTransport(srv *AccountsServer) *AccountsServerTransport
NewAccountsServerTransport creates a new instance of AccountsServerTransport with the provided implementation. The returned AccountsServerTransport instance is connected to an instance of armdatalakestore.AccountsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type FirewallRulesServer ¶
type FirewallRulesServer struct {
// CreateOrUpdate is the fake for method FirewallRulesClient.CreateOrUpdate
// HTTP status codes to indicate success: http.StatusOK
CreateOrUpdate func(ctx context.Context, resourceGroupName string, accountName string, firewallRuleName string, parameters armdatalakestore.CreateOrUpdateFirewallRuleParameters, options *armdatalakestore.FirewallRulesClientCreateOrUpdateOptions) (resp azfake.Responder[armdatalakestore.FirewallRulesClientCreateOrUpdateResponse], errResp azfake.ErrorResponder)
// Delete is the fake for method FirewallRulesClient.Delete
// HTTP status codes to indicate success: http.StatusOK, http.StatusNoContent
Delete func(ctx context.Context, resourceGroupName string, accountName string, firewallRuleName string, options *armdatalakestore.FirewallRulesClientDeleteOptions) (resp azfake.Responder[armdatalakestore.FirewallRulesClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method FirewallRulesClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, accountName string, firewallRuleName string, options *armdatalakestore.FirewallRulesClientGetOptions) (resp azfake.Responder[armdatalakestore.FirewallRulesClientGetResponse], errResp azfake.ErrorResponder)
// NewListByAccountPager is the fake for method FirewallRulesClient.NewListByAccountPager
// HTTP status codes to indicate success: http.StatusOK
NewListByAccountPager func(resourceGroupName string, accountName string, options *armdatalakestore.FirewallRulesClientListByAccountOptions) (resp azfake.PagerResponder[armdatalakestore.FirewallRulesClientListByAccountResponse])
// Update is the fake for method FirewallRulesClient.Update
// HTTP status codes to indicate success: http.StatusOK
Update func(ctx context.Context, resourceGroupName string, accountName string, firewallRuleName string, options *armdatalakestore.FirewallRulesClientUpdateOptions) (resp azfake.Responder[armdatalakestore.FirewallRulesClientUpdateResponse], errResp azfake.ErrorResponder)
}
FirewallRulesServer is a fake server for instances of the armdatalakestore.FirewallRulesClient type.
type FirewallRulesServerTransport ¶
type FirewallRulesServerTransport struct {
// contains filtered or unexported fields
}
FirewallRulesServerTransport connects instances of armdatalakestore.FirewallRulesClient to instances of FirewallRulesServer. Don't use this type directly, use NewFirewallRulesServerTransport instead.
func NewFirewallRulesServerTransport ¶
func NewFirewallRulesServerTransport(srv *FirewallRulesServer) *FirewallRulesServerTransport
NewFirewallRulesServerTransport creates a new instance of FirewallRulesServerTransport with the provided implementation. The returned FirewallRulesServerTransport instance is connected to an instance of armdatalakestore.FirewallRulesClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type LocationsServer ¶
type LocationsServer struct {
// GetCapability is the fake for method LocationsClient.GetCapability
// HTTP status codes to indicate success: http.StatusOK, http.StatusNotFound
GetCapability func(ctx context.Context, location string, options *armdatalakestore.LocationsClientGetCapabilityOptions) (resp azfake.Responder[armdatalakestore.LocationsClientGetCapabilityResponse], errResp azfake.ErrorResponder)
// NewGetUsagePager is the fake for method LocationsClient.NewGetUsagePager
// HTTP status codes to indicate success: http.StatusOK
NewGetUsagePager func(location string, options *armdatalakestore.LocationsClientGetUsageOptions) (resp azfake.PagerResponder[armdatalakestore.LocationsClientGetUsageResponse])
}
LocationsServer is a fake server for instances of the armdatalakestore.LocationsClient type.
type LocationsServerTransport ¶
type LocationsServerTransport struct {
// contains filtered or unexported fields
}
LocationsServerTransport connects instances of armdatalakestore.LocationsClient to instances of LocationsServer. Don't use this type directly, use NewLocationsServerTransport instead.
func NewLocationsServerTransport ¶
func NewLocationsServerTransport(srv *LocationsServer) *LocationsServerTransport
NewLocationsServerTransport creates a new instance of LocationsServerTransport with the provided implementation. The returned LocationsServerTransport instance is connected to an instance of armdatalakestore.LocationsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type OperationsServer ¶
type OperationsServer struct {
// List is the fake for method OperationsClient.List
// HTTP status codes to indicate success: http.StatusOK
List func(ctx context.Context, options *armdatalakestore.OperationsClientListOptions) (resp azfake.Responder[armdatalakestore.OperationsClientListResponse], errResp azfake.ErrorResponder)
}
OperationsServer is a fake server for instances of the armdatalakestore.OperationsClient type.
type OperationsServerTransport ¶
type OperationsServerTransport struct {
// contains filtered or unexported fields
}
OperationsServerTransport connects instances of armdatalakestore.OperationsClient to instances of OperationsServer. Don't use this type directly, use NewOperationsServerTransport instead.
func NewOperationsServerTransport ¶
func NewOperationsServerTransport(srv *OperationsServer) *OperationsServerTransport
NewOperationsServerTransport creates a new instance of OperationsServerTransport with the provided implementation. The returned OperationsServerTransport instance is connected to an instance of armdatalakestore.OperationsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type ServerFactory ¶
type ServerFactory struct {
AccountsServer AccountsServer
FirewallRulesServer FirewallRulesServer
LocationsServer LocationsServer
OperationsServer OperationsServer
TrustedIDProvidersServer TrustedIDProvidersServer
VirtualNetworkRulesServer VirtualNetworkRulesServer
}
ServerFactory is a fake server for instances of the armdatalakestore.ClientFactory type.
type ServerFactoryTransport ¶
type ServerFactoryTransport struct {
// contains filtered or unexported fields
}
ServerFactoryTransport connects instances of armdatalakestore.ClientFactory to instances of ServerFactory. Don't use this type directly, use NewServerFactoryTransport instead.
func NewServerFactoryTransport ¶
func NewServerFactoryTransport(srv *ServerFactory) *ServerFactoryTransport
NewServerFactoryTransport creates a new instance of ServerFactoryTransport with the provided implementation. The returned ServerFactoryTransport instance is connected to an instance of armdatalakestore.ClientFactory via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type TrustedIDProvidersServer ¶
type TrustedIDProvidersServer struct {
// CreateOrUpdate is the fake for method TrustedIDProvidersClient.CreateOrUpdate
// HTTP status codes to indicate success: http.StatusOK
CreateOrUpdate func(ctx context.Context, resourceGroupName string, accountName string, trustedIDProviderName string, parameters armdatalakestore.CreateOrUpdateTrustedIDProviderParameters, options *armdatalakestore.TrustedIDProvidersClientCreateOrUpdateOptions) (resp azfake.Responder[armdatalakestore.TrustedIDProvidersClientCreateOrUpdateResponse], errResp azfake.ErrorResponder)
// Delete is the fake for method TrustedIDProvidersClient.Delete
// HTTP status codes to indicate success: http.StatusOK, http.StatusNoContent
Delete func(ctx context.Context, resourceGroupName string, accountName string, trustedIDProviderName string, options *armdatalakestore.TrustedIDProvidersClientDeleteOptions) (resp azfake.Responder[armdatalakestore.TrustedIDProvidersClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method TrustedIDProvidersClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, accountName string, trustedIDProviderName string, options *armdatalakestore.TrustedIDProvidersClientGetOptions) (resp azfake.Responder[armdatalakestore.TrustedIDProvidersClientGetResponse], errResp azfake.ErrorResponder)
// NewListByAccountPager is the fake for method TrustedIDProvidersClient.NewListByAccountPager
// HTTP status codes to indicate success: http.StatusOK
NewListByAccountPager func(resourceGroupName string, accountName string, options *armdatalakestore.TrustedIDProvidersClientListByAccountOptions) (resp azfake.PagerResponder[armdatalakestore.TrustedIDProvidersClientListByAccountResponse])
// Update is the fake for method TrustedIDProvidersClient.Update
// HTTP status codes to indicate success: http.StatusOK
Update func(ctx context.Context, resourceGroupName string, accountName string, trustedIDProviderName string, options *armdatalakestore.TrustedIDProvidersClientUpdateOptions) (resp azfake.Responder[armdatalakestore.TrustedIDProvidersClientUpdateResponse], errResp azfake.ErrorResponder)
}
TrustedIDProvidersServer is a fake server for instances of the armdatalakestore.TrustedIDProvidersClient type.
type TrustedIDProvidersServerTransport ¶
type TrustedIDProvidersServerTransport struct {
// contains filtered or unexported fields
}
TrustedIDProvidersServerTransport connects instances of armdatalakestore.TrustedIDProvidersClient to instances of TrustedIDProvidersServer. Don't use this type directly, use NewTrustedIDProvidersServerTransport instead.
func NewTrustedIDProvidersServerTransport ¶
func NewTrustedIDProvidersServerTransport(srv *TrustedIDProvidersServer) *TrustedIDProvidersServerTransport
NewTrustedIDProvidersServerTransport creates a new instance of TrustedIDProvidersServerTransport with the provided implementation. The returned TrustedIDProvidersServerTransport instance is connected to an instance of armdatalakestore.TrustedIDProvidersClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type VirtualNetworkRulesServer ¶
type VirtualNetworkRulesServer struct {
// CreateOrUpdate is the fake for method VirtualNetworkRulesClient.CreateOrUpdate
// HTTP status codes to indicate success: http.StatusOK
CreateOrUpdate func(ctx context.Context, resourceGroupName string, accountName string, virtualNetworkRuleName string, parameters armdatalakestore.CreateOrUpdateVirtualNetworkRuleParameters, options *armdatalakestore.VirtualNetworkRulesClientCreateOrUpdateOptions) (resp azfake.Responder[armdatalakestore.VirtualNetworkRulesClientCreateOrUpdateResponse], errResp azfake.ErrorResponder)
// Delete is the fake for method VirtualNetworkRulesClient.Delete
// HTTP status codes to indicate success: http.StatusOK, http.StatusNoContent
Delete func(ctx context.Context, resourceGroupName string, accountName string, virtualNetworkRuleName string, options *armdatalakestore.VirtualNetworkRulesClientDeleteOptions) (resp azfake.Responder[armdatalakestore.VirtualNetworkRulesClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method VirtualNetworkRulesClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, accountName string, virtualNetworkRuleName string, options *armdatalakestore.VirtualNetworkRulesClientGetOptions) (resp azfake.Responder[armdatalakestore.VirtualNetworkRulesClientGetResponse], errResp azfake.ErrorResponder)
// NewListByAccountPager is the fake for method VirtualNetworkRulesClient.NewListByAccountPager
// HTTP status codes to indicate success: http.StatusOK
NewListByAccountPager func(resourceGroupName string, accountName string, options *armdatalakestore.VirtualNetworkRulesClientListByAccountOptions) (resp azfake.PagerResponder[armdatalakestore.VirtualNetworkRulesClientListByAccountResponse])
// Update is the fake for method VirtualNetworkRulesClient.Update
// HTTP status codes to indicate success: http.StatusOK
Update func(ctx context.Context, resourceGroupName string, accountName string, virtualNetworkRuleName string, options *armdatalakestore.VirtualNetworkRulesClientUpdateOptions) (resp azfake.Responder[armdatalakestore.VirtualNetworkRulesClientUpdateResponse], errResp azfake.ErrorResponder)
}
VirtualNetworkRulesServer is a fake server for instances of the armdatalakestore.VirtualNetworkRulesClient type.
type VirtualNetworkRulesServerTransport ¶
type VirtualNetworkRulesServerTransport struct {
// contains filtered or unexported fields
}
VirtualNetworkRulesServerTransport connects instances of armdatalakestore.VirtualNetworkRulesClient to instances of VirtualNetworkRulesServer. Don't use this type directly, use NewVirtualNetworkRulesServerTransport instead.
func NewVirtualNetworkRulesServerTransport ¶
func NewVirtualNetworkRulesServerTransport(srv *VirtualNetworkRulesServer) *VirtualNetworkRulesServerTransport
NewVirtualNetworkRulesServerTransport creates a new instance of VirtualNetworkRulesServerTransport with the provided implementation. The returned VirtualNetworkRulesServerTransport instance is connected to an instance of armdatalakestore.VirtualNetworkRulesClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.