Documentation
¶
Index ¶
- type AccountsServer
- type AccountsServerTransport
- type InstancesServer
- type InstancesServerTransport
- type OperationsServer
- type OperationsServerTransport
- type PrivateEndpointConnectionProxiesServer
- type PrivateEndpointConnectionProxiesServerTransport
- type PrivateEndpointConnectionsServer
- type PrivateEndpointConnectionsServerTransport
- type PrivateLinkResourcesServer
- type PrivateLinkResourcesServerTransport
- type Server
- type ServerFactory
- type ServerFactoryTransport
- type ServerTransport
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AccountsServer ¶
type AccountsServer struct {
// BeginCreate is the fake for method AccountsClient.BeginCreate
// HTTP status codes to indicate success: http.StatusCreated
BeginCreate func(ctx context.Context, resourceGroupName string, accountName string, account armdeviceupdate.Account, options *armdeviceupdate.AccountsClientBeginCreateOptions) (resp azfake.PollerResponder[armdeviceupdate.AccountsClientCreateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method AccountsClient.BeginDelete
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, resourceGroupName string, accountName string, options *armdeviceupdate.AccountsClientBeginDeleteOptions) (resp azfake.PollerResponder[armdeviceupdate.AccountsClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method AccountsClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, accountName string, options *armdeviceupdate.AccountsClientGetOptions) (resp azfake.Responder[armdeviceupdate.AccountsClientGetResponse], errResp azfake.ErrorResponder)
// Head is the fake for method AccountsClient.Head
// HTTP status codes to indicate success: http.StatusOK
Head func(ctx context.Context, resourceGroupName string, accountName string, options *armdeviceupdate.AccountsClientHeadOptions) (resp azfake.Responder[armdeviceupdate.AccountsClientHeadResponse], errResp azfake.ErrorResponder)
// NewListByResourceGroupPager is the fake for method AccountsClient.NewListByResourceGroupPager
// HTTP status codes to indicate success: http.StatusOK
NewListByResourceGroupPager func(resourceGroupName string, options *armdeviceupdate.AccountsClientListByResourceGroupOptions) (resp azfake.PagerResponder[armdeviceupdate.AccountsClientListByResourceGroupResponse])
// NewListBySubscriptionPager is the fake for method AccountsClient.NewListBySubscriptionPager
// HTTP status codes to indicate success: http.StatusOK
NewListBySubscriptionPager func(options *armdeviceupdate.AccountsClientListBySubscriptionOptions) (resp azfake.PagerResponder[armdeviceupdate.AccountsClientListBySubscriptionResponse])
// BeginUpdate is the fake for method AccountsClient.BeginUpdate
// HTTP status codes to indicate success: http.StatusOK, http.StatusCreated
BeginUpdate func(ctx context.Context, resourceGroupName string, accountName string, accountUpdatePayload armdeviceupdate.AccountUpdate, options *armdeviceupdate.AccountsClientBeginUpdateOptions) (resp azfake.PollerResponder[armdeviceupdate.AccountsClientUpdateResponse], errResp azfake.ErrorResponder)
}
AccountsServer is a fake server for instances of the armdeviceupdate.AccountsClient type.
type AccountsServerTransport ¶
type AccountsServerTransport struct {
// contains filtered or unexported fields
}
AccountsServerTransport connects instances of armdeviceupdate.AccountsClient to instances of AccountsServer. Don't use this type directly, use NewAccountsServerTransport instead.
func NewAccountsServerTransport ¶
func NewAccountsServerTransport(srv *AccountsServer) *AccountsServerTransport
NewAccountsServerTransport creates a new instance of AccountsServerTransport with the provided implementation. The returned AccountsServerTransport instance is connected to an instance of armdeviceupdate.AccountsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type InstancesServer ¶
type InstancesServer struct {
// BeginCreate is the fake for method InstancesClient.BeginCreate
// HTTP status codes to indicate success: http.StatusCreated
BeginCreate func(ctx context.Context, resourceGroupName string, accountName string, instanceName string, instance armdeviceupdate.Instance, options *armdeviceupdate.InstancesClientBeginCreateOptions) (resp azfake.PollerResponder[armdeviceupdate.InstancesClientCreateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method InstancesClient.BeginDelete
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, resourceGroupName string, accountName string, instanceName string, options *armdeviceupdate.InstancesClientBeginDeleteOptions) (resp azfake.PollerResponder[armdeviceupdate.InstancesClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method InstancesClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, accountName string, instanceName string, options *armdeviceupdate.InstancesClientGetOptions) (resp azfake.Responder[armdeviceupdate.InstancesClientGetResponse], errResp azfake.ErrorResponder)
// Head is the fake for method InstancesClient.Head
// HTTP status codes to indicate success: http.StatusOK
Head func(ctx context.Context, resourceGroupName string, accountName string, instanceName string, options *armdeviceupdate.InstancesClientHeadOptions) (resp azfake.Responder[armdeviceupdate.InstancesClientHeadResponse], errResp azfake.ErrorResponder)
// NewListByAccountPager is the fake for method InstancesClient.NewListByAccountPager
// HTTP status codes to indicate success: http.StatusOK
NewListByAccountPager func(resourceGroupName string, accountName string, options *armdeviceupdate.InstancesClientListByAccountOptions) (resp azfake.PagerResponder[armdeviceupdate.InstancesClientListByAccountResponse])
// Update is the fake for method InstancesClient.Update
// HTTP status codes to indicate success: http.StatusOK
Update func(ctx context.Context, resourceGroupName string, accountName string, instanceName string, tagUpdatePayload armdeviceupdate.TagUpdate, options *armdeviceupdate.InstancesClientUpdateOptions) (resp azfake.Responder[armdeviceupdate.InstancesClientUpdateResponse], errResp azfake.ErrorResponder)
}
InstancesServer is a fake server for instances of the armdeviceupdate.InstancesClient type.
type InstancesServerTransport ¶
type InstancesServerTransport struct {
// contains filtered or unexported fields
}
InstancesServerTransport connects instances of armdeviceupdate.InstancesClient to instances of InstancesServer. Don't use this type directly, use NewInstancesServerTransport instead.
func NewInstancesServerTransport ¶
func NewInstancesServerTransport(srv *InstancesServer) *InstancesServerTransport
NewInstancesServerTransport creates a new instance of InstancesServerTransport with the provided implementation. The returned InstancesServerTransport instance is connected to an instance of armdeviceupdate.InstancesClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type OperationsServer ¶
type OperationsServer struct {
// NewListPager is the fake for method OperationsClient.NewListPager
// HTTP status codes to indicate success: http.StatusOK
NewListPager func(options *armdeviceupdate.OperationsClientListOptions) (resp azfake.PagerResponder[armdeviceupdate.OperationsClientListResponse])
}
OperationsServer is a fake server for instances of the armdeviceupdate.OperationsClient type.
type OperationsServerTransport ¶
type OperationsServerTransport struct {
// contains filtered or unexported fields
}
OperationsServerTransport connects instances of armdeviceupdate.OperationsClient to instances of OperationsServer. Don't use this type directly, use NewOperationsServerTransport instead.
func NewOperationsServerTransport ¶
func NewOperationsServerTransport(srv *OperationsServer) *OperationsServerTransport
NewOperationsServerTransport creates a new instance of OperationsServerTransport with the provided implementation. The returned OperationsServerTransport instance is connected to an instance of armdeviceupdate.OperationsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type PrivateEndpointConnectionProxiesServer ¶
type PrivateEndpointConnectionProxiesServer struct {
// BeginCreateOrUpdate is the fake for method PrivateEndpointConnectionProxiesClient.BeginCreateOrUpdate
// HTTP status codes to indicate success: http.StatusCreated
BeginCreateOrUpdate func(ctx context.Context, resourceGroupName string, accountName string, privateEndpointConnectionProxyID string, privateEndpointConnectionProxy armdeviceupdate.PrivateEndpointConnectionProxy, options *armdeviceupdate.PrivateEndpointConnectionProxiesClientBeginCreateOrUpdateOptions) (resp azfake.PollerResponder[armdeviceupdate.PrivateEndpointConnectionProxiesClientCreateOrUpdateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method PrivateEndpointConnectionProxiesClient.BeginDelete
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, resourceGroupName string, accountName string, privateEndpointConnectionProxyID string, options *armdeviceupdate.PrivateEndpointConnectionProxiesClientBeginDeleteOptions) (resp azfake.PollerResponder[armdeviceupdate.PrivateEndpointConnectionProxiesClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method PrivateEndpointConnectionProxiesClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, accountName string, privateEndpointConnectionProxyID string, options *armdeviceupdate.PrivateEndpointConnectionProxiesClientGetOptions) (resp azfake.Responder[armdeviceupdate.PrivateEndpointConnectionProxiesClientGetResponse], errResp azfake.ErrorResponder)
// NewListByAccountPager is the fake for method PrivateEndpointConnectionProxiesClient.NewListByAccountPager
// HTTP status codes to indicate success: http.StatusOK
NewListByAccountPager func(resourceGroupName string, accountName string, options *armdeviceupdate.PrivateEndpointConnectionProxiesClientListByAccountOptions) (resp azfake.PagerResponder[armdeviceupdate.PrivateEndpointConnectionProxiesClientListByAccountResponse])
// UpdatePrivateEndpointProperties is the fake for method PrivateEndpointConnectionProxiesClient.UpdatePrivateEndpointProperties
// HTTP status codes to indicate success: http.StatusOK
UpdatePrivateEndpointProperties func(ctx context.Context, resourceGroupName string, accountName string, privateEndpointConnectionProxyID string, privateEndpointUpdate armdeviceupdate.PrivateEndpointUpdate, options *armdeviceupdate.PrivateEndpointConnectionProxiesClientUpdatePrivateEndpointPropertiesOptions) (resp azfake.Responder[armdeviceupdate.PrivateEndpointConnectionProxiesClientUpdatePrivateEndpointPropertiesResponse], errResp azfake.ErrorResponder)
// Validate is the fake for method PrivateEndpointConnectionProxiesClient.Validate
// HTTP status codes to indicate success: http.StatusOK
Validate func(ctx context.Context, resourceGroupName string, accountName string, privateEndpointConnectionProxyID string, privateEndpointConnectionProxy armdeviceupdate.PrivateEndpointConnectionProxy, options *armdeviceupdate.PrivateEndpointConnectionProxiesClientValidateOptions) (resp azfake.Responder[armdeviceupdate.PrivateEndpointConnectionProxiesClientValidateResponse], errResp azfake.ErrorResponder)
}
PrivateEndpointConnectionProxiesServer is a fake server for instances of the armdeviceupdate.PrivateEndpointConnectionProxiesClient type.
type PrivateEndpointConnectionProxiesServerTransport ¶
type PrivateEndpointConnectionProxiesServerTransport struct {
// contains filtered or unexported fields
}
PrivateEndpointConnectionProxiesServerTransport connects instances of armdeviceupdate.PrivateEndpointConnectionProxiesClient to instances of PrivateEndpointConnectionProxiesServer. Don't use this type directly, use NewPrivateEndpointConnectionProxiesServerTransport instead.
func NewPrivateEndpointConnectionProxiesServerTransport ¶
func NewPrivateEndpointConnectionProxiesServerTransport(srv *PrivateEndpointConnectionProxiesServer) *PrivateEndpointConnectionProxiesServerTransport
NewPrivateEndpointConnectionProxiesServerTransport creates a new instance of PrivateEndpointConnectionProxiesServerTransport with the provided implementation. The returned PrivateEndpointConnectionProxiesServerTransport instance is connected to an instance of armdeviceupdate.PrivateEndpointConnectionProxiesClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type PrivateEndpointConnectionsServer ¶
type PrivateEndpointConnectionsServer struct {
// BeginCreateOrUpdate is the fake for method PrivateEndpointConnectionsClient.BeginCreateOrUpdate
// HTTP status codes to indicate success: http.StatusCreated
BeginCreateOrUpdate func(ctx context.Context, resourceGroupName string, accountName string, privateEndpointConnectionName string, privateEndpointConnection armdeviceupdate.PrivateEndpointConnection, options *armdeviceupdate.PrivateEndpointConnectionsClientBeginCreateOrUpdateOptions) (resp azfake.PollerResponder[armdeviceupdate.PrivateEndpointConnectionsClientCreateOrUpdateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method PrivateEndpointConnectionsClient.BeginDelete
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, resourceGroupName string, accountName string, privateEndpointConnectionName string, options *armdeviceupdate.PrivateEndpointConnectionsClientBeginDeleteOptions) (resp azfake.PollerResponder[armdeviceupdate.PrivateEndpointConnectionsClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method PrivateEndpointConnectionsClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, accountName string, privateEndpointConnectionName string, options *armdeviceupdate.PrivateEndpointConnectionsClientGetOptions) (resp azfake.Responder[armdeviceupdate.PrivateEndpointConnectionsClientGetResponse], errResp azfake.ErrorResponder)
// NewListByAccountPager is the fake for method PrivateEndpointConnectionsClient.NewListByAccountPager
// HTTP status codes to indicate success: http.StatusOK
NewListByAccountPager func(resourceGroupName string, accountName string, options *armdeviceupdate.PrivateEndpointConnectionsClientListByAccountOptions) (resp azfake.PagerResponder[armdeviceupdate.PrivateEndpointConnectionsClientListByAccountResponse])
}
PrivateEndpointConnectionsServer is a fake server for instances of the armdeviceupdate.PrivateEndpointConnectionsClient type.
type PrivateEndpointConnectionsServerTransport ¶
type PrivateEndpointConnectionsServerTransport struct {
// contains filtered or unexported fields
}
PrivateEndpointConnectionsServerTransport connects instances of armdeviceupdate.PrivateEndpointConnectionsClient to instances of PrivateEndpointConnectionsServer. Don't use this type directly, use NewPrivateEndpointConnectionsServerTransport instead.
func NewPrivateEndpointConnectionsServerTransport ¶
func NewPrivateEndpointConnectionsServerTransport(srv *PrivateEndpointConnectionsServer) *PrivateEndpointConnectionsServerTransport
NewPrivateEndpointConnectionsServerTransport creates a new instance of PrivateEndpointConnectionsServerTransport with the provided implementation. The returned PrivateEndpointConnectionsServerTransport instance is connected to an instance of armdeviceupdate.PrivateEndpointConnectionsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type PrivateLinkResourcesServer ¶
type PrivateLinkResourcesServer struct {
// Get is the fake for method PrivateLinkResourcesClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, accountName string, groupID string, options *armdeviceupdate.PrivateLinkResourcesClientGetOptions) (resp azfake.Responder[armdeviceupdate.PrivateLinkResourcesClientGetResponse], errResp azfake.ErrorResponder)
// NewListByAccountPager is the fake for method PrivateLinkResourcesClient.NewListByAccountPager
// HTTP status codes to indicate success: http.StatusOK
NewListByAccountPager func(resourceGroupName string, accountName string, options *armdeviceupdate.PrivateLinkResourcesClientListByAccountOptions) (resp azfake.PagerResponder[armdeviceupdate.PrivateLinkResourcesClientListByAccountResponse])
}
PrivateLinkResourcesServer is a fake server for instances of the armdeviceupdate.PrivateLinkResourcesClient type.
type PrivateLinkResourcesServerTransport ¶
type PrivateLinkResourcesServerTransport struct {
// contains filtered or unexported fields
}
PrivateLinkResourcesServerTransport connects instances of armdeviceupdate.PrivateLinkResourcesClient to instances of PrivateLinkResourcesServer. Don't use this type directly, use NewPrivateLinkResourcesServerTransport instead.
func NewPrivateLinkResourcesServerTransport ¶
func NewPrivateLinkResourcesServerTransport(srv *PrivateLinkResourcesServer) *PrivateLinkResourcesServerTransport
NewPrivateLinkResourcesServerTransport creates a new instance of PrivateLinkResourcesServerTransport with the provided implementation. The returned PrivateLinkResourcesServerTransport instance is connected to an instance of armdeviceupdate.PrivateLinkResourcesClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type Server ¶
type Server struct {
// CheckNameAvailability is the fake for method Client.CheckNameAvailability
// HTTP status codes to indicate success: http.StatusOK
CheckNameAvailability func(ctx context.Context, request armdeviceupdate.CheckNameAvailabilityRequest, options *armdeviceupdate.ClientCheckNameAvailabilityOptions) (resp azfake.Responder[armdeviceupdate.ClientCheckNameAvailabilityResponse], errResp azfake.ErrorResponder)
}
Server is a fake server for instances of the armdeviceupdate.Client type.
type ServerFactory ¶
type ServerFactory struct {
AccountsServer AccountsServer
Server Server
InstancesServer InstancesServer
OperationsServer OperationsServer
PrivateEndpointConnectionProxiesServer PrivateEndpointConnectionProxiesServer
PrivateEndpointConnectionsServer PrivateEndpointConnectionsServer
PrivateLinkResourcesServer PrivateLinkResourcesServer
}
ServerFactory is a fake server for instances of the armdeviceupdate.ClientFactory type.
type ServerFactoryTransport ¶
type ServerFactoryTransport struct {
// contains filtered or unexported fields
}
ServerFactoryTransport connects instances of armdeviceupdate.ClientFactory to instances of ServerFactory. Don't use this type directly, use NewServerFactoryTransport instead.
func NewServerFactoryTransport ¶
func NewServerFactoryTransport(srv *ServerFactory) *ServerFactoryTransport
NewServerFactoryTransport creates a new instance of ServerFactoryTransport with the provided implementation. The returned ServerFactoryTransport instance is connected to an instance of armdeviceupdate.ClientFactory via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type ServerTransport ¶
type ServerTransport struct {
// contains filtered or unexported fields
}
ServerTransport connects instances of armdeviceupdate.Client to instances of Server. Don't use this type directly, use NewServerTransport instead.
func NewServerTransport ¶
func NewServerTransport(srv *Server) *ServerTransport
NewServerTransport creates a new instance of ServerTransport with the provided implementation. The returned ServerTransport instance is connected to an instance of armdeviceupdate.Client via the azcore.ClientOptions.Transporter field in the client's constructor parameters.