Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MonitorsServer ¶
type MonitorsServer struct {
// BeginCreateOrUpdate is the fake for method MonitorsClient.BeginCreateOrUpdate
// HTTP status codes to indicate success: http.StatusOK, http.StatusCreated
BeginCreateOrUpdate func(ctx context.Context, resourceGroupName string, monitorName string, resource armdynatrace.MonitorResource, options *armdynatrace.MonitorsClientBeginCreateOrUpdateOptions) (resp azfake.PollerResponder[armdynatrace.MonitorsClientCreateOrUpdateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method MonitorsClient.BeginDelete
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, resourceGroupName string, monitorName string, options *armdynatrace.MonitorsClientBeginDeleteOptions) (resp azfake.PollerResponder[armdynatrace.MonitorsClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method MonitorsClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, monitorName string, options *armdynatrace.MonitorsClientGetOptions) (resp azfake.Responder[armdynatrace.MonitorsClientGetResponse], errResp azfake.ErrorResponder)
// GetMarketplaceSaaSResourceDetails is the fake for method MonitorsClient.GetMarketplaceSaaSResourceDetails
// HTTP status codes to indicate success: http.StatusOK
GetMarketplaceSaaSResourceDetails func(ctx context.Context, request armdynatrace.MarketplaceSaaSResourceDetailsRequest, options *armdynatrace.MonitorsClientGetMarketplaceSaaSResourceDetailsOptions) (resp azfake.Responder[armdynatrace.MonitorsClientGetMarketplaceSaaSResourceDetailsResponse], errResp azfake.ErrorResponder)
// GetMetricStatus is the fake for method MonitorsClient.GetMetricStatus
// HTTP status codes to indicate success: http.StatusOK
GetMetricStatus func(ctx context.Context, resourceGroupName string, monitorName string, options *armdynatrace.MonitorsClientGetMetricStatusOptions) (resp azfake.Responder[armdynatrace.MonitorsClientGetMetricStatusResponse], errResp azfake.ErrorResponder)
// GetSSODetails is the fake for method MonitorsClient.GetSSODetails
// HTTP status codes to indicate success: http.StatusOK
GetSSODetails func(ctx context.Context, resourceGroupName string, monitorName string, options *armdynatrace.MonitorsClientGetSSODetailsOptions) (resp azfake.Responder[armdynatrace.MonitorsClientGetSSODetailsResponse], errResp azfake.ErrorResponder)
// GetVMHostPayload is the fake for method MonitorsClient.GetVMHostPayload
// HTTP status codes to indicate success: http.StatusOK
GetVMHostPayload func(ctx context.Context, resourceGroupName string, monitorName string, options *armdynatrace.MonitorsClientGetVMHostPayloadOptions) (resp azfake.Responder[armdynatrace.MonitorsClientGetVMHostPayloadResponse], errResp azfake.ErrorResponder)
// NewListAppServicesPager is the fake for method MonitorsClient.NewListAppServicesPager
// HTTP status codes to indicate success: http.StatusOK
NewListAppServicesPager func(resourceGroupName string, monitorName string, options *armdynatrace.MonitorsClientListAppServicesOptions) (resp azfake.PagerResponder[armdynatrace.MonitorsClientListAppServicesResponse])
// NewListByResourceGroupPager is the fake for method MonitorsClient.NewListByResourceGroupPager
// HTTP status codes to indicate success: http.StatusOK
NewListByResourceGroupPager func(resourceGroupName string, options *armdynatrace.MonitorsClientListByResourceGroupOptions) (resp azfake.PagerResponder[armdynatrace.MonitorsClientListByResourceGroupResponse])
// NewListBySubscriptionIDPager is the fake for method MonitorsClient.NewListBySubscriptionIDPager
// HTTP status codes to indicate success: http.StatusOK
NewListBySubscriptionIDPager func(options *armdynatrace.MonitorsClientListBySubscriptionIDOptions) (resp azfake.PagerResponder[armdynatrace.MonitorsClientListBySubscriptionIDResponse])
// NewListHostsPager is the fake for method MonitorsClient.NewListHostsPager
// HTTP status codes to indicate success: http.StatusOK
NewListHostsPager func(resourceGroupName string, monitorName string, options *armdynatrace.MonitorsClientListHostsOptions) (resp azfake.PagerResponder[armdynatrace.MonitorsClientListHostsResponse])
// NewListLinkableEnvironmentsPager is the fake for method MonitorsClient.NewListLinkableEnvironmentsPager
// HTTP status codes to indicate success: http.StatusOK
NewListLinkableEnvironmentsPager func(resourceGroupName string, monitorName string, request armdynatrace.LinkableEnvironmentRequest, options *armdynatrace.MonitorsClientListLinkableEnvironmentsOptions) (resp azfake.PagerResponder[armdynatrace.MonitorsClientListLinkableEnvironmentsResponse])
// NewListMonitoredResourcesPager is the fake for method MonitorsClient.NewListMonitoredResourcesPager
// HTTP status codes to indicate success: http.StatusOK
NewListMonitoredResourcesPager func(resourceGroupName string, monitorName string, options *armdynatrace.MonitorsClientListMonitoredResourcesOptions) (resp azfake.PagerResponder[armdynatrace.MonitorsClientListMonitoredResourcesResponse])
// Update is the fake for method MonitorsClient.Update
// HTTP status codes to indicate success: http.StatusOK
Update func(ctx context.Context, resourceGroupName string, monitorName string, resource armdynatrace.MonitorResourceUpdate, options *armdynatrace.MonitorsClientUpdateOptions) (resp azfake.Responder[armdynatrace.MonitorsClientUpdateResponse], errResp azfake.ErrorResponder)
}
MonitorsServer is a fake server for instances of the armdynatrace.MonitorsClient type.
type MonitorsServerTransport ¶
type MonitorsServerTransport struct {
// contains filtered or unexported fields
}
MonitorsServerTransport connects instances of armdynatrace.MonitorsClient to instances of MonitorsServer. Don't use this type directly, use NewMonitorsServerTransport instead.
func NewMonitorsServerTransport ¶
func NewMonitorsServerTransport(srv *MonitorsServer) *MonitorsServerTransport
NewMonitorsServerTransport creates a new instance of MonitorsServerTransport with the provided implementation. The returned MonitorsServerTransport instance is connected to an instance of armdynatrace.MonitorsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type OperationsServer ¶
type OperationsServer struct {
// NewListPager is the fake for method OperationsClient.NewListPager
// HTTP status codes to indicate success: http.StatusOK
NewListPager func(options *armdynatrace.OperationsClientListOptions) (resp azfake.PagerResponder[armdynatrace.OperationsClientListResponse])
}
OperationsServer is a fake server for instances of the armdynatrace.OperationsClient type.
type OperationsServerTransport ¶
type OperationsServerTransport struct {
// contains filtered or unexported fields
}
OperationsServerTransport connects instances of armdynatrace.OperationsClient to instances of OperationsServer. Don't use this type directly, use NewOperationsServerTransport instead.
func NewOperationsServerTransport ¶
func NewOperationsServerTransport(srv *OperationsServer) *OperationsServerTransport
NewOperationsServerTransport creates a new instance of OperationsServerTransport with the provided implementation. The returned OperationsServerTransport instance is connected to an instance of armdynatrace.OperationsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type ServerFactory ¶
type ServerFactory struct {
MonitorsServer MonitorsServer
OperationsServer OperationsServer
SingleSignOnServer SingleSignOnServer
TagRulesServer TagRulesServer
}
ServerFactory is a fake server for instances of the armdynatrace.ClientFactory type.
type ServerFactoryTransport ¶
type ServerFactoryTransport struct {
// contains filtered or unexported fields
}
ServerFactoryTransport connects instances of armdynatrace.ClientFactory to instances of ServerFactory. Don't use this type directly, use NewServerFactoryTransport instead.
func NewServerFactoryTransport ¶
func NewServerFactoryTransport(srv *ServerFactory) *ServerFactoryTransport
NewServerFactoryTransport creates a new instance of ServerFactoryTransport with the provided implementation. The returned ServerFactoryTransport instance is connected to an instance of armdynatrace.ClientFactory via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type SingleSignOnServer ¶
type SingleSignOnServer struct {
// BeginCreateOrUpdate is the fake for method SingleSignOnClient.BeginCreateOrUpdate
// HTTP status codes to indicate success: http.StatusOK, http.StatusCreated
BeginCreateOrUpdate func(ctx context.Context, resourceGroupName string, monitorName string, configurationName string, resource armdynatrace.SingleSignOnResource, options *armdynatrace.SingleSignOnClientBeginCreateOrUpdateOptions) (resp azfake.PollerResponder[armdynatrace.SingleSignOnClientCreateOrUpdateResponse], errResp azfake.ErrorResponder)
// Get is the fake for method SingleSignOnClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, monitorName string, configurationName string, options *armdynatrace.SingleSignOnClientGetOptions) (resp azfake.Responder[armdynatrace.SingleSignOnClientGetResponse], errResp azfake.ErrorResponder)
// NewListPager is the fake for method SingleSignOnClient.NewListPager
// HTTP status codes to indicate success: http.StatusOK
NewListPager func(resourceGroupName string, monitorName string, options *armdynatrace.SingleSignOnClientListOptions) (resp azfake.PagerResponder[armdynatrace.SingleSignOnClientListResponse])
}
SingleSignOnServer is a fake server for instances of the armdynatrace.SingleSignOnClient type.
type SingleSignOnServerTransport ¶
type SingleSignOnServerTransport struct {
// contains filtered or unexported fields
}
SingleSignOnServerTransport connects instances of armdynatrace.SingleSignOnClient to instances of SingleSignOnServer. Don't use this type directly, use NewSingleSignOnServerTransport instead.
func NewSingleSignOnServerTransport ¶
func NewSingleSignOnServerTransport(srv *SingleSignOnServer) *SingleSignOnServerTransport
NewSingleSignOnServerTransport creates a new instance of SingleSignOnServerTransport with the provided implementation. The returned SingleSignOnServerTransport instance is connected to an instance of armdynatrace.SingleSignOnClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type TagRulesServer ¶
type TagRulesServer struct {
// BeginCreateOrUpdate is the fake for method TagRulesClient.BeginCreateOrUpdate
// HTTP status codes to indicate success: http.StatusOK, http.StatusCreated
BeginCreateOrUpdate func(ctx context.Context, resourceGroupName string, monitorName string, ruleSetName string, resource armdynatrace.TagRule, options *armdynatrace.TagRulesClientBeginCreateOrUpdateOptions) (resp azfake.PollerResponder[armdynatrace.TagRulesClientCreateOrUpdateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method TagRulesClient.BeginDelete
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, resourceGroupName string, monitorName string, ruleSetName string, options *armdynatrace.TagRulesClientBeginDeleteOptions) (resp azfake.PollerResponder[armdynatrace.TagRulesClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method TagRulesClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, monitorName string, ruleSetName string, options *armdynatrace.TagRulesClientGetOptions) (resp azfake.Responder[armdynatrace.TagRulesClientGetResponse], errResp azfake.ErrorResponder)
// NewListPager is the fake for method TagRulesClient.NewListPager
// HTTP status codes to indicate success: http.StatusOK
NewListPager func(resourceGroupName string, monitorName string, options *armdynatrace.TagRulesClientListOptions) (resp azfake.PagerResponder[armdynatrace.TagRulesClientListResponse])
}
TagRulesServer is a fake server for instances of the armdynatrace.TagRulesClient type.
type TagRulesServerTransport ¶
type TagRulesServerTransport struct {
// contains filtered or unexported fields
}
TagRulesServerTransport connects instances of armdynatrace.TagRulesClient to instances of TagRulesServer. Don't use this type directly, use NewTagRulesServerTransport instead.
func NewTagRulesServerTransport ¶
func NewTagRulesServerTransport(srv *TagRulesServer) *TagRulesServerTransport
NewTagRulesServerTransport creates a new instance of TagRulesServerTransport with the provided implementation. The returned TagRulesServerTransport instance is connected to an instance of armdynatrace.TagRulesClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.