Documentation
¶
Index ¶
- type EndpointsServer
- type EndpointsServerTransport
- type ExperimentsServer
- type ExperimentsServerTransport
- type FrontDoorsServer
- type FrontDoorsServerTransport
- type FrontendEndpointsServer
- type FrontendEndpointsServerTransport
- type ManagedRuleSetsServer
- type ManagedRuleSetsServerTransport
- type NameAvailabilityServer
- type NameAvailabilityServerTransport
- type NameAvailabilityWithSubscriptionServer
- type NameAvailabilityWithSubscriptionServerTransport
- type NetworkExperimentProfilesServer
- type NetworkExperimentProfilesServerTransport
- type PoliciesServer
- type PoliciesServerTransport
- type PreconfiguredEndpointsServer
- type PreconfiguredEndpointsServerTransport
- type ReportsServer
- type ReportsServerTransport
- type RulesEnginesServer
- type RulesEnginesServerTransport
- type ServerFactory
- type ServerFactoryTransport
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type EndpointsServer ¶
type EndpointsServer struct {
// BeginPurgeContent is the fake for method EndpointsClient.BeginPurgeContent
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginPurgeContent func(ctx context.Context, resourceGroupName string, frontDoorName string, contentFilePaths armfrontdoor.PurgeParameters, options *armfrontdoor.EndpointsClientBeginPurgeContentOptions) (resp azfake.PollerResponder[armfrontdoor.EndpointsClientPurgeContentResponse], errResp azfake.ErrorResponder)
}
EndpointsServer is a fake server for instances of the armfrontdoor.EndpointsClient type.
type EndpointsServerTransport ¶
type EndpointsServerTransport struct {
// contains filtered or unexported fields
}
EndpointsServerTransport connects instances of armfrontdoor.EndpointsClient to instances of EndpointsServer. Don't use this type directly, use NewEndpointsServerTransport instead.
func NewEndpointsServerTransport ¶
func NewEndpointsServerTransport(srv *EndpointsServer) *EndpointsServerTransport
NewEndpointsServerTransport creates a new instance of EndpointsServerTransport with the provided implementation. The returned EndpointsServerTransport instance is connected to an instance of armfrontdoor.EndpointsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type ExperimentsServer ¶
type ExperimentsServer struct {
// BeginCreateOrUpdate is the fake for method ExperimentsClient.BeginCreateOrUpdate
// HTTP status codes to indicate success: http.StatusOK, http.StatusCreated, http.StatusAccepted
BeginCreateOrUpdate func(ctx context.Context, resourceGroupName string, profileName string, experimentName string, parameters armfrontdoor.Experiment, options *armfrontdoor.ExperimentsClientBeginCreateOrUpdateOptions) (resp azfake.PollerResponder[armfrontdoor.ExperimentsClientCreateOrUpdateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method ExperimentsClient.BeginDelete
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, resourceGroupName string, profileName string, experimentName string, options *armfrontdoor.ExperimentsClientBeginDeleteOptions) (resp azfake.PollerResponder[armfrontdoor.ExperimentsClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method ExperimentsClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, profileName string, experimentName string, options *armfrontdoor.ExperimentsClientGetOptions) (resp azfake.Responder[armfrontdoor.ExperimentsClientGetResponse], errResp azfake.ErrorResponder)
// NewListByProfilePager is the fake for method ExperimentsClient.NewListByProfilePager
// HTTP status codes to indicate success: http.StatusOK
NewListByProfilePager func(resourceGroupName string, profileName string, options *armfrontdoor.ExperimentsClientListByProfileOptions) (resp azfake.PagerResponder[armfrontdoor.ExperimentsClientListByProfileResponse])
// BeginUpdate is the fake for method ExperimentsClient.BeginUpdate
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginUpdate func(ctx context.Context, resourceGroupName string, profileName string, experimentName string, parameters armfrontdoor.ExperimentUpdateModel, options *armfrontdoor.ExperimentsClientBeginUpdateOptions) (resp azfake.PollerResponder[armfrontdoor.ExperimentsClientUpdateResponse], errResp azfake.ErrorResponder)
}
ExperimentsServer is a fake server for instances of the armfrontdoor.ExperimentsClient type.
type ExperimentsServerTransport ¶
type ExperimentsServerTransport struct {
// contains filtered or unexported fields
}
ExperimentsServerTransport connects instances of armfrontdoor.ExperimentsClient to instances of ExperimentsServer. Don't use this type directly, use NewExperimentsServerTransport instead.
func NewExperimentsServerTransport ¶
func NewExperimentsServerTransport(srv *ExperimentsServer) *ExperimentsServerTransport
NewExperimentsServerTransport creates a new instance of ExperimentsServerTransport with the provided implementation. The returned ExperimentsServerTransport instance is connected to an instance of armfrontdoor.ExperimentsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type FrontDoorsServer ¶
type FrontDoorsServer struct {
// BeginCreateOrUpdate is the fake for method FrontDoorsClient.BeginCreateOrUpdate
// HTTP status codes to indicate success: http.StatusOK, http.StatusCreated, http.StatusAccepted
BeginCreateOrUpdate func(ctx context.Context, resourceGroupName string, frontDoorName string, frontDoorParameters armfrontdoor.FrontDoor, options *armfrontdoor.FrontDoorsClientBeginCreateOrUpdateOptions) (resp azfake.PollerResponder[armfrontdoor.FrontDoorsClientCreateOrUpdateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method FrontDoorsClient.BeginDelete
// HTTP status codes to indicate success: http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, resourceGroupName string, frontDoorName string, options *armfrontdoor.FrontDoorsClientBeginDeleteOptions) (resp azfake.PollerResponder[armfrontdoor.FrontDoorsClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method FrontDoorsClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, frontDoorName string, options *armfrontdoor.FrontDoorsClientGetOptions) (resp azfake.Responder[armfrontdoor.FrontDoorsClientGetResponse], errResp azfake.ErrorResponder)
// NewListPager is the fake for method FrontDoorsClient.NewListPager
// HTTP status codes to indicate success: http.StatusOK
NewListPager func(options *armfrontdoor.FrontDoorsClientListOptions) (resp azfake.PagerResponder[armfrontdoor.FrontDoorsClientListResponse])
// NewListByResourceGroupPager is the fake for method FrontDoorsClient.NewListByResourceGroupPager
// HTTP status codes to indicate success: http.StatusOK
NewListByResourceGroupPager func(resourceGroupName string, options *armfrontdoor.FrontDoorsClientListByResourceGroupOptions) (resp azfake.PagerResponder[armfrontdoor.FrontDoorsClientListByResourceGroupResponse])
// ValidateCustomDomain is the fake for method FrontDoorsClient.ValidateCustomDomain
// HTTP status codes to indicate success: http.StatusOK
ValidateCustomDomain func(ctx context.Context, resourceGroupName string, frontDoorName string, customDomainProperties armfrontdoor.ValidateCustomDomainInput, options *armfrontdoor.FrontDoorsClientValidateCustomDomainOptions) (resp azfake.Responder[armfrontdoor.FrontDoorsClientValidateCustomDomainResponse], errResp azfake.ErrorResponder)
}
FrontDoorsServer is a fake server for instances of the armfrontdoor.FrontDoorsClient type.
type FrontDoorsServerTransport ¶
type FrontDoorsServerTransport struct {
// contains filtered or unexported fields
}
FrontDoorsServerTransport connects instances of armfrontdoor.FrontDoorsClient to instances of FrontDoorsServer. Don't use this type directly, use NewFrontDoorsServerTransport instead.
func NewFrontDoorsServerTransport ¶
func NewFrontDoorsServerTransport(srv *FrontDoorsServer) *FrontDoorsServerTransport
NewFrontDoorsServerTransport creates a new instance of FrontDoorsServerTransport with the provided implementation. The returned FrontDoorsServerTransport instance is connected to an instance of armfrontdoor.FrontDoorsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type FrontendEndpointsServer ¶
type FrontendEndpointsServer struct {
// BeginDisableHTTPS is the fake for method FrontendEndpointsClient.BeginDisableHTTPS
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginDisableHTTPS func(ctx context.Context, resourceGroupName string, frontDoorName string, frontendEndpointName string, options *armfrontdoor.FrontendEndpointsClientBeginDisableHTTPSOptions) (resp azfake.PollerResponder[armfrontdoor.FrontendEndpointsClientDisableHTTPSResponse], errResp azfake.ErrorResponder)
// BeginEnableHTTPS is the fake for method FrontendEndpointsClient.BeginEnableHTTPS
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginEnableHTTPS func(ctx context.Context, resourceGroupName string, frontDoorName string, frontendEndpointName string, customHTTPSConfiguration armfrontdoor.CustomHTTPSConfiguration, options *armfrontdoor.FrontendEndpointsClientBeginEnableHTTPSOptions) (resp azfake.PollerResponder[armfrontdoor.FrontendEndpointsClientEnableHTTPSResponse], errResp azfake.ErrorResponder)
// Get is the fake for method FrontendEndpointsClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, frontDoorName string, frontendEndpointName string, options *armfrontdoor.FrontendEndpointsClientGetOptions) (resp azfake.Responder[armfrontdoor.FrontendEndpointsClientGetResponse], errResp azfake.ErrorResponder)
// NewListByFrontDoorPager is the fake for method FrontendEndpointsClient.NewListByFrontDoorPager
// HTTP status codes to indicate success: http.StatusOK
NewListByFrontDoorPager func(resourceGroupName string, frontDoorName string, options *armfrontdoor.FrontendEndpointsClientListByFrontDoorOptions) (resp azfake.PagerResponder[armfrontdoor.FrontendEndpointsClientListByFrontDoorResponse])
}
FrontendEndpointsServer is a fake server for instances of the armfrontdoor.FrontendEndpointsClient type.
type FrontendEndpointsServerTransport ¶
type FrontendEndpointsServerTransport struct {
// contains filtered or unexported fields
}
FrontendEndpointsServerTransport connects instances of armfrontdoor.FrontendEndpointsClient to instances of FrontendEndpointsServer. Don't use this type directly, use NewFrontendEndpointsServerTransport instead.
func NewFrontendEndpointsServerTransport ¶
func NewFrontendEndpointsServerTransport(srv *FrontendEndpointsServer) *FrontendEndpointsServerTransport
NewFrontendEndpointsServerTransport creates a new instance of FrontendEndpointsServerTransport with the provided implementation. The returned FrontendEndpointsServerTransport instance is connected to an instance of armfrontdoor.FrontendEndpointsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type ManagedRuleSetsServer ¶
type ManagedRuleSetsServer struct {
// NewListPager is the fake for method ManagedRuleSetsClient.NewListPager
// HTTP status codes to indicate success: http.StatusOK
NewListPager func(options *armfrontdoor.ManagedRuleSetsClientListOptions) (resp azfake.PagerResponder[armfrontdoor.ManagedRuleSetsClientListResponse])
}
ManagedRuleSetsServer is a fake server for instances of the armfrontdoor.ManagedRuleSetsClient type.
type ManagedRuleSetsServerTransport ¶
type ManagedRuleSetsServerTransport struct {
// contains filtered or unexported fields
}
ManagedRuleSetsServerTransport connects instances of armfrontdoor.ManagedRuleSetsClient to instances of ManagedRuleSetsServer. Don't use this type directly, use NewManagedRuleSetsServerTransport instead.
func NewManagedRuleSetsServerTransport ¶
func NewManagedRuleSetsServerTransport(srv *ManagedRuleSetsServer) *ManagedRuleSetsServerTransport
NewManagedRuleSetsServerTransport creates a new instance of ManagedRuleSetsServerTransport with the provided implementation. The returned ManagedRuleSetsServerTransport instance is connected to an instance of armfrontdoor.ManagedRuleSetsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type NameAvailabilityServer ¶
type NameAvailabilityServer struct {
// Check is the fake for method NameAvailabilityClient.Check
// HTTP status codes to indicate success: http.StatusOK
Check func(ctx context.Context, checkFrontDoorNameAvailabilityInput armfrontdoor.CheckNameAvailabilityInput, options *armfrontdoor.NameAvailabilityClientCheckOptions) (resp azfake.Responder[armfrontdoor.NameAvailabilityClientCheckResponse], errResp azfake.ErrorResponder)
}
NameAvailabilityServer is a fake server for instances of the armfrontdoor.NameAvailabilityClient type.
type NameAvailabilityServerTransport ¶
type NameAvailabilityServerTransport struct {
// contains filtered or unexported fields
}
NameAvailabilityServerTransport connects instances of armfrontdoor.NameAvailabilityClient to instances of NameAvailabilityServer. Don't use this type directly, use NewNameAvailabilityServerTransport instead.
func NewNameAvailabilityServerTransport ¶
func NewNameAvailabilityServerTransport(srv *NameAvailabilityServer) *NameAvailabilityServerTransport
NewNameAvailabilityServerTransport creates a new instance of NameAvailabilityServerTransport with the provided implementation. The returned NameAvailabilityServerTransport instance is connected to an instance of armfrontdoor.NameAvailabilityClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type NameAvailabilityWithSubscriptionServer ¶
type NameAvailabilityWithSubscriptionServer struct {
// Check is the fake for method NameAvailabilityWithSubscriptionClient.Check
// HTTP status codes to indicate success: http.StatusOK
Check func(ctx context.Context, checkFrontDoorNameAvailabilityInput armfrontdoor.CheckNameAvailabilityInput, options *armfrontdoor.NameAvailabilityWithSubscriptionClientCheckOptions) (resp azfake.Responder[armfrontdoor.NameAvailabilityWithSubscriptionClientCheckResponse], errResp azfake.ErrorResponder)
}
NameAvailabilityWithSubscriptionServer is a fake server for instances of the armfrontdoor.NameAvailabilityWithSubscriptionClient type.
type NameAvailabilityWithSubscriptionServerTransport ¶
type NameAvailabilityWithSubscriptionServerTransport struct {
// contains filtered or unexported fields
}
NameAvailabilityWithSubscriptionServerTransport connects instances of armfrontdoor.NameAvailabilityWithSubscriptionClient to instances of NameAvailabilityWithSubscriptionServer. Don't use this type directly, use NewNameAvailabilityWithSubscriptionServerTransport instead.
func NewNameAvailabilityWithSubscriptionServerTransport ¶
func NewNameAvailabilityWithSubscriptionServerTransport(srv *NameAvailabilityWithSubscriptionServer) *NameAvailabilityWithSubscriptionServerTransport
NewNameAvailabilityWithSubscriptionServerTransport creates a new instance of NameAvailabilityWithSubscriptionServerTransport with the provided implementation. The returned NameAvailabilityWithSubscriptionServerTransport instance is connected to an instance of armfrontdoor.NameAvailabilityWithSubscriptionClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type NetworkExperimentProfilesServer ¶
type NetworkExperimentProfilesServer struct {
// BeginCreateOrUpdate is the fake for method NetworkExperimentProfilesClient.BeginCreateOrUpdate
// HTTP status codes to indicate success: http.StatusOK, http.StatusCreated, http.StatusAccepted
BeginCreateOrUpdate func(ctx context.Context, profileName string, resourceGroupName string, parameters armfrontdoor.Profile, options *armfrontdoor.NetworkExperimentProfilesClientBeginCreateOrUpdateOptions) (resp azfake.PollerResponder[armfrontdoor.NetworkExperimentProfilesClientCreateOrUpdateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method NetworkExperimentProfilesClient.BeginDelete
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, resourceGroupName string, profileName string, options *armfrontdoor.NetworkExperimentProfilesClientBeginDeleteOptions) (resp azfake.PollerResponder[armfrontdoor.NetworkExperimentProfilesClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method NetworkExperimentProfilesClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, profileName string, options *armfrontdoor.NetworkExperimentProfilesClientGetOptions) (resp azfake.Responder[armfrontdoor.NetworkExperimentProfilesClientGetResponse], errResp azfake.ErrorResponder)
// NewListPager is the fake for method NetworkExperimentProfilesClient.NewListPager
// HTTP status codes to indicate success: http.StatusOK
NewListPager func(options *armfrontdoor.NetworkExperimentProfilesClientListOptions) (resp azfake.PagerResponder[armfrontdoor.NetworkExperimentProfilesClientListResponse])
// NewListByResourceGroupPager is the fake for method NetworkExperimentProfilesClient.NewListByResourceGroupPager
// HTTP status codes to indicate success: http.StatusOK
NewListByResourceGroupPager func(resourceGroupName string, options *armfrontdoor.NetworkExperimentProfilesClientListByResourceGroupOptions) (resp azfake.PagerResponder[armfrontdoor.NetworkExperimentProfilesClientListByResourceGroupResponse])
// BeginUpdate is the fake for method NetworkExperimentProfilesClient.BeginUpdate
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginUpdate func(ctx context.Context, resourceGroupName string, profileName string, parameters armfrontdoor.ProfileUpdateModel, options *armfrontdoor.NetworkExperimentProfilesClientBeginUpdateOptions) (resp azfake.PollerResponder[armfrontdoor.NetworkExperimentProfilesClientUpdateResponse], errResp azfake.ErrorResponder)
}
NetworkExperimentProfilesServer is a fake server for instances of the armfrontdoor.NetworkExperimentProfilesClient type.
type NetworkExperimentProfilesServerTransport ¶
type NetworkExperimentProfilesServerTransport struct {
// contains filtered or unexported fields
}
NetworkExperimentProfilesServerTransport connects instances of armfrontdoor.NetworkExperimentProfilesClient to instances of NetworkExperimentProfilesServer. Don't use this type directly, use NewNetworkExperimentProfilesServerTransport instead.
func NewNetworkExperimentProfilesServerTransport ¶
func NewNetworkExperimentProfilesServerTransport(srv *NetworkExperimentProfilesServer) *NetworkExperimentProfilesServerTransport
NewNetworkExperimentProfilesServerTransport creates a new instance of NetworkExperimentProfilesServerTransport with the provided implementation. The returned NetworkExperimentProfilesServerTransport instance is connected to an instance of armfrontdoor.NetworkExperimentProfilesClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type PoliciesServer ¶
type PoliciesServer struct {
// BeginCreateOrUpdate is the fake for method PoliciesClient.BeginCreateOrUpdate
// HTTP status codes to indicate success: http.StatusOK, http.StatusCreated, http.StatusAccepted
BeginCreateOrUpdate func(ctx context.Context, resourceGroupName string, policyName string, parameters armfrontdoor.WebApplicationFirewallPolicy, options *armfrontdoor.PoliciesClientBeginCreateOrUpdateOptions) (resp azfake.PollerResponder[armfrontdoor.PoliciesClientCreateOrUpdateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method PoliciesClient.BeginDelete
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, resourceGroupName string, policyName string, options *armfrontdoor.PoliciesClientBeginDeleteOptions) (resp azfake.PollerResponder[armfrontdoor.PoliciesClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method PoliciesClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, policyName string, options *armfrontdoor.PoliciesClientGetOptions) (resp azfake.Responder[armfrontdoor.PoliciesClientGetResponse], errResp azfake.ErrorResponder)
// NewListPager is the fake for method PoliciesClient.NewListPager
// HTTP status codes to indicate success: http.StatusOK
NewListPager func(resourceGroupName string, options *armfrontdoor.PoliciesClientListOptions) (resp azfake.PagerResponder[armfrontdoor.PoliciesClientListResponse])
// NewListBySubscriptionPager is the fake for method PoliciesClient.NewListBySubscriptionPager
// HTTP status codes to indicate success: http.StatusOK
NewListBySubscriptionPager func(options *armfrontdoor.PoliciesClientListBySubscriptionOptions) (resp azfake.PagerResponder[armfrontdoor.PoliciesClientListBySubscriptionResponse])
// BeginUpdate is the fake for method PoliciesClient.BeginUpdate
// HTTP status codes to indicate success: http.StatusOK
BeginUpdate func(ctx context.Context, resourceGroupName string, policyName string, parameters armfrontdoor.TagsObject, options *armfrontdoor.PoliciesClientBeginUpdateOptions) (resp azfake.PollerResponder[armfrontdoor.PoliciesClientUpdateResponse], errResp azfake.ErrorResponder)
}
PoliciesServer is a fake server for instances of the armfrontdoor.PoliciesClient type.
type PoliciesServerTransport ¶
type PoliciesServerTransport struct {
// contains filtered or unexported fields
}
PoliciesServerTransport connects instances of armfrontdoor.PoliciesClient to instances of PoliciesServer. Don't use this type directly, use NewPoliciesServerTransport instead.
func NewPoliciesServerTransport ¶
func NewPoliciesServerTransport(srv *PoliciesServer) *PoliciesServerTransport
NewPoliciesServerTransport creates a new instance of PoliciesServerTransport with the provided implementation. The returned PoliciesServerTransport instance is connected to an instance of armfrontdoor.PoliciesClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type PreconfiguredEndpointsServer ¶
type PreconfiguredEndpointsServer struct {
// NewListPager is the fake for method PreconfiguredEndpointsClient.NewListPager
// HTTP status codes to indicate success: http.StatusOK
NewListPager func(resourceGroupName string, profileName string, options *armfrontdoor.PreconfiguredEndpointsClientListOptions) (resp azfake.PagerResponder[armfrontdoor.PreconfiguredEndpointsClientListResponse])
}
PreconfiguredEndpointsServer is a fake server for instances of the armfrontdoor.PreconfiguredEndpointsClient type.
type PreconfiguredEndpointsServerTransport ¶
type PreconfiguredEndpointsServerTransport struct {
// contains filtered or unexported fields
}
PreconfiguredEndpointsServerTransport connects instances of armfrontdoor.PreconfiguredEndpointsClient to instances of PreconfiguredEndpointsServer. Don't use this type directly, use NewPreconfiguredEndpointsServerTransport instead.
func NewPreconfiguredEndpointsServerTransport ¶
func NewPreconfiguredEndpointsServerTransport(srv *PreconfiguredEndpointsServer) *PreconfiguredEndpointsServerTransport
NewPreconfiguredEndpointsServerTransport creates a new instance of PreconfiguredEndpointsServerTransport with the provided implementation. The returned PreconfiguredEndpointsServerTransport instance is connected to an instance of armfrontdoor.PreconfiguredEndpointsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type ReportsServer ¶
type ReportsServer struct {
// GetLatencyScorecards is the fake for method ReportsClient.GetLatencyScorecards
// HTTP status codes to indicate success: http.StatusOK
GetLatencyScorecards func(ctx context.Context, resourceGroupName string, profileName string, experimentName string, aggregationInterval armfrontdoor.LatencyScorecardAggregationInterval, options *armfrontdoor.ReportsClientGetLatencyScorecardsOptions) (resp azfake.Responder[armfrontdoor.ReportsClientGetLatencyScorecardsResponse], errResp azfake.ErrorResponder)
// GetTimeseries is the fake for method ReportsClient.GetTimeseries
// HTTP status codes to indicate success: http.StatusOK
GetTimeseries func(ctx context.Context, resourceGroupName string, profileName string, experimentName string, startDateTimeUTC time.Time, endDateTimeUTC time.Time, aggregationInterval armfrontdoor.TimeseriesAggregationInterval, timeseriesType armfrontdoor.TimeseriesType, options *armfrontdoor.ReportsClientGetTimeseriesOptions) (resp azfake.Responder[armfrontdoor.ReportsClientGetTimeseriesResponse], errResp azfake.ErrorResponder)
}
ReportsServer is a fake server for instances of the armfrontdoor.ReportsClient type.
type ReportsServerTransport ¶
type ReportsServerTransport struct {
// contains filtered or unexported fields
}
ReportsServerTransport connects instances of armfrontdoor.ReportsClient to instances of ReportsServer. Don't use this type directly, use NewReportsServerTransport instead.
func NewReportsServerTransport ¶
func NewReportsServerTransport(srv *ReportsServer) *ReportsServerTransport
NewReportsServerTransport creates a new instance of ReportsServerTransport with the provided implementation. The returned ReportsServerTransport instance is connected to an instance of armfrontdoor.ReportsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type RulesEnginesServer ¶
type RulesEnginesServer struct {
// BeginCreateOrUpdate is the fake for method RulesEnginesClient.BeginCreateOrUpdate
// HTTP status codes to indicate success: http.StatusOK, http.StatusCreated, http.StatusAccepted
BeginCreateOrUpdate func(ctx context.Context, resourceGroupName string, frontDoorName string, rulesEngineName string, rulesEngineParameters armfrontdoor.RulesEngine, options *armfrontdoor.RulesEnginesClientBeginCreateOrUpdateOptions) (resp azfake.PollerResponder[armfrontdoor.RulesEnginesClientCreateOrUpdateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method RulesEnginesClient.BeginDelete
// HTTP status codes to indicate success: http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, resourceGroupName string, frontDoorName string, rulesEngineName string, options *armfrontdoor.RulesEnginesClientBeginDeleteOptions) (resp azfake.PollerResponder[armfrontdoor.RulesEnginesClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method RulesEnginesClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, frontDoorName string, rulesEngineName string, options *armfrontdoor.RulesEnginesClientGetOptions) (resp azfake.Responder[armfrontdoor.RulesEnginesClientGetResponse], errResp azfake.ErrorResponder)
// NewListByFrontDoorPager is the fake for method RulesEnginesClient.NewListByFrontDoorPager
// HTTP status codes to indicate success: http.StatusOK
NewListByFrontDoorPager func(resourceGroupName string, frontDoorName string, options *armfrontdoor.RulesEnginesClientListByFrontDoorOptions) (resp azfake.PagerResponder[armfrontdoor.RulesEnginesClientListByFrontDoorResponse])
}
RulesEnginesServer is a fake server for instances of the armfrontdoor.RulesEnginesClient type.
type RulesEnginesServerTransport ¶
type RulesEnginesServerTransport struct {
// contains filtered or unexported fields
}
RulesEnginesServerTransport connects instances of armfrontdoor.RulesEnginesClient to instances of RulesEnginesServer. Don't use this type directly, use NewRulesEnginesServerTransport instead.
func NewRulesEnginesServerTransport ¶
func NewRulesEnginesServerTransport(srv *RulesEnginesServer) *RulesEnginesServerTransport
NewRulesEnginesServerTransport creates a new instance of RulesEnginesServerTransport with the provided implementation. The returned RulesEnginesServerTransport instance is connected to an instance of armfrontdoor.RulesEnginesClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type ServerFactory ¶
type ServerFactory struct {
EndpointsServer EndpointsServer
ExperimentsServer ExperimentsServer
FrontDoorsServer FrontDoorsServer
FrontendEndpointsServer FrontendEndpointsServer
ManagedRuleSetsServer ManagedRuleSetsServer
NameAvailabilityServer NameAvailabilityServer
NameAvailabilityWithSubscriptionServer NameAvailabilityWithSubscriptionServer
NetworkExperimentProfilesServer NetworkExperimentProfilesServer
PoliciesServer PoliciesServer
PreconfiguredEndpointsServer PreconfiguredEndpointsServer
ReportsServer ReportsServer
RulesEnginesServer RulesEnginesServer
}
ServerFactory is a fake server for instances of the armfrontdoor.ClientFactory type.
type ServerFactoryTransport ¶
type ServerFactoryTransport struct {
// contains filtered or unexported fields
}
ServerFactoryTransport connects instances of armfrontdoor.ClientFactory to instances of ServerFactory. Don't use this type directly, use NewServerFactoryTransport instead.
func NewServerFactoryTransport ¶
func NewServerFactoryTransport(srv *ServerFactory) *ServerFactoryTransport
NewServerFactoryTransport creates a new instance of ServerFactoryTransport with the provided implementation. The returned ServerFactoryTransport instance is connected to an instance of armfrontdoor.ClientFactory via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
Source Files
¶
- endpoints_server.go
- experiments_server.go
- frontdoors_server.go
- frontendendpoints_server.go
- internal.go
- managedrulesets_server.go
- nameavailability_server.go
- nameavailabilitywithsubscription_server.go
- networkexperimentprofiles_server.go
- policies_server.go
- preconfiguredendpoints_server.go
- reports_server.go
- rulesengines_server.go
- server_factory.go
- time_rfc3339.go