Documentation
¶
Index ¶
- type ExtensionMetadataServer
- type ExtensionMetadataServerTransport
- type GatewaysServer
- type GatewaysServerTransport
- type LicenseProfilesServer
- type LicenseProfilesServerTransport
- type LicensesServer
- type LicensesServerTransport
- type MachineExtensionsServer
- type MachineExtensionsServerTransport
- type MachineRunCommandsServer
- type MachineRunCommandsServerTransport
- type MachinesServer
- type MachinesServerTransport
- type ManagementServer
- type ManagementServerTransport
- type NetworkProfileServer
- type NetworkProfileServerTransport
- type NetworkSecurityPerimeterConfigurationsServer
- type NetworkSecurityPerimeterConfigurationsServerTransport
- type OperationsServer
- type OperationsServerTransport
- type PrivateEndpointConnectionsServer
- type PrivateEndpointConnectionsServerTransport
- type PrivateLinkResourcesServer
- type PrivateLinkResourcesServerTransport
- type PrivateLinkScopesServer
- type PrivateLinkScopesServerTransport
- type ServerFactory
- type ServerFactoryTransport
- type SettingsServer
- type SettingsServerTransport
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ExtensionMetadataServer ¶
type ExtensionMetadataServer struct {
// Get is the fake for method ExtensionMetadataClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, location string, publisher string, extensionType string, version string, options *armhybridcompute.ExtensionMetadataClientGetOptions) (resp azfake.Responder[armhybridcompute.ExtensionMetadataClientGetResponse], errResp azfake.ErrorResponder)
// NewListPager is the fake for method ExtensionMetadataClient.NewListPager
// HTTP status codes to indicate success: http.StatusOK
NewListPager func(location string, publisher string, extensionType string, options *armhybridcompute.ExtensionMetadataClientListOptions) (resp azfake.PagerResponder[armhybridcompute.ExtensionMetadataClientListResponse])
}
ExtensionMetadataServer is a fake server for instances of the armhybridcompute.ExtensionMetadataClient type.
type ExtensionMetadataServerTransport ¶
type ExtensionMetadataServerTransport struct {
// contains filtered or unexported fields
}
ExtensionMetadataServerTransport connects instances of armhybridcompute.ExtensionMetadataClient to instances of ExtensionMetadataServer. Don't use this type directly, use NewExtensionMetadataServerTransport instead.
func NewExtensionMetadataServerTransport ¶
func NewExtensionMetadataServerTransport(srv *ExtensionMetadataServer) *ExtensionMetadataServerTransport
NewExtensionMetadataServerTransport creates a new instance of ExtensionMetadataServerTransport with the provided implementation. The returned ExtensionMetadataServerTransport instance is connected to an instance of armhybridcompute.ExtensionMetadataClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type GatewaysServer ¶
type GatewaysServer struct {
// BeginCreateOrUpdate is the fake for method GatewaysClient.BeginCreateOrUpdate
// HTTP status codes to indicate success: http.StatusOK, http.StatusCreated
BeginCreateOrUpdate func(ctx context.Context, resourceGroupName string, gatewayName string, parameters armhybridcompute.Gateway, options *armhybridcompute.GatewaysClientBeginCreateOrUpdateOptions) (resp azfake.PollerResponder[armhybridcompute.GatewaysClientCreateOrUpdateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method GatewaysClient.BeginDelete
// HTTP status codes to indicate success: http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, resourceGroupName string, gatewayName string, options *armhybridcompute.GatewaysClientBeginDeleteOptions) (resp azfake.PollerResponder[armhybridcompute.GatewaysClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method GatewaysClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, gatewayName string, options *armhybridcompute.GatewaysClientGetOptions) (resp azfake.Responder[armhybridcompute.GatewaysClientGetResponse], errResp azfake.ErrorResponder)
// NewListByResourceGroupPager is the fake for method GatewaysClient.NewListByResourceGroupPager
// HTTP status codes to indicate success: http.StatusOK
NewListByResourceGroupPager func(resourceGroupName string, options *armhybridcompute.GatewaysClientListByResourceGroupOptions) (resp azfake.PagerResponder[armhybridcompute.GatewaysClientListByResourceGroupResponse])
// NewListBySubscriptionPager is the fake for method GatewaysClient.NewListBySubscriptionPager
// HTTP status codes to indicate success: http.StatusOK
NewListBySubscriptionPager func(options *armhybridcompute.GatewaysClientListBySubscriptionOptions) (resp azfake.PagerResponder[armhybridcompute.GatewaysClientListBySubscriptionResponse])
// Update is the fake for method GatewaysClient.Update
// HTTP status codes to indicate success: http.StatusOK
Update func(ctx context.Context, resourceGroupName string, gatewayName string, parameters armhybridcompute.GatewayUpdate, options *armhybridcompute.GatewaysClientUpdateOptions) (resp azfake.Responder[armhybridcompute.GatewaysClientUpdateResponse], errResp azfake.ErrorResponder)
}
GatewaysServer is a fake server for instances of the armhybridcompute.GatewaysClient type.
type GatewaysServerTransport ¶
type GatewaysServerTransport struct {
// contains filtered or unexported fields
}
GatewaysServerTransport connects instances of armhybridcompute.GatewaysClient to instances of GatewaysServer. Don't use this type directly, use NewGatewaysServerTransport instead.
func NewGatewaysServerTransport ¶
func NewGatewaysServerTransport(srv *GatewaysServer) *GatewaysServerTransport
NewGatewaysServerTransport creates a new instance of GatewaysServerTransport with the provided implementation. The returned GatewaysServerTransport instance is connected to an instance of armhybridcompute.GatewaysClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type LicenseProfilesServer ¶
type LicenseProfilesServer struct {
// BeginCreateOrUpdate is the fake for method LicenseProfilesClient.BeginCreateOrUpdate
// HTTP status codes to indicate success: http.StatusOK, http.StatusCreated
BeginCreateOrUpdate func(ctx context.Context, resourceGroupName string, machineName string, parameters armhybridcompute.LicenseProfile, options *armhybridcompute.LicenseProfilesClientBeginCreateOrUpdateOptions) (resp azfake.PollerResponder[armhybridcompute.LicenseProfilesClientCreateOrUpdateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method LicenseProfilesClient.BeginDelete
// HTTP status codes to indicate success: http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, resourceGroupName string, machineName string, options *armhybridcompute.LicenseProfilesClientBeginDeleteOptions) (resp azfake.PollerResponder[armhybridcompute.LicenseProfilesClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method LicenseProfilesClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, machineName string, options *armhybridcompute.LicenseProfilesClientGetOptions) (resp azfake.Responder[armhybridcompute.LicenseProfilesClientGetResponse], errResp azfake.ErrorResponder)
// NewListPager is the fake for method LicenseProfilesClient.NewListPager
// HTTP status codes to indicate success: http.StatusOK
NewListPager func(resourceGroupName string, machineName string, options *armhybridcompute.LicenseProfilesClientListOptions) (resp azfake.PagerResponder[armhybridcompute.LicenseProfilesClientListResponse])
// BeginUpdate is the fake for method LicenseProfilesClient.BeginUpdate
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginUpdate func(ctx context.Context, resourceGroupName string, machineName string, parameters armhybridcompute.LicenseProfileUpdate, options *armhybridcompute.LicenseProfilesClientBeginUpdateOptions) (resp azfake.PollerResponder[armhybridcompute.LicenseProfilesClientUpdateResponse], errResp azfake.ErrorResponder)
}
LicenseProfilesServer is a fake server for instances of the armhybridcompute.LicenseProfilesClient type.
type LicenseProfilesServerTransport ¶
type LicenseProfilesServerTransport struct {
// contains filtered or unexported fields
}
LicenseProfilesServerTransport connects instances of armhybridcompute.LicenseProfilesClient to instances of LicenseProfilesServer. Don't use this type directly, use NewLicenseProfilesServerTransport instead.
func NewLicenseProfilesServerTransport ¶
func NewLicenseProfilesServerTransport(srv *LicenseProfilesServer) *LicenseProfilesServerTransport
NewLicenseProfilesServerTransport creates a new instance of LicenseProfilesServerTransport with the provided implementation. The returned LicenseProfilesServerTransport instance is connected to an instance of armhybridcompute.LicenseProfilesClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type LicensesServer ¶
type LicensesServer struct {
// BeginCreateOrUpdate is the fake for method LicensesClient.BeginCreateOrUpdate
// HTTP status codes to indicate success: http.StatusOK
BeginCreateOrUpdate func(ctx context.Context, resourceGroupName string, licenseName string, parameters armhybridcompute.License, options *armhybridcompute.LicensesClientBeginCreateOrUpdateOptions) (resp azfake.PollerResponder[armhybridcompute.LicensesClientCreateOrUpdateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method LicensesClient.BeginDelete
// HTTP status codes to indicate success: http.StatusOK, http.StatusNoContent
BeginDelete func(ctx context.Context, resourceGroupName string, licenseName string, options *armhybridcompute.LicensesClientBeginDeleteOptions) (resp azfake.PollerResponder[armhybridcompute.LicensesClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method LicensesClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, licenseName string, options *armhybridcompute.LicensesClientGetOptions) (resp azfake.Responder[armhybridcompute.LicensesClientGetResponse], errResp azfake.ErrorResponder)
// NewListByResourceGroupPager is the fake for method LicensesClient.NewListByResourceGroupPager
// HTTP status codes to indicate success: http.StatusOK
NewListByResourceGroupPager func(resourceGroupName string, options *armhybridcompute.LicensesClientListByResourceGroupOptions) (resp azfake.PagerResponder[armhybridcompute.LicensesClientListByResourceGroupResponse])
// NewListBySubscriptionPager is the fake for method LicensesClient.NewListBySubscriptionPager
// HTTP status codes to indicate success: http.StatusOK
NewListBySubscriptionPager func(options *armhybridcompute.LicensesClientListBySubscriptionOptions) (resp azfake.PagerResponder[armhybridcompute.LicensesClientListBySubscriptionResponse])
// BeginUpdate is the fake for method LicensesClient.BeginUpdate
// HTTP status codes to indicate success: http.StatusOK
BeginUpdate func(ctx context.Context, resourceGroupName string, licenseName string, parameters armhybridcompute.LicenseUpdate, options *armhybridcompute.LicensesClientBeginUpdateOptions) (resp azfake.PollerResponder[armhybridcompute.LicensesClientUpdateResponse], errResp azfake.ErrorResponder)
// BeginValidateLicense is the fake for method LicensesClient.BeginValidateLicense
// HTTP status codes to indicate success: http.StatusOK
BeginValidateLicense func(ctx context.Context, parameters armhybridcompute.License, options *armhybridcompute.LicensesClientBeginValidateLicenseOptions) (resp azfake.PollerResponder[armhybridcompute.LicensesClientValidateLicenseResponse], errResp azfake.ErrorResponder)
}
LicensesServer is a fake server for instances of the armhybridcompute.LicensesClient type.
type LicensesServerTransport ¶
type LicensesServerTransport struct {
// contains filtered or unexported fields
}
LicensesServerTransport connects instances of armhybridcompute.LicensesClient to instances of LicensesServer. Don't use this type directly, use NewLicensesServerTransport instead.
func NewLicensesServerTransport ¶
func NewLicensesServerTransport(srv *LicensesServer) *LicensesServerTransport
NewLicensesServerTransport creates a new instance of LicensesServerTransport with the provided implementation. The returned LicensesServerTransport instance is connected to an instance of armhybridcompute.LicensesClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type MachineExtensionsServer ¶
type MachineExtensionsServer struct {
// BeginCreateOrUpdate is the fake for method MachineExtensionsClient.BeginCreateOrUpdate
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginCreateOrUpdate func(ctx context.Context, resourceGroupName string, machineName string, extensionName string, extensionParameters armhybridcompute.MachineExtension, options *armhybridcompute.MachineExtensionsClientBeginCreateOrUpdateOptions) (resp azfake.PollerResponder[armhybridcompute.MachineExtensionsClientCreateOrUpdateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method MachineExtensionsClient.BeginDelete
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, resourceGroupName string, machineName string, extensionName string, options *armhybridcompute.MachineExtensionsClientBeginDeleteOptions) (resp azfake.PollerResponder[armhybridcompute.MachineExtensionsClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method MachineExtensionsClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, machineName string, extensionName string, options *armhybridcompute.MachineExtensionsClientGetOptions) (resp azfake.Responder[armhybridcompute.MachineExtensionsClientGetResponse], errResp azfake.ErrorResponder)
// NewListPager is the fake for method MachineExtensionsClient.NewListPager
// HTTP status codes to indicate success: http.StatusOK
NewListPager func(resourceGroupName string, machineName string, options *armhybridcompute.MachineExtensionsClientListOptions) (resp azfake.PagerResponder[armhybridcompute.MachineExtensionsClientListResponse])
// BeginUpdate is the fake for method MachineExtensionsClient.BeginUpdate
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginUpdate func(ctx context.Context, resourceGroupName string, machineName string, extensionName string, extensionParameters armhybridcompute.MachineExtensionUpdate, options *armhybridcompute.MachineExtensionsClientBeginUpdateOptions) (resp azfake.PollerResponder[armhybridcompute.MachineExtensionsClientUpdateResponse], errResp azfake.ErrorResponder)
}
MachineExtensionsServer is a fake server for instances of the armhybridcompute.MachineExtensionsClient type.
type MachineExtensionsServerTransport ¶
type MachineExtensionsServerTransport struct {
// contains filtered or unexported fields
}
MachineExtensionsServerTransport connects instances of armhybridcompute.MachineExtensionsClient to instances of MachineExtensionsServer. Don't use this type directly, use NewMachineExtensionsServerTransport instead.
func NewMachineExtensionsServerTransport ¶
func NewMachineExtensionsServerTransport(srv *MachineExtensionsServer) *MachineExtensionsServerTransport
NewMachineExtensionsServerTransport creates a new instance of MachineExtensionsServerTransport with the provided implementation. The returned MachineExtensionsServerTransport instance is connected to an instance of armhybridcompute.MachineExtensionsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type MachineRunCommandsServer ¶
type MachineRunCommandsServer struct {
// BeginCreateOrUpdate is the fake for method MachineRunCommandsClient.BeginCreateOrUpdate
// HTTP status codes to indicate success: http.StatusOK, http.StatusCreated
BeginCreateOrUpdate func(ctx context.Context, resourceGroupName string, machineName string, runCommandName string, runCommandProperties armhybridcompute.MachineRunCommand, options *armhybridcompute.MachineRunCommandsClientBeginCreateOrUpdateOptions) (resp azfake.PollerResponder[armhybridcompute.MachineRunCommandsClientCreateOrUpdateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method MachineRunCommandsClient.BeginDelete
// HTTP status codes to indicate success: http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, resourceGroupName string, machineName string, runCommandName string, options *armhybridcompute.MachineRunCommandsClientBeginDeleteOptions) (resp azfake.PollerResponder[armhybridcompute.MachineRunCommandsClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method MachineRunCommandsClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, machineName string, runCommandName string, options *armhybridcompute.MachineRunCommandsClientGetOptions) (resp azfake.Responder[armhybridcompute.MachineRunCommandsClientGetResponse], errResp azfake.ErrorResponder)
// NewListPager is the fake for method MachineRunCommandsClient.NewListPager
// HTTP status codes to indicate success: http.StatusOK
NewListPager func(resourceGroupName string, machineName string, options *armhybridcompute.MachineRunCommandsClientListOptions) (resp azfake.PagerResponder[armhybridcompute.MachineRunCommandsClientListResponse])
}
MachineRunCommandsServer is a fake server for instances of the armhybridcompute.MachineRunCommandsClient type.
type MachineRunCommandsServerTransport ¶
type MachineRunCommandsServerTransport struct {
// contains filtered or unexported fields
}
MachineRunCommandsServerTransport connects instances of armhybridcompute.MachineRunCommandsClient to instances of MachineRunCommandsServer. Don't use this type directly, use NewMachineRunCommandsServerTransport instead.
func NewMachineRunCommandsServerTransport ¶
func NewMachineRunCommandsServerTransport(srv *MachineRunCommandsServer) *MachineRunCommandsServerTransport
NewMachineRunCommandsServerTransport creates a new instance of MachineRunCommandsServerTransport with the provided implementation. The returned MachineRunCommandsServerTransport instance is connected to an instance of armhybridcompute.MachineRunCommandsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type MachinesServer ¶
type MachinesServer struct {
// BeginAssessPatches is the fake for method MachinesClient.BeginAssessPatches
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginAssessPatches func(ctx context.Context, resourceGroupName string, name string, options *armhybridcompute.MachinesClientBeginAssessPatchesOptions) (resp azfake.PollerResponder[armhybridcompute.MachinesClientAssessPatchesResponse], errResp azfake.ErrorResponder)
// CreateOrUpdate is the fake for method MachinesClient.CreateOrUpdate
// HTTP status codes to indicate success: http.StatusOK
CreateOrUpdate func(ctx context.Context, resourceGroupName string, machineName string, parameters armhybridcompute.Machine, options *armhybridcompute.MachinesClientCreateOrUpdateOptions) (resp azfake.Responder[armhybridcompute.MachinesClientCreateOrUpdateResponse], errResp azfake.ErrorResponder)
// Delete is the fake for method MachinesClient.Delete
// HTTP status codes to indicate success: http.StatusOK, http.StatusNoContent
Delete func(ctx context.Context, resourceGroupName string, machineName string, options *armhybridcompute.MachinesClientDeleteOptions) (resp azfake.Responder[armhybridcompute.MachinesClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method MachinesClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, machineName string, options *armhybridcompute.MachinesClientGetOptions) (resp azfake.Responder[armhybridcompute.MachinesClientGetResponse], errResp azfake.ErrorResponder)
// BeginInstallPatches is the fake for method MachinesClient.BeginInstallPatches
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginInstallPatches func(ctx context.Context, resourceGroupName string, name string, installPatchesInput armhybridcompute.MachineInstallPatchesParameters, options *armhybridcompute.MachinesClientBeginInstallPatchesOptions) (resp azfake.PollerResponder[armhybridcompute.MachinesClientInstallPatchesResponse], errResp azfake.ErrorResponder)
// NewListByResourceGroupPager is the fake for method MachinesClient.NewListByResourceGroupPager
// HTTP status codes to indicate success: http.StatusOK
NewListByResourceGroupPager func(resourceGroupName string, options *armhybridcompute.MachinesClientListByResourceGroupOptions) (resp azfake.PagerResponder[armhybridcompute.MachinesClientListByResourceGroupResponse])
// NewListBySubscriptionPager is the fake for method MachinesClient.NewListBySubscriptionPager
// HTTP status codes to indicate success: http.StatusOK
NewListBySubscriptionPager func(options *armhybridcompute.MachinesClientListBySubscriptionOptions) (resp azfake.PagerResponder[armhybridcompute.MachinesClientListBySubscriptionResponse])
// Update is the fake for method MachinesClient.Update
// HTTP status codes to indicate success: http.StatusOK
Update func(ctx context.Context, resourceGroupName string, machineName string, parameters armhybridcompute.MachineUpdate, options *armhybridcompute.MachinesClientUpdateOptions) (resp azfake.Responder[armhybridcompute.MachinesClientUpdateResponse], errResp azfake.ErrorResponder)
}
MachinesServer is a fake server for instances of the armhybridcompute.MachinesClient type.
type MachinesServerTransport ¶
type MachinesServerTransport struct {
// contains filtered or unexported fields
}
MachinesServerTransport connects instances of armhybridcompute.MachinesClient to instances of MachinesServer. Don't use this type directly, use NewMachinesServerTransport instead.
func NewMachinesServerTransport ¶
func NewMachinesServerTransport(srv *MachinesServer) *MachinesServerTransport
NewMachinesServerTransport creates a new instance of MachinesServerTransport with the provided implementation. The returned MachinesServerTransport instance is connected to an instance of armhybridcompute.MachinesClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type ManagementServer ¶
type ManagementServer struct {
// BeginUpgradeExtensions is the fake for method ManagementClient.BeginUpgradeExtensions
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginUpgradeExtensions func(ctx context.Context, resourceGroupName string, machineName string, extensionUpgradeParameters armhybridcompute.MachineExtensionUpgrade, options *armhybridcompute.ManagementClientBeginUpgradeExtensionsOptions) (resp azfake.PollerResponder[armhybridcompute.ManagementClientUpgradeExtensionsResponse], errResp azfake.ErrorResponder)
}
ManagementServer is a fake server for instances of the armhybridcompute.ManagementClient type.
type ManagementServerTransport ¶
type ManagementServerTransport struct {
// contains filtered or unexported fields
}
ManagementServerTransport connects instances of armhybridcompute.ManagementClient to instances of ManagementServer. Don't use this type directly, use NewManagementServerTransport instead.
func NewManagementServerTransport ¶
func NewManagementServerTransport(srv *ManagementServer) *ManagementServerTransport
NewManagementServerTransport creates a new instance of ManagementServerTransport with the provided implementation. The returned ManagementServerTransport instance is connected to an instance of armhybridcompute.ManagementClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type NetworkProfileServer ¶
type NetworkProfileServer struct {
// Get is the fake for method NetworkProfileClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, machineName string, options *armhybridcompute.NetworkProfileClientGetOptions) (resp azfake.Responder[armhybridcompute.NetworkProfileClientGetResponse], errResp azfake.ErrorResponder)
}
NetworkProfileServer is a fake server for instances of the armhybridcompute.NetworkProfileClient type.
type NetworkProfileServerTransport ¶
type NetworkProfileServerTransport struct {
// contains filtered or unexported fields
}
NetworkProfileServerTransport connects instances of armhybridcompute.NetworkProfileClient to instances of NetworkProfileServer. Don't use this type directly, use NewNetworkProfileServerTransport instead.
func NewNetworkProfileServerTransport ¶
func NewNetworkProfileServerTransport(srv *NetworkProfileServer) *NetworkProfileServerTransport
NewNetworkProfileServerTransport creates a new instance of NetworkProfileServerTransport with the provided implementation. The returned NetworkProfileServerTransport instance is connected to an instance of armhybridcompute.NetworkProfileClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type NetworkSecurityPerimeterConfigurationsServer ¶
type NetworkSecurityPerimeterConfigurationsServer struct {
// GetByPrivateLinkScope is the fake for method NetworkSecurityPerimeterConfigurationsClient.GetByPrivateLinkScope
// HTTP status codes to indicate success: http.StatusOK
GetByPrivateLinkScope func(ctx context.Context, resourceGroupName string, scopeName string, perimeterName string, options *armhybridcompute.NetworkSecurityPerimeterConfigurationsClientGetByPrivateLinkScopeOptions) (resp azfake.Responder[armhybridcompute.NetworkSecurityPerimeterConfigurationsClientGetByPrivateLinkScopeResponse], errResp azfake.ErrorResponder)
// NewListByPrivateLinkScopePager is the fake for method NetworkSecurityPerimeterConfigurationsClient.NewListByPrivateLinkScopePager
// HTTP status codes to indicate success: http.StatusOK
NewListByPrivateLinkScopePager func(resourceGroupName string, scopeName string, options *armhybridcompute.NetworkSecurityPerimeterConfigurationsClientListByPrivateLinkScopeOptions) (resp azfake.PagerResponder[armhybridcompute.NetworkSecurityPerimeterConfigurationsClientListByPrivateLinkScopeResponse])
// BeginReconcileForPrivateLinkScope is the fake for method NetworkSecurityPerimeterConfigurationsClient.BeginReconcileForPrivateLinkScope
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginReconcileForPrivateLinkScope func(ctx context.Context, resourceGroupName string, scopeName string, perimeterName string, options *armhybridcompute.NetworkSecurityPerimeterConfigurationsClientBeginReconcileForPrivateLinkScopeOptions) (resp azfake.PollerResponder[armhybridcompute.NetworkSecurityPerimeterConfigurationsClientReconcileForPrivateLinkScopeResponse], errResp azfake.ErrorResponder)
}
NetworkSecurityPerimeterConfigurationsServer is a fake server for instances of the armhybridcompute.NetworkSecurityPerimeterConfigurationsClient type.
type NetworkSecurityPerimeterConfigurationsServerTransport ¶
type NetworkSecurityPerimeterConfigurationsServerTransport struct {
// contains filtered or unexported fields
}
NetworkSecurityPerimeterConfigurationsServerTransport connects instances of armhybridcompute.NetworkSecurityPerimeterConfigurationsClient to instances of NetworkSecurityPerimeterConfigurationsServer. Don't use this type directly, use NewNetworkSecurityPerimeterConfigurationsServerTransport instead.
func NewNetworkSecurityPerimeterConfigurationsServerTransport ¶
func NewNetworkSecurityPerimeterConfigurationsServerTransport(srv *NetworkSecurityPerimeterConfigurationsServer) *NetworkSecurityPerimeterConfigurationsServerTransport
NewNetworkSecurityPerimeterConfigurationsServerTransport creates a new instance of NetworkSecurityPerimeterConfigurationsServerTransport with the provided implementation. The returned NetworkSecurityPerimeterConfigurationsServerTransport instance is connected to an instance of armhybridcompute.NetworkSecurityPerimeterConfigurationsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type OperationsServer ¶
type OperationsServer struct {
// NewListPager is the fake for method OperationsClient.NewListPager
// HTTP status codes to indicate success: http.StatusOK
NewListPager func(options *armhybridcompute.OperationsClientListOptions) (resp azfake.PagerResponder[armhybridcompute.OperationsClientListResponse])
}
OperationsServer is a fake server for instances of the armhybridcompute.OperationsClient type.
type OperationsServerTransport ¶
type OperationsServerTransport struct {
// contains filtered or unexported fields
}
OperationsServerTransport connects instances of armhybridcompute.OperationsClient to instances of OperationsServer. Don't use this type directly, use NewOperationsServerTransport instead.
func NewOperationsServerTransport ¶
func NewOperationsServerTransport(srv *OperationsServer) *OperationsServerTransport
NewOperationsServerTransport creates a new instance of OperationsServerTransport with the provided implementation. The returned OperationsServerTransport instance is connected to an instance of armhybridcompute.OperationsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type PrivateEndpointConnectionsServer ¶
type PrivateEndpointConnectionsServer struct {
// BeginCreateOrUpdate is the fake for method PrivateEndpointConnectionsClient.BeginCreateOrUpdate
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginCreateOrUpdate func(ctx context.Context, resourceGroupName string, scopeName string, privateEndpointConnectionName string, parameters armhybridcompute.PrivateEndpointConnection, options *armhybridcompute.PrivateEndpointConnectionsClientBeginCreateOrUpdateOptions) (resp azfake.PollerResponder[armhybridcompute.PrivateEndpointConnectionsClientCreateOrUpdateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method PrivateEndpointConnectionsClient.BeginDelete
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, resourceGroupName string, scopeName string, privateEndpointConnectionName string, options *armhybridcompute.PrivateEndpointConnectionsClientBeginDeleteOptions) (resp azfake.PollerResponder[armhybridcompute.PrivateEndpointConnectionsClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method PrivateEndpointConnectionsClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, scopeName string, privateEndpointConnectionName string, options *armhybridcompute.PrivateEndpointConnectionsClientGetOptions) (resp azfake.Responder[armhybridcompute.PrivateEndpointConnectionsClientGetResponse], errResp azfake.ErrorResponder)
// NewListByPrivateLinkScopePager is the fake for method PrivateEndpointConnectionsClient.NewListByPrivateLinkScopePager
// HTTP status codes to indicate success: http.StatusOK
NewListByPrivateLinkScopePager func(resourceGroupName string, scopeName string, options *armhybridcompute.PrivateEndpointConnectionsClientListByPrivateLinkScopeOptions) (resp azfake.PagerResponder[armhybridcompute.PrivateEndpointConnectionsClientListByPrivateLinkScopeResponse])
}
PrivateEndpointConnectionsServer is a fake server for instances of the armhybridcompute.PrivateEndpointConnectionsClient type.
type PrivateEndpointConnectionsServerTransport ¶
type PrivateEndpointConnectionsServerTransport struct {
// contains filtered or unexported fields
}
PrivateEndpointConnectionsServerTransport connects instances of armhybridcompute.PrivateEndpointConnectionsClient to instances of PrivateEndpointConnectionsServer. Don't use this type directly, use NewPrivateEndpointConnectionsServerTransport instead.
func NewPrivateEndpointConnectionsServerTransport ¶
func NewPrivateEndpointConnectionsServerTransport(srv *PrivateEndpointConnectionsServer) *PrivateEndpointConnectionsServerTransport
NewPrivateEndpointConnectionsServerTransport creates a new instance of PrivateEndpointConnectionsServerTransport with the provided implementation. The returned PrivateEndpointConnectionsServerTransport instance is connected to an instance of armhybridcompute.PrivateEndpointConnectionsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type PrivateLinkResourcesServer ¶
type PrivateLinkResourcesServer struct {
// Get is the fake for method PrivateLinkResourcesClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, scopeName string, groupName string, options *armhybridcompute.PrivateLinkResourcesClientGetOptions) (resp azfake.Responder[armhybridcompute.PrivateLinkResourcesClientGetResponse], errResp azfake.ErrorResponder)
// NewListByPrivateLinkScopePager is the fake for method PrivateLinkResourcesClient.NewListByPrivateLinkScopePager
// HTTP status codes to indicate success: http.StatusOK
NewListByPrivateLinkScopePager func(resourceGroupName string, scopeName string, options *armhybridcompute.PrivateLinkResourcesClientListByPrivateLinkScopeOptions) (resp azfake.PagerResponder[armhybridcompute.PrivateLinkResourcesClientListByPrivateLinkScopeResponse])
}
PrivateLinkResourcesServer is a fake server for instances of the armhybridcompute.PrivateLinkResourcesClient type.
type PrivateLinkResourcesServerTransport ¶
type PrivateLinkResourcesServerTransport struct {
// contains filtered or unexported fields
}
PrivateLinkResourcesServerTransport connects instances of armhybridcompute.PrivateLinkResourcesClient to instances of PrivateLinkResourcesServer. Don't use this type directly, use NewPrivateLinkResourcesServerTransport instead.
func NewPrivateLinkResourcesServerTransport ¶
func NewPrivateLinkResourcesServerTransport(srv *PrivateLinkResourcesServer) *PrivateLinkResourcesServerTransport
NewPrivateLinkResourcesServerTransport creates a new instance of PrivateLinkResourcesServerTransport with the provided implementation. The returned PrivateLinkResourcesServerTransport instance is connected to an instance of armhybridcompute.PrivateLinkResourcesClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type PrivateLinkScopesServer ¶
type PrivateLinkScopesServer struct {
// CreateOrUpdate is the fake for method PrivateLinkScopesClient.CreateOrUpdate
// HTTP status codes to indicate success: http.StatusOK, http.StatusCreated
CreateOrUpdate func(ctx context.Context, resourceGroupName string, scopeName string, parameters armhybridcompute.PrivateLinkScope, options *armhybridcompute.PrivateLinkScopesClientCreateOrUpdateOptions) (resp azfake.Responder[armhybridcompute.PrivateLinkScopesClientCreateOrUpdateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method PrivateLinkScopesClient.BeginDelete
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, resourceGroupName string, scopeName string, options *armhybridcompute.PrivateLinkScopesClientBeginDeleteOptions) (resp azfake.PollerResponder[armhybridcompute.PrivateLinkScopesClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method PrivateLinkScopesClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, scopeName string, options *armhybridcompute.PrivateLinkScopesClientGetOptions) (resp azfake.Responder[armhybridcompute.PrivateLinkScopesClientGetResponse], errResp azfake.ErrorResponder)
// GetValidationDetails is the fake for method PrivateLinkScopesClient.GetValidationDetails
// HTTP status codes to indicate success: http.StatusOK
GetValidationDetails func(ctx context.Context, location string, privateLinkScopeID string, options *armhybridcompute.PrivateLinkScopesClientGetValidationDetailsOptions) (resp azfake.Responder[armhybridcompute.PrivateLinkScopesClientGetValidationDetailsResponse], errResp azfake.ErrorResponder)
// GetValidationDetailsForMachine is the fake for method PrivateLinkScopesClient.GetValidationDetailsForMachine
// HTTP status codes to indicate success: http.StatusOK
GetValidationDetailsForMachine func(ctx context.Context, resourceGroupName string, machineName string, options *armhybridcompute.PrivateLinkScopesClientGetValidationDetailsForMachineOptions) (resp azfake.Responder[armhybridcompute.PrivateLinkScopesClientGetValidationDetailsForMachineResponse], errResp azfake.ErrorResponder)
// NewListPager is the fake for method PrivateLinkScopesClient.NewListPager
// HTTP status codes to indicate success: http.StatusOK
NewListPager func(options *armhybridcompute.PrivateLinkScopesClientListOptions) (resp azfake.PagerResponder[armhybridcompute.PrivateLinkScopesClientListResponse])
// NewListByResourceGroupPager is the fake for method PrivateLinkScopesClient.NewListByResourceGroupPager
// HTTP status codes to indicate success: http.StatusOK
NewListByResourceGroupPager func(resourceGroupName string, options *armhybridcompute.PrivateLinkScopesClientListByResourceGroupOptions) (resp azfake.PagerResponder[armhybridcompute.PrivateLinkScopesClientListByResourceGroupResponse])
// UpdateTags is the fake for method PrivateLinkScopesClient.UpdateTags
// HTTP status codes to indicate success: http.StatusOK
UpdateTags func(ctx context.Context, resourceGroupName string, scopeName string, privateLinkScopeTags armhybridcompute.TagsResource, options *armhybridcompute.PrivateLinkScopesClientUpdateTagsOptions) (resp azfake.Responder[armhybridcompute.PrivateLinkScopesClientUpdateTagsResponse], errResp azfake.ErrorResponder)
}
PrivateLinkScopesServer is a fake server for instances of the armhybridcompute.PrivateLinkScopesClient type.
type PrivateLinkScopesServerTransport ¶
type PrivateLinkScopesServerTransport struct {
// contains filtered or unexported fields
}
PrivateLinkScopesServerTransport connects instances of armhybridcompute.PrivateLinkScopesClient to instances of PrivateLinkScopesServer. Don't use this type directly, use NewPrivateLinkScopesServerTransport instead.
func NewPrivateLinkScopesServerTransport ¶
func NewPrivateLinkScopesServerTransport(srv *PrivateLinkScopesServer) *PrivateLinkScopesServerTransport
NewPrivateLinkScopesServerTransport creates a new instance of PrivateLinkScopesServerTransport with the provided implementation. The returned PrivateLinkScopesServerTransport instance is connected to an instance of armhybridcompute.PrivateLinkScopesClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type ServerFactory ¶
type ServerFactory struct {
ExtensionMetadataServer ExtensionMetadataServer
GatewaysServer GatewaysServer
LicenseProfilesServer LicenseProfilesServer
LicensesServer LicensesServer
MachineExtensionsServer MachineExtensionsServer
MachineRunCommandsServer MachineRunCommandsServer
MachinesServer MachinesServer
ManagementServer ManagementServer
NetworkProfileServer NetworkProfileServer
NetworkSecurityPerimeterConfigurationsServer NetworkSecurityPerimeterConfigurationsServer
OperationsServer OperationsServer
PrivateEndpointConnectionsServer PrivateEndpointConnectionsServer
PrivateLinkResourcesServer PrivateLinkResourcesServer
PrivateLinkScopesServer PrivateLinkScopesServer
SettingsServer SettingsServer
}
ServerFactory is a fake server for instances of the armhybridcompute.ClientFactory type.
type ServerFactoryTransport ¶
type ServerFactoryTransport struct {
// contains filtered or unexported fields
}
ServerFactoryTransport connects instances of armhybridcompute.ClientFactory to instances of ServerFactory. Don't use this type directly, use NewServerFactoryTransport instead.
func NewServerFactoryTransport ¶
func NewServerFactoryTransport(srv *ServerFactory) *ServerFactoryTransport
NewServerFactoryTransport creates a new instance of ServerFactoryTransport with the provided implementation. The returned ServerFactoryTransport instance is connected to an instance of armhybridcompute.ClientFactory via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type SettingsServer ¶
type SettingsServer struct {
// Get is the fake for method SettingsClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, baseProvider string, baseResourceType string, baseResourceName string, settingsResourceName string, options *armhybridcompute.SettingsClientGetOptions) (resp azfake.Responder[armhybridcompute.SettingsClientGetResponse], errResp azfake.ErrorResponder)
// Patch is the fake for method SettingsClient.Patch
// HTTP status codes to indicate success: http.StatusOK
Patch func(ctx context.Context, resourceGroupName string, baseProvider string, baseResourceType string, baseResourceName string, settingsResourceName string, parameters armhybridcompute.Settings, options *armhybridcompute.SettingsClientPatchOptions) (resp azfake.Responder[armhybridcompute.SettingsClientPatchResponse], errResp azfake.ErrorResponder)
// Update is the fake for method SettingsClient.Update
// HTTP status codes to indicate success: http.StatusOK, http.StatusCreated
Update func(ctx context.Context, resourceGroupName string, baseProvider string, baseResourceType string, baseResourceName string, settingsResourceName string, parameters armhybridcompute.Settings, options *armhybridcompute.SettingsClientUpdateOptions) (resp azfake.Responder[armhybridcompute.SettingsClientUpdateResponse], errResp azfake.ErrorResponder)
}
SettingsServer is a fake server for instances of the armhybridcompute.SettingsClient type.
type SettingsServerTransport ¶
type SettingsServerTransport struct {
// contains filtered or unexported fields
}
SettingsServerTransport connects instances of armhybridcompute.SettingsClient to instances of SettingsServer. Don't use this type directly, use NewSettingsServerTransport instead.
func NewSettingsServerTransport ¶
func NewSettingsServerTransport(srv *SettingsServer) *SettingsServerTransport
NewSettingsServerTransport creates a new instance of SettingsServerTransport with the provided implementation. The returned SettingsServerTransport instance is connected to an instance of armhybridcompute.SettingsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
Source Files
¶
- extensionmetadata_server.go
- gateways_server.go
- internal.go
- licenseprofiles_server.go
- licenses_server.go
- machineextensions_server.go
- machineruncommands_server.go
- machines_server.go
- management_server.go
- networkprofile_server.go
- networksecurityperimeterconfigurations_server.go
- operations_server.go
- privateendpointconnections_server.go
- privatelinkresources_server.go
- privatelinkscopes_server.go
- server_factory.go
- settings_server.go
- time_rfc3339.go