Documentation
¶
Index ¶
- type GroupsServer
- type GroupsServerTransport
- type ManagedNetworksServer
- type ManagedNetworksServerTransport
- type OperationsServer
- type OperationsServerTransport
- type PeeringPoliciesServer
- type PeeringPoliciesServerTransport
- type ScopeAssignmentsServer
- type ScopeAssignmentsServerTransport
- type ServerFactory
- type ServerFactoryTransport
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type GroupsServer ¶
type GroupsServer struct {
// BeginCreateOrUpdate is the fake for method GroupsClient.BeginCreateOrUpdate
// HTTP status codes to indicate success: http.StatusOK, http.StatusCreated
BeginCreateOrUpdate func(ctx context.Context, resourceGroupName string, managedNetworkName string, managedNetworkGroupName string, managedNetworkGroup armmanagednetwork.Group, options *armmanagednetwork.GroupsClientBeginCreateOrUpdateOptions) (resp azfake.PollerResponder[armmanagednetwork.GroupsClientCreateOrUpdateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method GroupsClient.BeginDelete
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, resourceGroupName string, managedNetworkName string, managedNetworkGroupName string, options *armmanagednetwork.GroupsClientBeginDeleteOptions) (resp azfake.PollerResponder[armmanagednetwork.GroupsClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method GroupsClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, managedNetworkName string, managedNetworkGroupName string, options *armmanagednetwork.GroupsClientGetOptions) (resp azfake.Responder[armmanagednetwork.GroupsClientGetResponse], errResp azfake.ErrorResponder)
// NewListByManagedNetworkPager is the fake for method GroupsClient.NewListByManagedNetworkPager
// HTTP status codes to indicate success: http.StatusOK
NewListByManagedNetworkPager func(resourceGroupName string, managedNetworkName string, options *armmanagednetwork.GroupsClientListByManagedNetworkOptions) (resp azfake.PagerResponder[armmanagednetwork.GroupsClientListByManagedNetworkResponse])
}
GroupsServer is a fake server for instances of the armmanagednetwork.GroupsClient type.
type GroupsServerTransport ¶
type GroupsServerTransport struct {
// contains filtered or unexported fields
}
GroupsServerTransport connects instances of armmanagednetwork.GroupsClient to instances of GroupsServer. Don't use this type directly, use NewGroupsServerTransport instead.
func NewGroupsServerTransport ¶
func NewGroupsServerTransport(srv *GroupsServer) *GroupsServerTransport
NewGroupsServerTransport creates a new instance of GroupsServerTransport with the provided implementation. The returned GroupsServerTransport instance is connected to an instance of armmanagednetwork.GroupsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type ManagedNetworksServer ¶
type ManagedNetworksServer struct {
// CreateOrUpdate is the fake for method ManagedNetworksClient.CreateOrUpdate
// HTTP status codes to indicate success: http.StatusOK, http.StatusCreated
CreateOrUpdate func(ctx context.Context, resourceGroupName string, managedNetworkName string, managedNetwork armmanagednetwork.ManagedNetwork, options *armmanagednetwork.ManagedNetworksClientCreateOrUpdateOptions) (resp azfake.Responder[armmanagednetwork.ManagedNetworksClientCreateOrUpdateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method ManagedNetworksClient.BeginDelete
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, resourceGroupName string, managedNetworkName string, options *armmanagednetwork.ManagedNetworksClientBeginDeleteOptions) (resp azfake.PollerResponder[armmanagednetwork.ManagedNetworksClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method ManagedNetworksClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, managedNetworkName string, options *armmanagednetwork.ManagedNetworksClientGetOptions) (resp azfake.Responder[armmanagednetwork.ManagedNetworksClientGetResponse], errResp azfake.ErrorResponder)
// NewListByResourceGroupPager is the fake for method ManagedNetworksClient.NewListByResourceGroupPager
// HTTP status codes to indicate success: http.StatusOK
NewListByResourceGroupPager func(resourceGroupName string, options *armmanagednetwork.ManagedNetworksClientListByResourceGroupOptions) (resp azfake.PagerResponder[armmanagednetwork.ManagedNetworksClientListByResourceGroupResponse])
// NewListBySubscriptionPager is the fake for method ManagedNetworksClient.NewListBySubscriptionPager
// HTTP status codes to indicate success: http.StatusOK
NewListBySubscriptionPager func(options *armmanagednetwork.ManagedNetworksClientListBySubscriptionOptions) (resp azfake.PagerResponder[armmanagednetwork.ManagedNetworksClientListBySubscriptionResponse])
// BeginUpdate is the fake for method ManagedNetworksClient.BeginUpdate
// HTTP status codes to indicate success: http.StatusOK, http.StatusCreated
BeginUpdate func(ctx context.Context, resourceGroupName string, managedNetworkName string, parameters armmanagednetwork.Update, options *armmanagednetwork.ManagedNetworksClientBeginUpdateOptions) (resp azfake.PollerResponder[armmanagednetwork.ManagedNetworksClientUpdateResponse], errResp azfake.ErrorResponder)
}
ManagedNetworksServer is a fake server for instances of the armmanagednetwork.ManagedNetworksClient type.
type ManagedNetworksServerTransport ¶
type ManagedNetworksServerTransport struct {
// contains filtered or unexported fields
}
ManagedNetworksServerTransport connects instances of armmanagednetwork.ManagedNetworksClient to instances of ManagedNetworksServer. Don't use this type directly, use NewManagedNetworksServerTransport instead.
func NewManagedNetworksServerTransport ¶
func NewManagedNetworksServerTransport(srv *ManagedNetworksServer) *ManagedNetworksServerTransport
NewManagedNetworksServerTransport creates a new instance of ManagedNetworksServerTransport with the provided implementation. The returned ManagedNetworksServerTransport instance is connected to an instance of armmanagednetwork.ManagedNetworksClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type OperationsServer ¶
type OperationsServer struct {
// NewListPager is the fake for method OperationsClient.NewListPager
// HTTP status codes to indicate success: http.StatusOK
NewListPager func(options *armmanagednetwork.OperationsClientListOptions) (resp azfake.PagerResponder[armmanagednetwork.OperationsClientListResponse])
}
OperationsServer is a fake server for instances of the armmanagednetwork.OperationsClient type.
type OperationsServerTransport ¶
type OperationsServerTransport struct {
// contains filtered or unexported fields
}
OperationsServerTransport connects instances of armmanagednetwork.OperationsClient to instances of OperationsServer. Don't use this type directly, use NewOperationsServerTransport instead.
func NewOperationsServerTransport ¶
func NewOperationsServerTransport(srv *OperationsServer) *OperationsServerTransport
NewOperationsServerTransport creates a new instance of OperationsServerTransport with the provided implementation. The returned OperationsServerTransport instance is connected to an instance of armmanagednetwork.OperationsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type PeeringPoliciesServer ¶
type PeeringPoliciesServer struct {
// BeginCreateOrUpdate is the fake for method PeeringPoliciesClient.BeginCreateOrUpdate
// HTTP status codes to indicate success: http.StatusOK, http.StatusCreated
BeginCreateOrUpdate func(ctx context.Context, resourceGroupName string, managedNetworkName string, managedNetworkPeeringPolicyName string, managedNetworkPolicy armmanagednetwork.PeeringPolicy, options *armmanagednetwork.PeeringPoliciesClientBeginCreateOrUpdateOptions) (resp azfake.PollerResponder[armmanagednetwork.PeeringPoliciesClientCreateOrUpdateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method PeeringPoliciesClient.BeginDelete
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, resourceGroupName string, managedNetworkName string, managedNetworkPeeringPolicyName string, options *armmanagednetwork.PeeringPoliciesClientBeginDeleteOptions) (resp azfake.PollerResponder[armmanagednetwork.PeeringPoliciesClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method PeeringPoliciesClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, managedNetworkName string, managedNetworkPeeringPolicyName string, options *armmanagednetwork.PeeringPoliciesClientGetOptions) (resp azfake.Responder[armmanagednetwork.PeeringPoliciesClientGetResponse], errResp azfake.ErrorResponder)
// NewListByManagedNetworkPager is the fake for method PeeringPoliciesClient.NewListByManagedNetworkPager
// HTTP status codes to indicate success: http.StatusOK
NewListByManagedNetworkPager func(resourceGroupName string, managedNetworkName string, options *armmanagednetwork.PeeringPoliciesClientListByManagedNetworkOptions) (resp azfake.PagerResponder[armmanagednetwork.PeeringPoliciesClientListByManagedNetworkResponse])
}
PeeringPoliciesServer is a fake server for instances of the armmanagednetwork.PeeringPoliciesClient type.
type PeeringPoliciesServerTransport ¶
type PeeringPoliciesServerTransport struct {
// contains filtered or unexported fields
}
PeeringPoliciesServerTransport connects instances of armmanagednetwork.PeeringPoliciesClient to instances of PeeringPoliciesServer. Don't use this type directly, use NewPeeringPoliciesServerTransport instead.
func NewPeeringPoliciesServerTransport ¶
func NewPeeringPoliciesServerTransport(srv *PeeringPoliciesServer) *PeeringPoliciesServerTransport
NewPeeringPoliciesServerTransport creates a new instance of PeeringPoliciesServerTransport with the provided implementation. The returned PeeringPoliciesServerTransport instance is connected to an instance of armmanagednetwork.PeeringPoliciesClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type ScopeAssignmentsServer ¶
type ScopeAssignmentsServer struct {
// CreateOrUpdate is the fake for method ScopeAssignmentsClient.CreateOrUpdate
// HTTP status codes to indicate success: http.StatusOK, http.StatusCreated
CreateOrUpdate func(ctx context.Context, scope string, scopeAssignmentName string, parameters armmanagednetwork.ScopeAssignment, options *armmanagednetwork.ScopeAssignmentsClientCreateOrUpdateOptions) (resp azfake.Responder[armmanagednetwork.ScopeAssignmentsClientCreateOrUpdateResponse], errResp azfake.ErrorResponder)
// Delete is the fake for method ScopeAssignmentsClient.Delete
// HTTP status codes to indicate success: http.StatusOK
Delete func(ctx context.Context, scope string, scopeAssignmentName string, options *armmanagednetwork.ScopeAssignmentsClientDeleteOptions) (resp azfake.Responder[armmanagednetwork.ScopeAssignmentsClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method ScopeAssignmentsClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, scope string, scopeAssignmentName string, options *armmanagednetwork.ScopeAssignmentsClientGetOptions) (resp azfake.Responder[armmanagednetwork.ScopeAssignmentsClientGetResponse], errResp azfake.ErrorResponder)
// NewListPager is the fake for method ScopeAssignmentsClient.NewListPager
// HTTP status codes to indicate success: http.StatusOK
NewListPager func(scope string, options *armmanagednetwork.ScopeAssignmentsClientListOptions) (resp azfake.PagerResponder[armmanagednetwork.ScopeAssignmentsClientListResponse])
}
ScopeAssignmentsServer is a fake server for instances of the armmanagednetwork.ScopeAssignmentsClient type.
type ScopeAssignmentsServerTransport ¶
type ScopeAssignmentsServerTransport struct {
// contains filtered or unexported fields
}
ScopeAssignmentsServerTransport connects instances of armmanagednetwork.ScopeAssignmentsClient to instances of ScopeAssignmentsServer. Don't use this type directly, use NewScopeAssignmentsServerTransport instead.
func NewScopeAssignmentsServerTransport ¶
func NewScopeAssignmentsServerTransport(srv *ScopeAssignmentsServer) *ScopeAssignmentsServerTransport
NewScopeAssignmentsServerTransport creates a new instance of ScopeAssignmentsServerTransport with the provided implementation. The returned ScopeAssignmentsServerTransport instance is connected to an instance of armmanagednetwork.ScopeAssignmentsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type ServerFactory ¶
type ServerFactory struct {
GroupsServer GroupsServer
ManagedNetworksServer ManagedNetworksServer
OperationsServer OperationsServer
PeeringPoliciesServer PeeringPoliciesServer
ScopeAssignmentsServer ScopeAssignmentsServer
}
ServerFactory is a fake server for instances of the armmanagednetwork.ClientFactory type.
type ServerFactoryTransport ¶
type ServerFactoryTransport struct {
// contains filtered or unexported fields
}
ServerFactoryTransport connects instances of armmanagednetwork.ClientFactory to instances of ServerFactory. Don't use this type directly, use NewServerFactoryTransport instead.
func NewServerFactoryTransport ¶
func NewServerFactoryTransport(srv *ServerFactory) *ServerFactoryTransport
NewServerFactoryTransport creates a new instance of ServerFactoryTransport with the provided implementation. The returned ServerFactoryTransport instance is connected to an instance of armmanagednetwork.ClientFactory via the azcore.ClientOptions.Transporter field in the client's constructor parameters.