Documentation
¶
Index ¶
- type APIServer
- type APIServerTransport
- type EntitiesServer
- type EntitiesServerTransport
- type HierarchySettingsServer
- type HierarchySettingsServerTransport
- type ManagementGroupSubscriptionsServer
- type ManagementGroupSubscriptionsServerTransport
- type OperationsServer
- type OperationsServerTransport
- type Server
- type ServerFactory
- type ServerFactoryTransport
- type ServerTransport
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type APIServer ¶
type APIServer struct {
// CheckNameAvailability is the fake for method APIClient.CheckNameAvailability
// HTTP status codes to indicate success: http.StatusOK
CheckNameAvailability func(ctx context.Context, checkNameAvailabilityRequest armmanagementgroups.CheckNameAvailabilityRequest, options *armmanagementgroups.APIClientCheckNameAvailabilityOptions) (resp azfake.Responder[armmanagementgroups.APIClientCheckNameAvailabilityResponse], errResp azfake.ErrorResponder)
// StartTenantBackfill is the fake for method APIClient.StartTenantBackfill
// HTTP status codes to indicate success: http.StatusOK
StartTenantBackfill func(ctx context.Context, options *armmanagementgroups.APIClientStartTenantBackfillOptions) (resp azfake.Responder[armmanagementgroups.APIClientStartTenantBackfillResponse], errResp azfake.ErrorResponder)
// TenantBackfillStatus is the fake for method APIClient.TenantBackfillStatus
// HTTP status codes to indicate success: http.StatusOK
TenantBackfillStatus func(ctx context.Context, options *armmanagementgroups.APIClientTenantBackfillStatusOptions) (resp azfake.Responder[armmanagementgroups.APIClientTenantBackfillStatusResponse], errResp azfake.ErrorResponder)
}
APIServer is a fake server for instances of the armmanagementgroups.APIClient type.
type APIServerTransport ¶
type APIServerTransport struct {
// contains filtered or unexported fields
}
APIServerTransport connects instances of armmanagementgroups.APIClient to instances of APIServer. Don't use this type directly, use NewAPIServerTransport instead.
func NewAPIServerTransport ¶
func NewAPIServerTransport(srv *APIServer) *APIServerTransport
NewAPIServerTransport creates a new instance of APIServerTransport with the provided implementation. The returned APIServerTransport instance is connected to an instance of armmanagementgroups.APIClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type EntitiesServer ¶
type EntitiesServer struct {
// NewListPager is the fake for method EntitiesClient.NewListPager
// HTTP status codes to indicate success: http.StatusOK
NewListPager func(options *armmanagementgroups.EntitiesClientListOptions) (resp azfake.PagerResponder[armmanagementgroups.EntitiesClientListResponse])
}
EntitiesServer is a fake server for instances of the armmanagementgroups.EntitiesClient type.
type EntitiesServerTransport ¶
type EntitiesServerTransport struct {
// contains filtered or unexported fields
}
EntitiesServerTransport connects instances of armmanagementgroups.EntitiesClient to instances of EntitiesServer. Don't use this type directly, use NewEntitiesServerTransport instead.
func NewEntitiesServerTransport ¶
func NewEntitiesServerTransport(srv *EntitiesServer) *EntitiesServerTransport
NewEntitiesServerTransport creates a new instance of EntitiesServerTransport with the provided implementation. The returned EntitiesServerTransport instance is connected to an instance of armmanagementgroups.EntitiesClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type HierarchySettingsServer ¶
type HierarchySettingsServer struct {
// CreateOrUpdate is the fake for method HierarchySettingsClient.CreateOrUpdate
// HTTP status codes to indicate success: http.StatusOK
CreateOrUpdate func(ctx context.Context, groupID string, createTenantSettingsRequest armmanagementgroups.CreateOrUpdateSettingsRequest, options *armmanagementgroups.HierarchySettingsClientCreateOrUpdateOptions) (resp azfake.Responder[armmanagementgroups.HierarchySettingsClientCreateOrUpdateResponse], errResp azfake.ErrorResponder)
// Delete is the fake for method HierarchySettingsClient.Delete
// HTTP status codes to indicate success: http.StatusOK
Delete func(ctx context.Context, groupID string, options *armmanagementgroups.HierarchySettingsClientDeleteOptions) (resp azfake.Responder[armmanagementgroups.HierarchySettingsClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method HierarchySettingsClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, groupID string, options *armmanagementgroups.HierarchySettingsClientGetOptions) (resp azfake.Responder[armmanagementgroups.HierarchySettingsClientGetResponse], errResp azfake.ErrorResponder)
// List is the fake for method HierarchySettingsClient.List
// HTTP status codes to indicate success: http.StatusOK
List func(ctx context.Context, groupID string, options *armmanagementgroups.HierarchySettingsClientListOptions) (resp azfake.Responder[armmanagementgroups.HierarchySettingsClientListResponse], errResp azfake.ErrorResponder)
// Update is the fake for method HierarchySettingsClient.Update
// HTTP status codes to indicate success: http.StatusOK
Update func(ctx context.Context, groupID string, createTenantSettingsRequest armmanagementgroups.CreateOrUpdateSettingsRequest, options *armmanagementgroups.HierarchySettingsClientUpdateOptions) (resp azfake.Responder[armmanagementgroups.HierarchySettingsClientUpdateResponse], errResp azfake.ErrorResponder)
}
HierarchySettingsServer is a fake server for instances of the armmanagementgroups.HierarchySettingsClient type.
type HierarchySettingsServerTransport ¶
type HierarchySettingsServerTransport struct {
// contains filtered or unexported fields
}
HierarchySettingsServerTransport connects instances of armmanagementgroups.HierarchySettingsClient to instances of HierarchySettingsServer. Don't use this type directly, use NewHierarchySettingsServerTransport instead.
func NewHierarchySettingsServerTransport ¶
func NewHierarchySettingsServerTransport(srv *HierarchySettingsServer) *HierarchySettingsServerTransport
NewHierarchySettingsServerTransport creates a new instance of HierarchySettingsServerTransport with the provided implementation. The returned HierarchySettingsServerTransport instance is connected to an instance of armmanagementgroups.HierarchySettingsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type ManagementGroupSubscriptionsServer ¶
type ManagementGroupSubscriptionsServer struct {
// Create is the fake for method ManagementGroupSubscriptionsClient.Create
// HTTP status codes to indicate success: http.StatusOK
Create func(ctx context.Context, groupID string, subscriptionID string, options *armmanagementgroups.ManagementGroupSubscriptionsClientCreateOptions) (resp azfake.Responder[armmanagementgroups.ManagementGroupSubscriptionsClientCreateResponse], errResp azfake.ErrorResponder)
// Delete is the fake for method ManagementGroupSubscriptionsClient.Delete
// HTTP status codes to indicate success: http.StatusOK, http.StatusNoContent
Delete func(ctx context.Context, groupID string, subscriptionID string, options *armmanagementgroups.ManagementGroupSubscriptionsClientDeleteOptions) (resp azfake.Responder[armmanagementgroups.ManagementGroupSubscriptionsClientDeleteResponse], errResp azfake.ErrorResponder)
// GetSubscription is the fake for method ManagementGroupSubscriptionsClient.GetSubscription
// HTTP status codes to indicate success: http.StatusOK
GetSubscription func(ctx context.Context, groupID string, subscriptionID string, options *armmanagementgroups.ManagementGroupSubscriptionsClientGetSubscriptionOptions) (resp azfake.Responder[armmanagementgroups.ManagementGroupSubscriptionsClientGetSubscriptionResponse], errResp azfake.ErrorResponder)
// NewGetSubscriptionsUnderManagementGroupPager is the fake for method ManagementGroupSubscriptionsClient.NewGetSubscriptionsUnderManagementGroupPager
// HTTP status codes to indicate success: http.StatusOK
NewGetSubscriptionsUnderManagementGroupPager func(groupID string, options *armmanagementgroups.ManagementGroupSubscriptionsClientGetSubscriptionsUnderManagementGroupOptions) (resp azfake.PagerResponder[armmanagementgroups.ManagementGroupSubscriptionsClientGetSubscriptionsUnderManagementGroupResponse])
}
ManagementGroupSubscriptionsServer is a fake server for instances of the armmanagementgroups.ManagementGroupSubscriptionsClient type.
type ManagementGroupSubscriptionsServerTransport ¶
type ManagementGroupSubscriptionsServerTransport struct {
// contains filtered or unexported fields
}
ManagementGroupSubscriptionsServerTransport connects instances of armmanagementgroups.ManagementGroupSubscriptionsClient to instances of ManagementGroupSubscriptionsServer. Don't use this type directly, use NewManagementGroupSubscriptionsServerTransport instead.
func NewManagementGroupSubscriptionsServerTransport ¶
func NewManagementGroupSubscriptionsServerTransport(srv *ManagementGroupSubscriptionsServer) *ManagementGroupSubscriptionsServerTransport
NewManagementGroupSubscriptionsServerTransport creates a new instance of ManagementGroupSubscriptionsServerTransport with the provided implementation. The returned ManagementGroupSubscriptionsServerTransport instance is connected to an instance of armmanagementgroups.ManagementGroupSubscriptionsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type OperationsServer ¶
type OperationsServer struct {
// NewListPager is the fake for method OperationsClient.NewListPager
// HTTP status codes to indicate success: http.StatusOK
NewListPager func(options *armmanagementgroups.OperationsClientListOptions) (resp azfake.PagerResponder[armmanagementgroups.OperationsClientListResponse])
}
OperationsServer is a fake server for instances of the armmanagementgroups.OperationsClient type.
type OperationsServerTransport ¶
type OperationsServerTransport struct {
// contains filtered or unexported fields
}
OperationsServerTransport connects instances of armmanagementgroups.OperationsClient to instances of OperationsServer. Don't use this type directly, use NewOperationsServerTransport instead.
func NewOperationsServerTransport ¶
func NewOperationsServerTransport(srv *OperationsServer) *OperationsServerTransport
NewOperationsServerTransport creates a new instance of OperationsServerTransport with the provided implementation. The returned OperationsServerTransport instance is connected to an instance of armmanagementgroups.OperationsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type Server ¶
type Server struct {
// BeginCreateOrUpdate is the fake for method Client.BeginCreateOrUpdate
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginCreateOrUpdate func(ctx context.Context, groupID string, createManagementGroupRequest armmanagementgroups.CreateManagementGroupRequest, options *armmanagementgroups.ClientBeginCreateOrUpdateOptions) (resp azfake.PollerResponder[armmanagementgroups.ClientCreateOrUpdateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method Client.BeginDelete
// HTTP status codes to indicate success: http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, groupID string, options *armmanagementgroups.ClientBeginDeleteOptions) (resp azfake.PollerResponder[armmanagementgroups.ClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method Client.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, groupID string, options *armmanagementgroups.ClientGetOptions) (resp azfake.Responder[armmanagementgroups.ClientGetResponse], errResp azfake.ErrorResponder)
// NewGetDescendantsPager is the fake for method Client.NewGetDescendantsPager
// HTTP status codes to indicate success: http.StatusOK
NewGetDescendantsPager func(groupID string, options *armmanagementgroups.ClientGetDescendantsOptions) (resp azfake.PagerResponder[armmanagementgroups.ClientGetDescendantsResponse])
// NewListPager is the fake for method Client.NewListPager
// HTTP status codes to indicate success: http.StatusOK
NewListPager func(options *armmanagementgroups.ClientListOptions) (resp azfake.PagerResponder[armmanagementgroups.ClientListResponse])
// Update is the fake for method Client.Update
// HTTP status codes to indicate success: http.StatusOK
Update func(ctx context.Context, groupID string, patchGroupRequest armmanagementgroups.PatchManagementGroupRequest, options *armmanagementgroups.ClientUpdateOptions) (resp azfake.Responder[armmanagementgroups.ClientUpdateResponse], errResp azfake.ErrorResponder)
}
Server is a fake server for instances of the armmanagementgroups.Client type.
type ServerFactory ¶
type ServerFactory struct {
APIServer APIServer
Server Server
EntitiesServer EntitiesServer
HierarchySettingsServer HierarchySettingsServer
ManagementGroupSubscriptionsServer ManagementGroupSubscriptionsServer
OperationsServer OperationsServer
}
ServerFactory is a fake server for instances of the armmanagementgroups.ClientFactory type.
type ServerFactoryTransport ¶
type ServerFactoryTransport struct {
// contains filtered or unexported fields
}
ServerFactoryTransport connects instances of armmanagementgroups.ClientFactory to instances of ServerFactory. Don't use this type directly, use NewServerFactoryTransport instead.
func NewServerFactoryTransport ¶
func NewServerFactoryTransport(srv *ServerFactory) *ServerFactoryTransport
NewServerFactoryTransport creates a new instance of ServerFactoryTransport with the provided implementation. The returned ServerFactoryTransport instance is connected to an instance of armmanagementgroups.ClientFactory via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type ServerTransport ¶
type ServerTransport struct {
// contains filtered or unexported fields
}
ServerTransport connects instances of armmanagementgroups.Client to instances of Server. Don't use this type directly, use NewServerTransport instead.
func NewServerTransport ¶
func NewServerTransport(srv *Server) *ServerTransport
NewServerTransport creates a new instance of ServerTransport with the provided implementation. The returned ServerTransport instance is connected to an instance of armmanagementgroups.Client via the azcore.ClientOptions.Transporter field in the client's constructor parameters.