Documentation
¶
Index ¶
- type CloudEndpointsServer
- type CloudEndpointsServerTransport
- type MicrosoftStorageSyncServer
- type MicrosoftStorageSyncServerTransport
- type OperationStatusServer
- type OperationStatusServerTransport
- type OperationsServer
- type OperationsServerTransport
- type PrivateEndpointConnectionsServer
- type PrivateEndpointConnectionsServerTransport
- type PrivateLinkResourcesServer
- type PrivateLinkResourcesServerTransport
- type RegisteredServersServer
- type RegisteredServersServerTransport
- type ServerEndpointsServer
- type ServerEndpointsServerTransport
- type ServerFactory
- type ServerFactoryTransport
- type ServicesServer
- type ServicesServerTransport
- type SyncGroupsServer
- type SyncGroupsServerTransport
- type WorkflowsServer
- type WorkflowsServerTransport
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CloudEndpointsServer ¶
type CloudEndpointsServer struct {
// BeginCreate is the fake for method CloudEndpointsClient.BeginCreate
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginCreate func(ctx context.Context, resourceGroupName string, storageSyncServiceName string, syncGroupName string, cloudEndpointName string, parameters armstoragesync.CloudEndpointCreateParameters, options *armstoragesync.CloudEndpointsClientBeginCreateOptions) (resp azfake.PollerResponder[armstoragesync.CloudEndpointsClientCreateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method CloudEndpointsClient.BeginDelete
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, resourceGroupName string, storageSyncServiceName string, syncGroupName string, cloudEndpointName string, options *armstoragesync.CloudEndpointsClientBeginDeleteOptions) (resp azfake.PollerResponder[armstoragesync.CloudEndpointsClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method CloudEndpointsClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, storageSyncServiceName string, syncGroupName string, cloudEndpointName string, options *armstoragesync.CloudEndpointsClientGetOptions) (resp azfake.Responder[armstoragesync.CloudEndpointsClientGetResponse], errResp azfake.ErrorResponder)
// NewListBySyncGroupPager is the fake for method CloudEndpointsClient.NewListBySyncGroupPager
// HTTP status codes to indicate success: http.StatusOK
NewListBySyncGroupPager func(resourceGroupName string, storageSyncServiceName string, syncGroupName string, options *armstoragesync.CloudEndpointsClientListBySyncGroupOptions) (resp azfake.PagerResponder[armstoragesync.CloudEndpointsClientListBySyncGroupResponse])
// BeginPostBackup is the fake for method CloudEndpointsClient.BeginPostBackup
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginPostBackup func(ctx context.Context, resourceGroupName string, storageSyncServiceName string, syncGroupName string, cloudEndpointName string, parameters armstoragesync.BackupRequest, options *armstoragesync.CloudEndpointsClientBeginPostBackupOptions) (resp azfake.PollerResponder[armstoragesync.CloudEndpointsClientPostBackupResponse], errResp azfake.ErrorResponder)
// BeginPostRestore is the fake for method CloudEndpointsClient.BeginPostRestore
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginPostRestore func(ctx context.Context, resourceGroupName string, storageSyncServiceName string, syncGroupName string, cloudEndpointName string, parameters armstoragesync.PostRestoreRequest, options *armstoragesync.CloudEndpointsClientBeginPostRestoreOptions) (resp azfake.PollerResponder[armstoragesync.CloudEndpointsClientPostRestoreResponse], errResp azfake.ErrorResponder)
// BeginPreBackup is the fake for method CloudEndpointsClient.BeginPreBackup
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginPreBackup func(ctx context.Context, resourceGroupName string, storageSyncServiceName string, syncGroupName string, cloudEndpointName string, parameters armstoragesync.BackupRequest, options *armstoragesync.CloudEndpointsClientBeginPreBackupOptions) (resp azfake.PollerResponder[armstoragesync.CloudEndpointsClientPreBackupResponse], errResp azfake.ErrorResponder)
// BeginPreRestore is the fake for method CloudEndpointsClient.BeginPreRestore
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginPreRestore func(ctx context.Context, resourceGroupName string, storageSyncServiceName string, syncGroupName string, cloudEndpointName string, parameters armstoragesync.PreRestoreRequest, options *armstoragesync.CloudEndpointsClientBeginPreRestoreOptions) (resp azfake.PollerResponder[armstoragesync.CloudEndpointsClientPreRestoreResponse], errResp azfake.ErrorResponder)
// Restoreheartbeat is the fake for method CloudEndpointsClient.Restoreheartbeat
// HTTP status codes to indicate success: http.StatusOK
Restoreheartbeat func(ctx context.Context, resourceGroupName string, storageSyncServiceName string, syncGroupName string, cloudEndpointName string, options *armstoragesync.CloudEndpointsClientRestoreheartbeatOptions) (resp azfake.Responder[armstoragesync.CloudEndpointsClientRestoreheartbeatResponse], errResp azfake.ErrorResponder)
// BeginTriggerChangeDetection is the fake for method CloudEndpointsClient.BeginTriggerChangeDetection
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginTriggerChangeDetection func(ctx context.Context, resourceGroupName string, storageSyncServiceName string, syncGroupName string, cloudEndpointName string, parameters armstoragesync.TriggerChangeDetectionParameters, options *armstoragesync.CloudEndpointsClientBeginTriggerChangeDetectionOptions) (resp azfake.PollerResponder[armstoragesync.CloudEndpointsClientTriggerChangeDetectionResponse], errResp azfake.ErrorResponder)
}
CloudEndpointsServer is a fake server for instances of the armstoragesync.CloudEndpointsClient type.
type CloudEndpointsServerTransport ¶
type CloudEndpointsServerTransport struct {
// contains filtered or unexported fields
}
CloudEndpointsServerTransport connects instances of armstoragesync.CloudEndpointsClient to instances of CloudEndpointsServer. Don't use this type directly, use NewCloudEndpointsServerTransport instead.
func NewCloudEndpointsServerTransport ¶
func NewCloudEndpointsServerTransport(srv *CloudEndpointsServer) *CloudEndpointsServerTransport
NewCloudEndpointsServerTransport creates a new instance of CloudEndpointsServerTransport with the provided implementation. The returned CloudEndpointsServerTransport instance is connected to an instance of armstoragesync.CloudEndpointsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type MicrosoftStorageSyncServer ¶
type MicrosoftStorageSyncServer struct {
// LocationOperationStatus is the fake for method MicrosoftStorageSyncClient.LocationOperationStatus
// HTTP status codes to indicate success: http.StatusOK
LocationOperationStatus func(ctx context.Context, locationName string, operationID string, options *armstoragesync.MicrosoftStorageSyncClientLocationOperationStatusOptions) (resp azfake.Responder[armstoragesync.MicrosoftStorageSyncClientLocationOperationStatusResponse], errResp azfake.ErrorResponder)
}
MicrosoftStorageSyncServer is a fake server for instances of the armstoragesync.MicrosoftStorageSyncClient type.
type MicrosoftStorageSyncServerTransport ¶
type MicrosoftStorageSyncServerTransport struct {
// contains filtered or unexported fields
}
MicrosoftStorageSyncServerTransport connects instances of armstoragesync.MicrosoftStorageSyncClient to instances of MicrosoftStorageSyncServer. Don't use this type directly, use NewMicrosoftStorageSyncServerTransport instead.
func NewMicrosoftStorageSyncServerTransport ¶
func NewMicrosoftStorageSyncServerTransport(srv *MicrosoftStorageSyncServer) *MicrosoftStorageSyncServerTransport
NewMicrosoftStorageSyncServerTransport creates a new instance of MicrosoftStorageSyncServerTransport with the provided implementation. The returned MicrosoftStorageSyncServerTransport instance is connected to an instance of armstoragesync.MicrosoftStorageSyncClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type OperationStatusServer ¶
type OperationStatusServer struct {
// Get is the fake for method OperationStatusClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, locationName string, workflowID string, operationID string, options *armstoragesync.OperationStatusClientGetOptions) (resp azfake.Responder[armstoragesync.OperationStatusClientGetResponse], errResp azfake.ErrorResponder)
}
OperationStatusServer is a fake server for instances of the armstoragesync.OperationStatusClient type.
type OperationStatusServerTransport ¶
type OperationStatusServerTransport struct {
// contains filtered or unexported fields
}
OperationStatusServerTransport connects instances of armstoragesync.OperationStatusClient to instances of OperationStatusServer. Don't use this type directly, use NewOperationStatusServerTransport instead.
func NewOperationStatusServerTransport ¶
func NewOperationStatusServerTransport(srv *OperationStatusServer) *OperationStatusServerTransport
NewOperationStatusServerTransport creates a new instance of OperationStatusServerTransport with the provided implementation. The returned OperationStatusServerTransport instance is connected to an instance of armstoragesync.OperationStatusClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type OperationsServer ¶
type OperationsServer struct {
// NewListPager is the fake for method OperationsClient.NewListPager
// HTTP status codes to indicate success: http.StatusOK
NewListPager func(options *armstoragesync.OperationsClientListOptions) (resp azfake.PagerResponder[armstoragesync.OperationsClientListResponse])
}
OperationsServer is a fake server for instances of the armstoragesync.OperationsClient type.
type OperationsServerTransport ¶
type OperationsServerTransport struct {
// contains filtered or unexported fields
}
OperationsServerTransport connects instances of armstoragesync.OperationsClient to instances of OperationsServer. Don't use this type directly, use NewOperationsServerTransport instead.
func NewOperationsServerTransport ¶
func NewOperationsServerTransport(srv *OperationsServer) *OperationsServerTransport
NewOperationsServerTransport creates a new instance of OperationsServerTransport with the provided implementation. The returned OperationsServerTransport instance is connected to an instance of armstoragesync.OperationsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type PrivateEndpointConnectionsServer ¶
type PrivateEndpointConnectionsServer struct {
// BeginCreate is the fake for method PrivateEndpointConnectionsClient.BeginCreate
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginCreate func(ctx context.Context, resourceGroupName string, storageSyncServiceName string, privateEndpointConnectionName string, properties armstoragesync.PrivateEndpointConnection, options *armstoragesync.PrivateEndpointConnectionsClientBeginCreateOptions) (resp azfake.PollerResponder[armstoragesync.PrivateEndpointConnectionsClientCreateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method PrivateEndpointConnectionsClient.BeginDelete
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, resourceGroupName string, storageSyncServiceName string, privateEndpointConnectionName string, options *armstoragesync.PrivateEndpointConnectionsClientBeginDeleteOptions) (resp azfake.PollerResponder[armstoragesync.PrivateEndpointConnectionsClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method PrivateEndpointConnectionsClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, storageSyncServiceName string, privateEndpointConnectionName string, options *armstoragesync.PrivateEndpointConnectionsClientGetOptions) (resp azfake.Responder[armstoragesync.PrivateEndpointConnectionsClientGetResponse], errResp azfake.ErrorResponder)
// NewListByStorageSyncServicePager is the fake for method PrivateEndpointConnectionsClient.NewListByStorageSyncServicePager
// HTTP status codes to indicate success: http.StatusOK
NewListByStorageSyncServicePager func(resourceGroupName string, storageSyncServiceName string, options *armstoragesync.PrivateEndpointConnectionsClientListByStorageSyncServiceOptions) (resp azfake.PagerResponder[armstoragesync.PrivateEndpointConnectionsClientListByStorageSyncServiceResponse])
}
PrivateEndpointConnectionsServer is a fake server for instances of the armstoragesync.PrivateEndpointConnectionsClient type.
type PrivateEndpointConnectionsServerTransport ¶
type PrivateEndpointConnectionsServerTransport struct {
// contains filtered or unexported fields
}
PrivateEndpointConnectionsServerTransport connects instances of armstoragesync.PrivateEndpointConnectionsClient to instances of PrivateEndpointConnectionsServer. Don't use this type directly, use NewPrivateEndpointConnectionsServerTransport instead.
func NewPrivateEndpointConnectionsServerTransport ¶
func NewPrivateEndpointConnectionsServerTransport(srv *PrivateEndpointConnectionsServer) *PrivateEndpointConnectionsServerTransport
NewPrivateEndpointConnectionsServerTransport creates a new instance of PrivateEndpointConnectionsServerTransport with the provided implementation. The returned PrivateEndpointConnectionsServerTransport instance is connected to an instance of armstoragesync.PrivateEndpointConnectionsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type PrivateLinkResourcesServer ¶
type PrivateLinkResourcesServer struct {
// ListByStorageSyncService is the fake for method PrivateLinkResourcesClient.ListByStorageSyncService
// HTTP status codes to indicate success: http.StatusOK
ListByStorageSyncService func(ctx context.Context, resourceGroupName string, storageSyncServiceName string, options *armstoragesync.PrivateLinkResourcesClientListByStorageSyncServiceOptions) (resp azfake.Responder[armstoragesync.PrivateLinkResourcesClientListByStorageSyncServiceResponse], errResp azfake.ErrorResponder)
}
PrivateLinkResourcesServer is a fake server for instances of the armstoragesync.PrivateLinkResourcesClient type.
type PrivateLinkResourcesServerTransport ¶
type PrivateLinkResourcesServerTransport struct {
// contains filtered or unexported fields
}
PrivateLinkResourcesServerTransport connects instances of armstoragesync.PrivateLinkResourcesClient to instances of PrivateLinkResourcesServer. Don't use this type directly, use NewPrivateLinkResourcesServerTransport instead.
func NewPrivateLinkResourcesServerTransport ¶
func NewPrivateLinkResourcesServerTransport(srv *PrivateLinkResourcesServer) *PrivateLinkResourcesServerTransport
NewPrivateLinkResourcesServerTransport creates a new instance of PrivateLinkResourcesServerTransport with the provided implementation. The returned PrivateLinkResourcesServerTransport instance is connected to an instance of armstoragesync.PrivateLinkResourcesClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type RegisteredServersServer ¶
type RegisteredServersServer struct {
// BeginCreate is the fake for method RegisteredServersClient.BeginCreate
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginCreate func(ctx context.Context, resourceGroupName string, storageSyncServiceName string, serverID string, parameters armstoragesync.RegisteredServerCreateParameters, options *armstoragesync.RegisteredServersClientBeginCreateOptions) (resp azfake.PollerResponder[armstoragesync.RegisteredServersClientCreateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method RegisteredServersClient.BeginDelete
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, resourceGroupName string, storageSyncServiceName string, serverID string, options *armstoragesync.RegisteredServersClientBeginDeleteOptions) (resp azfake.PollerResponder[armstoragesync.RegisteredServersClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method RegisteredServersClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, storageSyncServiceName string, serverID string, options *armstoragesync.RegisteredServersClientGetOptions) (resp azfake.Responder[armstoragesync.RegisteredServersClientGetResponse], errResp azfake.ErrorResponder)
// NewListByStorageSyncServicePager is the fake for method RegisteredServersClient.NewListByStorageSyncServicePager
// HTTP status codes to indicate success: http.StatusOK
NewListByStorageSyncServicePager func(resourceGroupName string, storageSyncServiceName string, options *armstoragesync.RegisteredServersClientListByStorageSyncServiceOptions) (resp azfake.PagerResponder[armstoragesync.RegisteredServersClientListByStorageSyncServiceResponse])
// BeginTriggerRollover is the fake for method RegisteredServersClient.BeginTriggerRollover
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginTriggerRollover func(ctx context.Context, resourceGroupName string, storageSyncServiceName string, serverID string, parameters armstoragesync.TriggerRolloverRequest, options *armstoragesync.RegisteredServersClientBeginTriggerRolloverOptions) (resp azfake.PollerResponder[armstoragesync.RegisteredServersClientTriggerRolloverResponse], errResp azfake.ErrorResponder)
}
RegisteredServersServer is a fake server for instances of the armstoragesync.RegisteredServersClient type.
type RegisteredServersServerTransport ¶
type RegisteredServersServerTransport struct {
// contains filtered or unexported fields
}
RegisteredServersServerTransport connects instances of armstoragesync.RegisteredServersClient to instances of RegisteredServersServer. Don't use this type directly, use NewRegisteredServersServerTransport instead.
func NewRegisteredServersServerTransport ¶
func NewRegisteredServersServerTransport(srv *RegisteredServersServer) *RegisteredServersServerTransport
NewRegisteredServersServerTransport creates a new instance of RegisteredServersServerTransport with the provided implementation. The returned RegisteredServersServerTransport instance is connected to an instance of armstoragesync.RegisteredServersClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type ServerEndpointsServer ¶
type ServerEndpointsServer struct {
// BeginCreate is the fake for method ServerEndpointsClient.BeginCreate
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginCreate func(ctx context.Context, resourceGroupName string, storageSyncServiceName string, syncGroupName string, serverEndpointName string, parameters armstoragesync.ServerEndpointCreateParameters, options *armstoragesync.ServerEndpointsClientBeginCreateOptions) (resp azfake.PollerResponder[armstoragesync.ServerEndpointsClientCreateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method ServerEndpointsClient.BeginDelete
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginDelete func(ctx context.Context, resourceGroupName string, storageSyncServiceName string, syncGroupName string, serverEndpointName string, options *armstoragesync.ServerEndpointsClientBeginDeleteOptions) (resp azfake.PollerResponder[armstoragesync.ServerEndpointsClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method ServerEndpointsClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, storageSyncServiceName string, syncGroupName string, serverEndpointName string, options *armstoragesync.ServerEndpointsClientGetOptions) (resp azfake.Responder[armstoragesync.ServerEndpointsClientGetResponse], errResp azfake.ErrorResponder)
// NewListBySyncGroupPager is the fake for method ServerEndpointsClient.NewListBySyncGroupPager
// HTTP status codes to indicate success: http.StatusOK
NewListBySyncGroupPager func(resourceGroupName string, storageSyncServiceName string, syncGroupName string, options *armstoragesync.ServerEndpointsClientListBySyncGroupOptions) (resp azfake.PagerResponder[armstoragesync.ServerEndpointsClientListBySyncGroupResponse])
// BeginRecallAction is the fake for method ServerEndpointsClient.BeginRecallAction
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginRecallAction func(ctx context.Context, resourceGroupName string, storageSyncServiceName string, syncGroupName string, serverEndpointName string, parameters armstoragesync.RecallActionParameters, options *armstoragesync.ServerEndpointsClientBeginRecallActionOptions) (resp azfake.PollerResponder[armstoragesync.ServerEndpointsClientRecallActionResponse], errResp azfake.ErrorResponder)
// BeginUpdate is the fake for method ServerEndpointsClient.BeginUpdate
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginUpdate func(ctx context.Context, resourceGroupName string, storageSyncServiceName string, syncGroupName string, serverEndpointName string, options *armstoragesync.ServerEndpointsClientBeginUpdateOptions) (resp azfake.PollerResponder[armstoragesync.ServerEndpointsClientUpdateResponse], errResp azfake.ErrorResponder)
}
ServerEndpointsServer is a fake server for instances of the armstoragesync.ServerEndpointsClient type.
type ServerEndpointsServerTransport ¶
type ServerEndpointsServerTransport struct {
// contains filtered or unexported fields
}
ServerEndpointsServerTransport connects instances of armstoragesync.ServerEndpointsClient to instances of ServerEndpointsServer. Don't use this type directly, use NewServerEndpointsServerTransport instead.
func NewServerEndpointsServerTransport ¶
func NewServerEndpointsServerTransport(srv *ServerEndpointsServer) *ServerEndpointsServerTransport
NewServerEndpointsServerTransport creates a new instance of ServerEndpointsServerTransport with the provided implementation. The returned ServerEndpointsServerTransport instance is connected to an instance of armstoragesync.ServerEndpointsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type ServerFactory ¶
type ServerFactory struct {
CloudEndpointsServer CloudEndpointsServer
MicrosoftStorageSyncServer MicrosoftStorageSyncServer
OperationStatusServer OperationStatusServer
OperationsServer OperationsServer
PrivateEndpointConnectionsServer PrivateEndpointConnectionsServer
PrivateLinkResourcesServer PrivateLinkResourcesServer
RegisteredServersServer RegisteredServersServer
ServerEndpointsServer ServerEndpointsServer
ServicesServer ServicesServer
SyncGroupsServer SyncGroupsServer
WorkflowsServer WorkflowsServer
}
ServerFactory is a fake server for instances of the armstoragesync.ClientFactory type.
type ServerFactoryTransport ¶
type ServerFactoryTransport struct {
// contains filtered or unexported fields
}
ServerFactoryTransport connects instances of armstoragesync.ClientFactory to instances of ServerFactory. Don't use this type directly, use NewServerFactoryTransport instead.
func NewServerFactoryTransport ¶
func NewServerFactoryTransport(srv *ServerFactory) *ServerFactoryTransport
NewServerFactoryTransport creates a new instance of ServerFactoryTransport with the provided implementation. The returned ServerFactoryTransport instance is connected to an instance of armstoragesync.ClientFactory via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type ServicesServer ¶
type ServicesServer struct {
// CheckNameAvailability is the fake for method ServicesClient.CheckNameAvailability
// HTTP status codes to indicate success: http.StatusOK
CheckNameAvailability func(ctx context.Context, locationName string, parameters armstoragesync.CheckNameAvailabilityParameters, options *armstoragesync.ServicesClientCheckNameAvailabilityOptions) (resp azfake.Responder[armstoragesync.ServicesClientCheckNameAvailabilityResponse], errResp azfake.ErrorResponder)
// BeginCreate is the fake for method ServicesClient.BeginCreate
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginCreate func(ctx context.Context, resourceGroupName string, storageSyncServiceName string, parameters armstoragesync.ServiceCreateParameters, options *armstoragesync.ServicesClientBeginCreateOptions) (resp azfake.PollerResponder[armstoragesync.ServicesClientCreateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method ServicesClient.BeginDelete
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, resourceGroupName string, storageSyncServiceName string, options *armstoragesync.ServicesClientBeginDeleteOptions) (resp azfake.PollerResponder[armstoragesync.ServicesClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method ServicesClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, storageSyncServiceName string, options *armstoragesync.ServicesClientGetOptions) (resp azfake.Responder[armstoragesync.ServicesClientGetResponse], errResp azfake.ErrorResponder)
// NewListByResourceGroupPager is the fake for method ServicesClient.NewListByResourceGroupPager
// HTTP status codes to indicate success: http.StatusOK
NewListByResourceGroupPager func(resourceGroupName string, options *armstoragesync.ServicesClientListByResourceGroupOptions) (resp azfake.PagerResponder[armstoragesync.ServicesClientListByResourceGroupResponse])
// NewListBySubscriptionPager is the fake for method ServicesClient.NewListBySubscriptionPager
// HTTP status codes to indicate success: http.StatusOK
NewListBySubscriptionPager func(options *armstoragesync.ServicesClientListBySubscriptionOptions) (resp azfake.PagerResponder[armstoragesync.ServicesClientListBySubscriptionResponse])
// BeginUpdate is the fake for method ServicesClient.BeginUpdate
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginUpdate func(ctx context.Context, resourceGroupName string, storageSyncServiceName string, options *armstoragesync.ServicesClientBeginUpdateOptions) (resp azfake.PollerResponder[armstoragesync.ServicesClientUpdateResponse], errResp azfake.ErrorResponder)
}
ServicesServer is a fake server for instances of the armstoragesync.ServicesClient type.
type ServicesServerTransport ¶
type ServicesServerTransport struct {
// contains filtered or unexported fields
}
ServicesServerTransport connects instances of armstoragesync.ServicesClient to instances of ServicesServer. Don't use this type directly, use NewServicesServerTransport instead.
func NewServicesServerTransport ¶
func NewServicesServerTransport(srv *ServicesServer) *ServicesServerTransport
NewServicesServerTransport creates a new instance of ServicesServerTransport with the provided implementation. The returned ServicesServerTransport instance is connected to an instance of armstoragesync.ServicesClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type SyncGroupsServer ¶
type SyncGroupsServer struct {
// Create is the fake for method SyncGroupsClient.Create
// HTTP status codes to indicate success: http.StatusOK
Create func(ctx context.Context, resourceGroupName string, storageSyncServiceName string, syncGroupName string, parameters armstoragesync.SyncGroupCreateParameters, options *armstoragesync.SyncGroupsClientCreateOptions) (resp azfake.Responder[armstoragesync.SyncGroupsClientCreateResponse], errResp azfake.ErrorResponder)
// Delete is the fake for method SyncGroupsClient.Delete
// HTTP status codes to indicate success: http.StatusOK, http.StatusNoContent
Delete func(ctx context.Context, resourceGroupName string, storageSyncServiceName string, syncGroupName string, options *armstoragesync.SyncGroupsClientDeleteOptions) (resp azfake.Responder[armstoragesync.SyncGroupsClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method SyncGroupsClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, storageSyncServiceName string, syncGroupName string, options *armstoragesync.SyncGroupsClientGetOptions) (resp azfake.Responder[armstoragesync.SyncGroupsClientGetResponse], errResp azfake.ErrorResponder)
// NewListByStorageSyncServicePager is the fake for method SyncGroupsClient.NewListByStorageSyncServicePager
// HTTP status codes to indicate success: http.StatusOK
NewListByStorageSyncServicePager func(resourceGroupName string, storageSyncServiceName string, options *armstoragesync.SyncGroupsClientListByStorageSyncServiceOptions) (resp azfake.PagerResponder[armstoragesync.SyncGroupsClientListByStorageSyncServiceResponse])
}
SyncGroupsServer is a fake server for instances of the armstoragesync.SyncGroupsClient type.
type SyncGroupsServerTransport ¶
type SyncGroupsServerTransport struct {
// contains filtered or unexported fields
}
SyncGroupsServerTransport connects instances of armstoragesync.SyncGroupsClient to instances of SyncGroupsServer. Don't use this type directly, use NewSyncGroupsServerTransport instead.
func NewSyncGroupsServerTransport ¶
func NewSyncGroupsServerTransport(srv *SyncGroupsServer) *SyncGroupsServerTransport
NewSyncGroupsServerTransport creates a new instance of SyncGroupsServerTransport with the provided implementation. The returned SyncGroupsServerTransport instance is connected to an instance of armstoragesync.SyncGroupsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type WorkflowsServer ¶
type WorkflowsServer struct {
// Abort is the fake for method WorkflowsClient.Abort
// HTTP status codes to indicate success: http.StatusOK
Abort func(ctx context.Context, resourceGroupName string, storageSyncServiceName string, workflowID string, options *armstoragesync.WorkflowsClientAbortOptions) (resp azfake.Responder[armstoragesync.WorkflowsClientAbortResponse], errResp azfake.ErrorResponder)
// Get is the fake for method WorkflowsClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, storageSyncServiceName string, workflowID string, options *armstoragesync.WorkflowsClientGetOptions) (resp azfake.Responder[armstoragesync.WorkflowsClientGetResponse], errResp azfake.ErrorResponder)
// NewListByStorageSyncServicePager is the fake for method WorkflowsClient.NewListByStorageSyncServicePager
// HTTP status codes to indicate success: http.StatusOK
NewListByStorageSyncServicePager func(resourceGroupName string, storageSyncServiceName string, options *armstoragesync.WorkflowsClientListByStorageSyncServiceOptions) (resp azfake.PagerResponder[armstoragesync.WorkflowsClientListByStorageSyncServiceResponse])
}
WorkflowsServer is a fake server for instances of the armstoragesync.WorkflowsClient type.
type WorkflowsServerTransport ¶
type WorkflowsServerTransport struct {
// contains filtered or unexported fields
}
WorkflowsServerTransport connects instances of armstoragesync.WorkflowsClient to instances of WorkflowsServer. Don't use this type directly, use NewWorkflowsServerTransport instead.
func NewWorkflowsServerTransport ¶
func NewWorkflowsServerTransport(srv *WorkflowsServer) *WorkflowsServerTransport
NewWorkflowsServerTransport creates a new instance of WorkflowsServerTransport with the provided implementation. The returned WorkflowsServerTransport instance is connected to an instance of armstoragesync.WorkflowsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
Source Files
¶
- cloudendpoints_server.go
- internal.go
- microsoftstoragesync_server.go
- operations_server.go
- operationstatus_server.go
- privateendpointconnections_server.go
- privatelinkresources_server.go
- registeredservers_server.go
- server_factory.go
- serverendpoints_server.go
- services_server.go
- syncgroups_server.go
- time_rfc3339.go
- workflows_server.go