Documentation
¶
Index ¶
- type OperationsServer
- type OperationsServerTransport
- type SAPApplicationServerInstancesServer
- type SAPApplicationServerInstancesServerTransport
- type SAPCentralInstancesServer
- type SAPCentralInstancesServerTransport
- type SAPDatabaseInstancesServer
- type SAPDatabaseInstancesServerTransport
- type SAPVirtualInstancesServer
- type SAPVirtualInstancesServerTransport
- type ServerFactory
- type ServerFactoryTransport
- type WorkloadsServer
- type WorkloadsServerTransport
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type OperationsServer ¶
type OperationsServer struct {
// NewListPager is the fake for method OperationsClient.NewListPager
// HTTP status codes to indicate success: http.StatusOK
NewListPager func(options *armworkloadssapvirtualinstance.OperationsClientListOptions) (resp azfake.PagerResponder[armworkloadssapvirtualinstance.OperationsClientListResponse])
}
OperationsServer is a fake server for instances of the armworkloadssapvirtualinstance.OperationsClient type.
type OperationsServerTransport ¶
type OperationsServerTransport struct {
// contains filtered or unexported fields
}
OperationsServerTransport connects instances of armworkloadssapvirtualinstance.OperationsClient to instances of OperationsServer. Don't use this type directly, use NewOperationsServerTransport instead.
func NewOperationsServerTransport ¶
func NewOperationsServerTransport(srv *OperationsServer) *OperationsServerTransport
NewOperationsServerTransport creates a new instance of OperationsServerTransport with the provided implementation. The returned OperationsServerTransport instance is connected to an instance of armworkloadssapvirtualinstance.OperationsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type SAPApplicationServerInstancesServer ¶
type SAPApplicationServerInstancesServer struct {
// BeginCreate is the fake for method SAPApplicationServerInstancesClient.BeginCreate
// HTTP status codes to indicate success: http.StatusOK, http.StatusCreated
BeginCreate func(ctx context.Context, resourceGroupName string, sapVirtualInstanceName string, applicationInstanceName string, body armworkloadssapvirtualinstance.SAPApplicationServerInstance, options *armworkloadssapvirtualinstance.SAPApplicationServerInstancesClientBeginCreateOptions) (resp azfake.PollerResponder[armworkloadssapvirtualinstance.SAPApplicationServerInstancesClientCreateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method SAPApplicationServerInstancesClient.BeginDelete
// HTTP status codes to indicate success: http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, resourceGroupName string, sapVirtualInstanceName string, applicationInstanceName string, options *armworkloadssapvirtualinstance.SAPApplicationServerInstancesClientBeginDeleteOptions) (resp azfake.PollerResponder[armworkloadssapvirtualinstance.SAPApplicationServerInstancesClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method SAPApplicationServerInstancesClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, sapVirtualInstanceName string, applicationInstanceName string, options *armworkloadssapvirtualinstance.SAPApplicationServerInstancesClientGetOptions) (resp azfake.Responder[armworkloadssapvirtualinstance.SAPApplicationServerInstancesClientGetResponse], errResp azfake.ErrorResponder)
// NewListPager is the fake for method SAPApplicationServerInstancesClient.NewListPager
// HTTP status codes to indicate success: http.StatusOK
NewListPager func(resourceGroupName string, sapVirtualInstanceName string, options *armworkloadssapvirtualinstance.SAPApplicationServerInstancesClientListOptions) (resp azfake.PagerResponder[armworkloadssapvirtualinstance.SAPApplicationServerInstancesClientListResponse])
// BeginStartInstance is the fake for method SAPApplicationServerInstancesClient.BeginStartInstance
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginStartInstance func(ctx context.Context, resourceGroupName string, sapVirtualInstanceName string, applicationInstanceName string, options *armworkloadssapvirtualinstance.SAPApplicationServerInstancesClientBeginStartInstanceOptions) (resp azfake.PollerResponder[armworkloadssapvirtualinstance.SAPApplicationServerInstancesClientStartInstanceResponse], errResp azfake.ErrorResponder)
// BeginStopInstance is the fake for method SAPApplicationServerInstancesClient.BeginStopInstance
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginStopInstance func(ctx context.Context, resourceGroupName string, sapVirtualInstanceName string, applicationInstanceName string, options *armworkloadssapvirtualinstance.SAPApplicationServerInstancesClientBeginStopInstanceOptions) (resp azfake.PollerResponder[armworkloadssapvirtualinstance.SAPApplicationServerInstancesClientStopInstanceResponse], errResp azfake.ErrorResponder)
// Update is the fake for method SAPApplicationServerInstancesClient.Update
// HTTP status codes to indicate success: http.StatusOK
Update func(ctx context.Context, resourceGroupName string, sapVirtualInstanceName string, applicationInstanceName string, body armworkloadssapvirtualinstance.UpdateSAPApplicationInstanceRequest, options *armworkloadssapvirtualinstance.SAPApplicationServerInstancesClientUpdateOptions) (resp azfake.Responder[armworkloadssapvirtualinstance.SAPApplicationServerInstancesClientUpdateResponse], errResp azfake.ErrorResponder)
}
SAPApplicationServerInstancesServer is a fake server for instances of the armworkloadssapvirtualinstance.SAPApplicationServerInstancesClient type.
type SAPApplicationServerInstancesServerTransport ¶
type SAPApplicationServerInstancesServerTransport struct {
// contains filtered or unexported fields
}
SAPApplicationServerInstancesServerTransport connects instances of armworkloadssapvirtualinstance.SAPApplicationServerInstancesClient to instances of SAPApplicationServerInstancesServer. Don't use this type directly, use NewSAPApplicationServerInstancesServerTransport instead.
func NewSAPApplicationServerInstancesServerTransport ¶
func NewSAPApplicationServerInstancesServerTransport(srv *SAPApplicationServerInstancesServer) *SAPApplicationServerInstancesServerTransport
NewSAPApplicationServerInstancesServerTransport creates a new instance of SAPApplicationServerInstancesServerTransport with the provided implementation. The returned SAPApplicationServerInstancesServerTransport instance is connected to an instance of armworkloadssapvirtualinstance.SAPApplicationServerInstancesClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type SAPCentralInstancesServer ¶
type SAPCentralInstancesServer struct {
// BeginCreate is the fake for method SAPCentralInstancesClient.BeginCreate
// HTTP status codes to indicate success: http.StatusOK, http.StatusCreated
BeginCreate func(ctx context.Context, resourceGroupName string, sapVirtualInstanceName string, centralInstanceName string, body armworkloadssapvirtualinstance.SAPCentralServerInstance, options *armworkloadssapvirtualinstance.SAPCentralInstancesClientBeginCreateOptions) (resp azfake.PollerResponder[armworkloadssapvirtualinstance.SAPCentralInstancesClientCreateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method SAPCentralInstancesClient.BeginDelete
// HTTP status codes to indicate success: http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, resourceGroupName string, sapVirtualInstanceName string, centralInstanceName string, options *armworkloadssapvirtualinstance.SAPCentralInstancesClientBeginDeleteOptions) (resp azfake.PollerResponder[armworkloadssapvirtualinstance.SAPCentralInstancesClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method SAPCentralInstancesClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, sapVirtualInstanceName string, centralInstanceName string, options *armworkloadssapvirtualinstance.SAPCentralInstancesClientGetOptions) (resp azfake.Responder[armworkloadssapvirtualinstance.SAPCentralInstancesClientGetResponse], errResp azfake.ErrorResponder)
// NewListPager is the fake for method SAPCentralInstancesClient.NewListPager
// HTTP status codes to indicate success: http.StatusOK
NewListPager func(resourceGroupName string, sapVirtualInstanceName string, options *armworkloadssapvirtualinstance.SAPCentralInstancesClientListOptions) (resp azfake.PagerResponder[armworkloadssapvirtualinstance.SAPCentralInstancesClientListResponse])
// BeginStartInstance is the fake for method SAPCentralInstancesClient.BeginStartInstance
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginStartInstance func(ctx context.Context, resourceGroupName string, sapVirtualInstanceName string, centralInstanceName string, options *armworkloadssapvirtualinstance.SAPCentralInstancesClientBeginStartInstanceOptions) (resp azfake.PollerResponder[armworkloadssapvirtualinstance.SAPCentralInstancesClientStartInstanceResponse], errResp azfake.ErrorResponder)
// BeginStopInstance is the fake for method SAPCentralInstancesClient.BeginStopInstance
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginStopInstance func(ctx context.Context, resourceGroupName string, sapVirtualInstanceName string, centralInstanceName string, options *armworkloadssapvirtualinstance.SAPCentralInstancesClientBeginStopInstanceOptions) (resp azfake.PollerResponder[armworkloadssapvirtualinstance.SAPCentralInstancesClientStopInstanceResponse], errResp azfake.ErrorResponder)
// Update is the fake for method SAPCentralInstancesClient.Update
// HTTP status codes to indicate success: http.StatusOK
Update func(ctx context.Context, resourceGroupName string, sapVirtualInstanceName string, centralInstanceName string, body armworkloadssapvirtualinstance.UpdateSAPCentralInstanceRequest, options *armworkloadssapvirtualinstance.SAPCentralInstancesClientUpdateOptions) (resp azfake.Responder[armworkloadssapvirtualinstance.SAPCentralInstancesClientUpdateResponse], errResp azfake.ErrorResponder)
}
SAPCentralInstancesServer is a fake server for instances of the armworkloadssapvirtualinstance.SAPCentralInstancesClient type.
type SAPCentralInstancesServerTransport ¶
type SAPCentralInstancesServerTransport struct {
// contains filtered or unexported fields
}
SAPCentralInstancesServerTransport connects instances of armworkloadssapvirtualinstance.SAPCentralInstancesClient to instances of SAPCentralInstancesServer. Don't use this type directly, use NewSAPCentralInstancesServerTransport instead.
func NewSAPCentralInstancesServerTransport ¶
func NewSAPCentralInstancesServerTransport(srv *SAPCentralInstancesServer) *SAPCentralInstancesServerTransport
NewSAPCentralInstancesServerTransport creates a new instance of SAPCentralInstancesServerTransport with the provided implementation. The returned SAPCentralInstancesServerTransport instance is connected to an instance of armworkloadssapvirtualinstance.SAPCentralInstancesClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type SAPDatabaseInstancesServer ¶
type SAPDatabaseInstancesServer struct {
// BeginCreate is the fake for method SAPDatabaseInstancesClient.BeginCreate
// HTTP status codes to indicate success: http.StatusOK, http.StatusCreated
BeginCreate func(ctx context.Context, resourceGroupName string, sapVirtualInstanceName string, databaseInstanceName string, body armworkloadssapvirtualinstance.SAPDatabaseInstance, options *armworkloadssapvirtualinstance.SAPDatabaseInstancesClientBeginCreateOptions) (resp azfake.PollerResponder[armworkloadssapvirtualinstance.SAPDatabaseInstancesClientCreateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method SAPDatabaseInstancesClient.BeginDelete
// HTTP status codes to indicate success: http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, resourceGroupName string, sapVirtualInstanceName string, databaseInstanceName string, options *armworkloadssapvirtualinstance.SAPDatabaseInstancesClientBeginDeleteOptions) (resp azfake.PollerResponder[armworkloadssapvirtualinstance.SAPDatabaseInstancesClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method SAPDatabaseInstancesClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, sapVirtualInstanceName string, databaseInstanceName string, options *armworkloadssapvirtualinstance.SAPDatabaseInstancesClientGetOptions) (resp azfake.Responder[armworkloadssapvirtualinstance.SAPDatabaseInstancesClientGetResponse], errResp azfake.ErrorResponder)
// NewListPager is the fake for method SAPDatabaseInstancesClient.NewListPager
// HTTP status codes to indicate success: http.StatusOK
NewListPager func(resourceGroupName string, sapVirtualInstanceName string, options *armworkloadssapvirtualinstance.SAPDatabaseInstancesClientListOptions) (resp azfake.PagerResponder[armworkloadssapvirtualinstance.SAPDatabaseInstancesClientListResponse])
// BeginStartInstance is the fake for method SAPDatabaseInstancesClient.BeginStartInstance
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginStartInstance func(ctx context.Context, resourceGroupName string, sapVirtualInstanceName string, databaseInstanceName string, options *armworkloadssapvirtualinstance.SAPDatabaseInstancesClientBeginStartInstanceOptions) (resp azfake.PollerResponder[armworkloadssapvirtualinstance.SAPDatabaseInstancesClientStartInstanceResponse], errResp azfake.ErrorResponder)
// BeginStopInstance is the fake for method SAPDatabaseInstancesClient.BeginStopInstance
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginStopInstance func(ctx context.Context, resourceGroupName string, sapVirtualInstanceName string, databaseInstanceName string, options *armworkloadssapvirtualinstance.SAPDatabaseInstancesClientBeginStopInstanceOptions) (resp azfake.PollerResponder[armworkloadssapvirtualinstance.SAPDatabaseInstancesClientStopInstanceResponse], errResp azfake.ErrorResponder)
// Update is the fake for method SAPDatabaseInstancesClient.Update
// HTTP status codes to indicate success: http.StatusOK
Update func(ctx context.Context, resourceGroupName string, sapVirtualInstanceName string, databaseInstanceName string, body armworkloadssapvirtualinstance.UpdateSAPDatabaseInstanceRequest, options *armworkloadssapvirtualinstance.SAPDatabaseInstancesClientUpdateOptions) (resp azfake.Responder[armworkloadssapvirtualinstance.SAPDatabaseInstancesClientUpdateResponse], errResp azfake.ErrorResponder)
}
SAPDatabaseInstancesServer is a fake server for instances of the armworkloadssapvirtualinstance.SAPDatabaseInstancesClient type.
type SAPDatabaseInstancesServerTransport ¶
type SAPDatabaseInstancesServerTransport struct {
// contains filtered or unexported fields
}
SAPDatabaseInstancesServerTransport connects instances of armworkloadssapvirtualinstance.SAPDatabaseInstancesClient to instances of SAPDatabaseInstancesServer. Don't use this type directly, use NewSAPDatabaseInstancesServerTransport instead.
func NewSAPDatabaseInstancesServerTransport ¶
func NewSAPDatabaseInstancesServerTransport(srv *SAPDatabaseInstancesServer) *SAPDatabaseInstancesServerTransport
NewSAPDatabaseInstancesServerTransport creates a new instance of SAPDatabaseInstancesServerTransport with the provided implementation. The returned SAPDatabaseInstancesServerTransport instance is connected to an instance of armworkloadssapvirtualinstance.SAPDatabaseInstancesClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type SAPVirtualInstancesServer ¶
type SAPVirtualInstancesServer struct {
// BeginCreate is the fake for method SAPVirtualInstancesClient.BeginCreate
// HTTP status codes to indicate success: http.StatusOK, http.StatusCreated
BeginCreate func(ctx context.Context, resourceGroupName string, sapVirtualInstanceName string, body armworkloadssapvirtualinstance.SAPVirtualInstance, options *armworkloadssapvirtualinstance.SAPVirtualInstancesClientBeginCreateOptions) (resp azfake.PollerResponder[armworkloadssapvirtualinstance.SAPVirtualInstancesClientCreateResponse], errResp azfake.ErrorResponder)
// BeginDelete is the fake for method SAPVirtualInstancesClient.BeginDelete
// HTTP status codes to indicate success: http.StatusAccepted, http.StatusNoContent
BeginDelete func(ctx context.Context, resourceGroupName string, sapVirtualInstanceName string, options *armworkloadssapvirtualinstance.SAPVirtualInstancesClientBeginDeleteOptions) (resp azfake.PollerResponder[armworkloadssapvirtualinstance.SAPVirtualInstancesClientDeleteResponse], errResp azfake.ErrorResponder)
// Get is the fake for method SAPVirtualInstancesClient.Get
// HTTP status codes to indicate success: http.StatusOK
Get func(ctx context.Context, resourceGroupName string, sapVirtualInstanceName string, options *armworkloadssapvirtualinstance.SAPVirtualInstancesClientGetOptions) (resp azfake.Responder[armworkloadssapvirtualinstance.SAPVirtualInstancesClientGetResponse], errResp azfake.ErrorResponder)
// NewListByResourceGroupPager is the fake for method SAPVirtualInstancesClient.NewListByResourceGroupPager
// HTTP status codes to indicate success: http.StatusOK
NewListByResourceGroupPager func(resourceGroupName string, options *armworkloadssapvirtualinstance.SAPVirtualInstancesClientListByResourceGroupOptions) (resp azfake.PagerResponder[armworkloadssapvirtualinstance.SAPVirtualInstancesClientListByResourceGroupResponse])
// NewListBySubscriptionPager is the fake for method SAPVirtualInstancesClient.NewListBySubscriptionPager
// HTTP status codes to indicate success: http.StatusOK
NewListBySubscriptionPager func(options *armworkloadssapvirtualinstance.SAPVirtualInstancesClientListBySubscriptionOptions) (resp azfake.PagerResponder[armworkloadssapvirtualinstance.SAPVirtualInstancesClientListBySubscriptionResponse])
// BeginStart is the fake for method SAPVirtualInstancesClient.BeginStart
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginStart func(ctx context.Context, resourceGroupName string, sapVirtualInstanceName string, options *armworkloadssapvirtualinstance.SAPVirtualInstancesClientBeginStartOptions) (resp azfake.PollerResponder[armworkloadssapvirtualinstance.SAPVirtualInstancesClientStartResponse], errResp azfake.ErrorResponder)
// BeginStop is the fake for method SAPVirtualInstancesClient.BeginStop
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginStop func(ctx context.Context, resourceGroupName string, sapVirtualInstanceName string, options *armworkloadssapvirtualinstance.SAPVirtualInstancesClientBeginStopOptions) (resp azfake.PollerResponder[armworkloadssapvirtualinstance.SAPVirtualInstancesClientStopResponse], errResp azfake.ErrorResponder)
// BeginUpdate is the fake for method SAPVirtualInstancesClient.BeginUpdate
// HTTP status codes to indicate success: http.StatusOK, http.StatusAccepted
BeginUpdate func(ctx context.Context, resourceGroupName string, sapVirtualInstanceName string, body armworkloadssapvirtualinstance.UpdateSAPVirtualInstanceRequest, options *armworkloadssapvirtualinstance.SAPVirtualInstancesClientBeginUpdateOptions) (resp azfake.PollerResponder[armworkloadssapvirtualinstance.SAPVirtualInstancesClientUpdateResponse], errResp azfake.ErrorResponder)
}
SAPVirtualInstancesServer is a fake server for instances of the armworkloadssapvirtualinstance.SAPVirtualInstancesClient type.
type SAPVirtualInstancesServerTransport ¶
type SAPVirtualInstancesServerTransport struct {
// contains filtered or unexported fields
}
SAPVirtualInstancesServerTransport connects instances of armworkloadssapvirtualinstance.SAPVirtualInstancesClient to instances of SAPVirtualInstancesServer. Don't use this type directly, use NewSAPVirtualInstancesServerTransport instead.
func NewSAPVirtualInstancesServerTransport ¶
func NewSAPVirtualInstancesServerTransport(srv *SAPVirtualInstancesServer) *SAPVirtualInstancesServerTransport
NewSAPVirtualInstancesServerTransport creates a new instance of SAPVirtualInstancesServerTransport with the provided implementation. The returned SAPVirtualInstancesServerTransport instance is connected to an instance of armworkloadssapvirtualinstance.SAPVirtualInstancesClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type ServerFactory ¶
type ServerFactory struct {
OperationsServer OperationsServer
SAPApplicationServerInstancesServer SAPApplicationServerInstancesServer
SAPCentralInstancesServer SAPCentralInstancesServer
SAPDatabaseInstancesServer SAPDatabaseInstancesServer
SAPVirtualInstancesServer SAPVirtualInstancesServer
WorkloadsServer WorkloadsServer
}
ServerFactory is a fake server for instances of the armworkloadssapvirtualinstance.ClientFactory type.
type ServerFactoryTransport ¶
type ServerFactoryTransport struct {
// contains filtered or unexported fields
}
ServerFactoryTransport connects instances of armworkloadssapvirtualinstance.ClientFactory to instances of ServerFactory. Don't use this type directly, use NewServerFactoryTransport instead.
func NewServerFactoryTransport ¶
func NewServerFactoryTransport(srv *ServerFactory) *ServerFactoryTransport
NewServerFactoryTransport creates a new instance of ServerFactoryTransport with the provided implementation. The returned ServerFactoryTransport instance is connected to an instance of armworkloadssapvirtualinstance.ClientFactory via the azcore.ClientOptions.Transporter field in the client's constructor parameters.
type WorkloadsServer ¶
type WorkloadsServer struct {
// SAPAvailabilityZoneDetails is the fake for method WorkloadsClient.SAPAvailabilityZoneDetails
// HTTP status codes to indicate success: http.StatusOK
SAPAvailabilityZoneDetails func(ctx context.Context, location string, options *armworkloadssapvirtualinstance.WorkloadsClientSAPAvailabilityZoneDetailsOptions) (resp azfake.Responder[armworkloadssapvirtualinstance.WorkloadsClientSAPAvailabilityZoneDetailsResponse], errResp azfake.ErrorResponder)
// SAPDiskConfigurations is the fake for method WorkloadsClient.SAPDiskConfigurations
// HTTP status codes to indicate success: http.StatusOK
SAPDiskConfigurations func(ctx context.Context, location string, options *armworkloadssapvirtualinstance.WorkloadsClientSAPDiskConfigurationsOptions) (resp azfake.Responder[armworkloadssapvirtualinstance.WorkloadsClientSAPDiskConfigurationsResponse], errResp azfake.ErrorResponder)
// SAPSizingRecommendations is the fake for method WorkloadsClient.SAPSizingRecommendations
// HTTP status codes to indicate success: http.StatusOK
SAPSizingRecommendations func(ctx context.Context, location string, options *armworkloadssapvirtualinstance.WorkloadsClientSAPSizingRecommendationsOptions) (resp azfake.Responder[armworkloadssapvirtualinstance.WorkloadsClientSAPSizingRecommendationsResponse], errResp azfake.ErrorResponder)
// SAPSupportedSKU is the fake for method WorkloadsClient.SAPSupportedSKU
// HTTP status codes to indicate success: http.StatusOK
SAPSupportedSKU func(ctx context.Context, location string, options *armworkloadssapvirtualinstance.WorkloadsClientSAPSupportedSKUOptions) (resp azfake.Responder[armworkloadssapvirtualinstance.WorkloadsClientSAPSupportedSKUResponse], errResp azfake.ErrorResponder)
}
WorkloadsServer is a fake server for instances of the armworkloadssapvirtualinstance.WorkloadsClient type.
type WorkloadsServerTransport ¶
type WorkloadsServerTransport struct {
// contains filtered or unexported fields
}
WorkloadsServerTransport connects instances of armworkloadssapvirtualinstance.WorkloadsClient to instances of WorkloadsServer. Don't use this type directly, use NewWorkloadsServerTransport instead.
func NewWorkloadsServerTransport ¶
func NewWorkloadsServerTransport(srv *WorkloadsServer) *WorkloadsServerTransport
NewWorkloadsServerTransport creates a new instance of WorkloadsServerTransport with the provided implementation. The returned WorkloadsServerTransport instance is connected to an instance of armworkloadssapvirtualinstance.WorkloadsClient via the azcore.ClientOptions.Transporter field in the client's constructor parameters.